@@ -11,13 +11,16 @@ void DeferredInit(PyMOLGlobals *G, CDeferred *I)
 
 void DeferredFree(CDeferred *I)
 {
-  FreeP(I);
+  while(I) {
+    CDeferred *next = I->next;
+    FreeP(I);
+    I=next;
+  }
 }
 
 CDeferred *DeferredExec(CDeferred *I)
 {
-  if(I)
-  while(I) {
+  while(I) { /* executes all deferred actions */
     CDeferred *next = I->next;
     if(I->fn) {
       if(!I->fn(I)) {
