@@ -20,44 +20,41 @@ Z* -------------------------------------------------------------------
 #include"Feedback.h"
 #include"Ortho.h"
 
-typedef struct {
-  char *Stack;
-  int Depth;
-} CFeedback;
 
-char *FeedbackMask;
 
-CFeedback Feedbk;
-
-void FeedbackInit(int quiet)
+int FeedbackInit(PyMOLGlobals *G,int quiet)
 {
   int a;
   
-  CFeedback *I=&Feedbk;
+  register CFeedback *I;
+  I = (G->Feedback = Calloc(CFeedback,1));
 
   I->Stack=VLAMalloc(FB_Total,sizeof(char),5,0);
   I->Depth=0;
-  FeedbackMask = I->Stack;
+  G->Feedback->Mask = I->Stack;
 
   if(quiet) {
     for(a=0;a<FB_Total;a++) {
-      FeedbackMask[a] = 0;
+      G->Feedback->Mask[a] = 0;
     }  
   } else {
     for(a=0;a<FB_Total;a++) {
-      FeedbackMask[a] = FB_Output | FB_Results | FB_Errors | FB_Warnings | FB_Actions | FB_Details;
+      G->Feedback->Mask[a] = FB_Output | FB_Results | FB_Errors | FB_Warnings | FB_Actions | FB_Details;
     }
 
-    FeedbackMask[FB_Main] &= ~(FB_Errors); /* suppress opengl errors in main */
+    G->Feedback->Mask[FB_Main] &= ~(FB_Errors); /* suppress opengl errors in main */
 
   }
+  return 1;
 }
 
-void FeedbackFree(void)
+void FeedbackFree(PyMOLGlobals *G)
 {
-  CFeedback *I=&Feedbk;
+  register CFeedback *I=G->Feedback;
 
   VLAFreeP(I->Stack);
+  FreeP(G->Feedback);
+
 }
 
 /* below we'll presume that any standard feedback on the feedback
@@ -65,84 +62,84 @@ module itself will be effected at the Python level, since feedback
 levels will be changed as a matter of course inside of PyMOL in order
 to quietly perform complex actions.  */
 
-void FeedbackPush(void)
+void FeedbackPush(PyMOLGlobals *G)
 {
-  CFeedback *I=&Feedbk;
+  register CFeedback *I=G->Feedback;
   int a;
   I->Depth++;
   VLACheck(I->Stack,char,(I->Depth+1)*FB_Total);
-  FeedbackMask=I->Stack+(I->Depth*FB_Total);
+  G->Feedback->Mask=I->Stack+(I->Depth*FB_Total);
   for(a=0;a<FB_Total;a++) {
-    FeedbackMask[a] = FeedbackMask[a-FB_Total];
+    G->Feedback->Mask[a] = G->Feedback->Mask[a-FB_Total];
   }
-  PRINTFD(FB_Feedback) " Feedback: push\n" ENDFD;
+  PRINTFD(G,FB_Feedback) " Feedback: push\n" ENDFD;
 }
 
-void FeedbackPop(void)
+void FeedbackPop(PyMOLGlobals *G)
 {
-  CFeedback *I=&Feedbk;
+  register CFeedback *I=G->Feedback;
   if(I->Depth) {
     I->Depth--;
-    FeedbackMask=I->Stack+(I->Depth*FB_Total);
+    G->Feedback->Mask=I->Stack+(I->Depth*FB_Total);
   }
-  PRINTFD(FB_Feedback) " Feedback: pop\n" ENDFD;
+  PRINTFD(G,FB_Feedback) " Feedback: pop\n" ENDFD;
 }
 
-void FeedbackSetMask(unsigned int sysmod,unsigned char mask)
+void FeedbackSetMask(PyMOLGlobals *G,unsigned int sysmod,unsigned char mask)
 {
   int a;
   if((sysmod>0)&&(sysmod<FB_Total)) {
-    FeedbackMask[sysmod] = mask;
+    G->Feedback->Mask[sysmod] = mask;
   } else if(!sysmod) {
     for(a=0;a<FB_Total;a++) {
-      FeedbackMask[a] = mask;
+      G->Feedback->Mask[a] = mask;
     }
   }
-  PRINTFD(FB_Feedback)
+  PRINTFD(G,FB_Feedback)
     " FeedbackSetMask: sysmod %d, mask 0x%02X\n",sysmod,mask 
     ENDFD;
 }
 
 
-void FeedbackDisable(unsigned int sysmod,unsigned char mask)
+void FeedbackDisable(PyMOLGlobals *G,unsigned int sysmod,unsigned char mask)
 {
   int a;
   if((sysmod>0)&&(sysmod<FB_Total)) {
-    FeedbackMask[sysmod] = FeedbackMask[sysmod] & (0xFF-mask);
+    G->Feedback->Mask[sysmod] = G->Feedback->Mask[sysmod] & (0xFF-mask);
   } else if(!sysmod) {
     for(a=0;a<FB_Total;a++) {
-      FeedbackMask[a] = FeedbackMask[a] & (0xFF-mask);
+      G->Feedback->Mask[a] = G->Feedback->Mask[a] & (0xFF-mask);
     }
   }
-  PRINTFD(FB_Feedback)
+  PRINTFD(G,FB_Feedback)
     " FeedbackDisable: sysmod %d, mask 0x%02X\n",sysmod,mask 
     ENDFD;
 
 }
 
-void FeedbackEnable(unsigned int sysmod,unsigned char mask)
+void FeedbackEnable(PyMOLGlobals *G,unsigned int sysmod,unsigned char mask)
 {
   int a;
   if((sysmod>0)&&(sysmod<FB_Total)) {
-    FeedbackMask[sysmod] = FeedbackMask[sysmod] | mask;
+    G->Feedback->Mask[sysmod] = G->Feedback->Mask[sysmod] | mask;
   } else if(!sysmod) {
     for(a=0;a<FB_Total;a++) {
-      FeedbackMask[a] = FeedbackMask[a] | mask;
+      G->Feedback->Mask[a] = G->Feedback->Mask[a] | mask;
     }
   }
-  PRINTFD(FB_Feedback)
+  PRINTFD(G,FB_Feedback)
     " FeedbackEnable: sysmod %d, mask 0x%02X\n",sysmod,mask 
     ENDFD;
   
 }
 
-void FeedbackAutoAdd(unsigned int sysmod,unsigned char mask,char *str)
+void FeedbackAutoAdd(PyMOLGlobals *G,unsigned int sysmod,unsigned char mask,char *str)
 {
-  if(Feedback(sysmod,mask))
-    OrthoAddOutput(str);
+  if(Feedback(G,sysmod,mask))
+    OrthoAddOutput(G,str);
 }
 
-void FeedbackAdd(char *str)
+void FeedbackAdd(PyMOLGlobals *G,char *str)
 {
-  OrthoAddOutput(str);
+  OrthoAddOutput(G,str);
 }
