@@ -16,6 +16,8 @@ Z* -------------------------------------------------------------------
 #ifndef _H_ListMacros
 #define _H_ListMacros
 
+/* simplest possible single-linked list */
+
 #include"MemoryDebug.h"
 #include"Err.h"
 
@@ -105,7 +107,7 @@ Z* -------------------------------------------------------------------
 }
 
 #define ListIterate(List,Counter,Link) \
-   ( (Counter) = ((Counter) ? (Counter)->Link : (List)))
+   ( (Counter) = ((List) ? (((Counter) ? (Counter)->Link : (List))) : NULL))
 
 /* Elem handling routines */
 
