@@ -52,7 +52,7 @@ MapType *MapNewCached(PyMOLGlobals *G,float range,float *vert,int nVert,float *e
 
 MapType *MapNewFlagged(PyMOLGlobals *G,float range,float *vert,int nVert,float *extent,int *flag);
 void MapSetupExpress(MapType *I);
-void MapSetupExpressPerp(MapType *I, float *vert, float front,int nVertHint,int negative_start);
+void MapSetupExpressPerp(MapType *I, float *vert, float front,int nVertHint,int negative_start,int *spanner);
 
 void MapFree(MapType *I);
 
@@ -63,6 +63,7 @@ void MapFree(MapType *I);
 #define MapNext(m,a) (*(m->Link+(a)))
 void MapLocus(MapType *map,float *v,int *a,int *b,int *c);
 int *MapLocusEStart(MapType *map,float *v);
+
 int MapExclLocus(MapType *map,float *v,int *a,int *b,int *c);
 
 #define MapCache(m,a) {(m)->Cache[a]=1;(m)->CacheLink[a]=(m)->CacheStart;(m)->CacheStart=a;}
