@@ -38,7 +38,7 @@ void MemoryCacheInit(PyMOLGlobals *G)
   G->MemoryCache=Calloc(CMemoryCache,1);
 }
 
-void *MemoryCacheMalloc(PyMOLGlobals *G,unsigned int size,int group_id,int block_id)
+void *_MemoryCacheMalloc(PyMOLGlobals *G,unsigned int size,int group_id,int block_id MD_FILE_LINE_Decl)
 {
   if((group_id<0)||(!SettingGetGlobal_b(G,cSetting_cache_memory)))
     return(mmalloc(size));
@@ -59,7 +59,7 @@ void *MemoryCacheMalloc(PyMOLGlobals *G,unsigned int size,int group_id,int block
   }
 }
 
-void *MemoryCacheCalloc(PyMOLGlobals *G,unsigned int number, unsigned int size,int group_id,int block_id)
+void *_MemoryCacheCalloc(PyMOLGlobals *G,unsigned int number, unsigned int size,int group_id,int block_id MD_FILE_LINE_Decl)
 {
   if((group_id<0)||(!SettingGetGlobal_b(G,cSetting_cache_memory)))
     return(mcalloc(number,size));
@@ -86,8 +86,21 @@ void *MemoryCacheCalloc(PyMOLGlobals *G,unsigned int number, unsigned int size,i
     return(rec->ptr);
   }
 }
+void MemoryCacheReplaceBlock(PyMOLGlobals *G,void *ptr, int group_id, int old_block_id, int new_block_id)
+{
+  if((group_id<0)||(!SettingGetGlobal_b(G,cSetting_cache_memory)))
+    return;
+  {
+    register CMemoryCache *I = G->MemoryCache;
+    register MemoryCacheRec *old_rec = &I->Cache[group_id][old_block_id];
+    register MemoryCacheRec *new_rec = &I->Cache[group_id][new_block_id];
+    if(new_rec->ptr) mfree(new_new->ptr);
+    *(new_rec)  = *(old_rec);
+    old_rec->ptr = NULL;
+  }
+}
 
-void *MemoryCacheRealloc(PyMOLGlobals *G,void *ptr, unsigned int size,int group_id, int block_id)
+void *_MemoryCacheRealloc(PyMOLGlobals *G,void *ptr, unsigned int size,int group_id, int block_id MD_FILE_LINE_Decl)
 {
   /* no checking done */
 
@@ -109,8 +122,33 @@ void *MemoryCacheRealloc(PyMOLGlobals *G,void *ptr, unsigned int size,int group_
     return(rec->ptr);
   }
 }
+void *_MemoryShrinkForSure(PyMOLGlobals *G,void *ptr, unsigned int size,int group_id, int block_id MD_FILE_LINE_Decl)
+{
+  /* no checking done */
 
-void MemoryCacheFree(PyMOLGlobals *G,void *ptr,int group_id, int block_id,int force)
+  if((group_id<0)||(!SettingGetGlobal_b(G,cSetting_cache_memory)))
+    return(ReallocForSure(ptr,size)); /* NOTE: fatal if new ptr is larger than old... */
+  {
+    register CMemoryCache *I = G->MemoryCache;
+    register MemoryCacheRec *rec = &I->Cache[group_id][block_id];
+
+    if(ptr!=rec->ptr)
+      printf("Error: Memory Cache Mismatch 2 %d %d\n",group_id,block_id);
+    if(!rec->ptr) { /* not currently cache-allocated... this should never happen */
+      rec->size= size;
+      rec->ptr = mrealloc(ptr,size);
+    } else if(rec->size<size) {
+      rec->ptr = MemoryReallocForSureSafe(ptr,size,rec->size);
+      rec->size = size;
+    } else { /* expanding size...should never happen... this should never happen*/
+      rec->size = size;
+      rec->ptr = mrealloc(ptr,size);
+    }
+    return(rec->ptr);
+  }
+}
+
+void _MemoryCacheFree(PyMOLGlobals *G,void *ptr,int group_id, int block_id,int force MD_FILE_LINE_Decl)
 {
   if((group_id<0)||(!SettingGetGlobal_b(G,cSetting_cache_memory))) {
     mfree(ptr);
@@ -142,4 +180,7 @@ void MemoryCacheDone(PyMOLGlobals *G)
   }
   FreeP(G->MemoryCache);
 }
+#else
+typedef int file_not_empty_as_per_iso_c;
+
 #endif
