@@ -16,21 +16,32 @@ Z* -------------------------------------------------------------------
 /* This file can be compiled under C as a .c file, or under C++ as a .cc file*/
 
 #include"os_predef.h"
-
-#ifdef __cplusplus
-#include<new.h>
-#endif
+#ifndef OV_JENARIX
 
 #include"MemoryDebug.h"
 #include"MemoryCache.h"
 
 #define GDB_ENTRY
 
-void *MemoryReallocForSure(void *ptr, unsigned int newSize)
+void *MemoryReallocForSureSafe(void *ptr, unsigned int new_size, unsigned int old_size)
 {
-  float *tmp = malloc(newSize);
+  if(new_size<old_size) {
+    float *tmp = mmalloc(new_size);
+    if(tmp && new_size && old_size) {
+        memcpy(tmp, ptr, new_size);
+    }
+    FreeP(ptr);
+    return tmp;
+  } else {
+    return mrealloc(ptr,new_size);
+  }
+}
+
+void *MemoryReallocForSure(void *ptr, unsigned int new_size) /* unsafe -- replace with above */
+{
+  float *tmp = mmalloc(new_size);
   if(tmp)
-    memcpy(tmp,ptr,newSize);
+    memcpy(tmp,ptr,new_size);
   FreeP(ptr);
   return tmp;
 }
@@ -104,124 +115,142 @@ void MemoryZero(char *p,char *q)
 
 }
 
-void *VLAExpand(void *ptr,unsigned int rec)
+void *VLAExpand(void *ptr,ov_size rec)
 {
   VLARec *vla;
   char *start,*stop;
   unsigned int soffset=0;
   vla = &(((VLARec*)ptr)[-1]);
-  if(rec>=vla->nAlloc)
-	 {
-		if(vla->autoZero)
-		  soffset = sizeof(VLARec)+(vla->recSize*vla->nAlloc);
-		vla->nAlloc = (rec*(vla->growFactor+10)/10)+1;
-		vla=(void*)mrealloc(vla,(vla->recSize*vla->nAlloc)+sizeof(VLARec));
-		if(!vla)
-		  {
-			 printf("VLAExpand-ERR: realloc failed.\n");
-          DieOutOfMemory();
-		  }
-		if(vla->autoZero)
-		  {
-			 start = ((char*)vla) + soffset;
-			 stop = ((char*)vla)+sizeof(VLARec)+(vla->recSize*vla->nAlloc);
-			 MemoryZero(start,stop);
-		  }
-	 }
+  if(rec>=vla->size) {
+    if(vla->auto_zero)
+      soffset = sizeof(VLARec)+(vla->unit_size*vla->size);
+    vla->size = ((unsigned int)(rec*vla->grow_factor))+1;
+    if(vla->size<=rec) vla->size = rec+1;
+    {
+      VLARec *old_vla = vla;
+      vla=(void*)mrealloc(vla,(vla->unit_size*vla->size)+sizeof(VLARec));
+      while(!vla) {  /* back off on the request size until it actually fits */
+        vla = old_vla;
+        vla->grow_factor = (vla->grow_factor-1.0F)/2.0F + 1.0F;   
+        vla->size = ((unsigned int)(rec*vla->grow_factor))+1;
+        vla=(void*)mrealloc(vla,(vla->unit_size*vla->size)+sizeof(VLARec));
+        if(!vla) {
+          if(old_vla->grow_factor<1.001F) {
+            printf("VLAExpand-ERR: realloc failed.\n");
+            DieOutOfMemory();
+          }
+        }
+      }
+    }
+    if(vla->auto_zero) {
+      start = ((char*)vla) + soffset;
+      stop = ((char*)vla)+sizeof(VLARec)+(vla->unit_size*vla->size);
+      MemoryZero(start,stop);
+    }
+  }
   return((void*)&(vla[1]));
 }
 
-
+#ifdef _MemoryCache_ON
 void *VLACacheExpand(PyMOLGlobals *G,void *ptr,unsigned int rec,int thread_index,int block_id)
 {
   VLARec *vla;
   char *start,*stop;
   unsigned int soffset=0;
   vla = &(((VLARec*)ptr)[-1]);
-  if(rec>=vla->nAlloc)
+  if(rec>=vla->size)
 	 {
-		if(vla->autoZero)
-		  soffset = sizeof(VLARec)+(vla->recSize*vla->nAlloc);
-		vla->nAlloc = (rec*(vla->growFactor+10)/10)+1;
-		vla=(void*)MemoryCacheRealloc(G,vla,(vla->recSize*vla->nAlloc)+sizeof(VLARec),thread_index,block_id);
+		if(vla->auto_zero)
+		  soffset = sizeof(VLARec)+(vla->unit_size*vla->size);
+		vla->size = ((unsigned int)(rec*vla->grow_factor))+1;
+        if(vla->size<=rec) vla->size = rec+1;
+		vla=(void*)_MemoryCacheRealloc(G,vla,
+                                       (vla->unit_size*vla->size)+sizeof(VLARec),
+                                       thread_index,block_id MD_FILE_LINE_Call);
 		if(!vla)
 		  {
 			 printf("VLAExpand-ERR: realloc failed.\n");
           DieOutOfMemory();
 		  }
-		if(vla->autoZero)
+		if(vla->auto_zero)
 		  {
 			 start = ((char*)vla) + soffset;
-			 stop = ((char*)vla)+sizeof(VLARec)+(vla->recSize*vla->nAlloc);
+			 stop = ((char*)vla)+sizeof(VLARec)+(vla->unit_size*vla->size);
 			 MemoryZero(start,stop);
 		  }
 	 }
   return((void*)&(vla[1]));
 }
+#endif
 
 #ifndef _MemoryDebug_ON
-void *VLAMalloc(unsigned int initSize,unsigned int recSize,unsigned int growFactor,int autoZero)
+void *VLAMalloc(ov_size init_size,ov_size unit_size,unsigned int grow_factor,int auto_zero)
 #else
-void *_VLAMalloc(const char *file,int line,unsigned int initSize,unsigned int recSize,unsigned int growFactor,int autoZero)
+void *_VLAMalloc(const char *file,int line,ov_size init_size,
+                 ov_size unit_size,unsigned int grow_factor,int auto_zero)
 #endif
 {
   VLARec *vla;
   char *start,*stop;
 #ifndef _MemoryDebug_ON
-  vla=(void*)mmalloc((initSize*recSize)+sizeof(VLARec));
+  vla=(void*)mmalloc((init_size*unit_size)+sizeof(VLARec));
 #else
-  vla=MemoryDebugMalloc((initSize*recSize)+sizeof(VLARec),file,line,_MDPointer);
+  vla=MemoryDebugMalloc((init_size*unit_size)+sizeof(VLARec),file,line,_MDPointer);
 #endif
 
+  if(!vla) {
+    printf("VLAMalloc-ERR: malloc failed\n");
+    DieOutOfMemory();
+  }
+  vla->size=init_size;
+  vla->unit_size=unit_size;
+  vla->grow_factor=(1.0F + grow_factor*0.1F);
+  vla->auto_zero=auto_zero;
+  if(vla->auto_zero) {
+    start = ((char*)vla)+sizeof(VLARec);
+    stop = ((char*)vla)+sizeof(VLARec)+(vla->unit_size*vla->size);
+    MemoryZero(start,stop);
+  }
+  return((void*)&(vla[1]));
+}
+
+
+#ifdef _MemoryCache_ON
+#ifndef _MemoryDebug_ON
+void *VLACacheMalloc(PyMOLGlobals *G,unsigned int init_size,unsigned int unit_size,
+                     unsigned int grow_factor,int auto_zero,int thread,int id)
+#else
+void *_VLACacheMalloc(PyMOLGlobals *G,const char *file,int line,
+                      unsigned int init_size,unsigned int unit_size,unsigned int grow_factor,
+                      int auto_zero,int thread,int id)
+#endif
+{
+  VLARec *vla;
+  char *start,*stop;
+
+  vla=(void*)_MemoryCacheMalloc(G,(init_size*unit_size)+sizeof(VLARec),
+                                thread,id 
+                                MD_FILE_LINE_Nest);
+
   if(!vla)
 	 {
 		printf("VLAMalloc-ERR: realloc failed\n");
       DieOutOfMemory();
 	 }
-  vla->nAlloc=initSize;
-  vla->recSize=recSize;
-  vla->growFactor=growFactor;
-  vla->autoZero=autoZero;
-  if(vla->autoZero)
+  vla->size=init_size;
+  vla->unit_size=unit_size;
+  vla->grow_factor=(1.0F + grow_factor*0.1F);
+  vla->auto_zero=auto_zero;
+  if(vla->auto_zero)
 	 {
 		start = ((char*)vla)+sizeof(VLARec);
-		stop = ((char*)vla)+sizeof(VLARec)+(vla->recSize*vla->nAlloc);
+		stop = ((char*)vla)+sizeof(VLARec)+(vla->unit_size*vla->size);
 		MemoryZero(start,stop);
 	 }
   return((void*)&(vla[1]));
 }
 
-
-
-#ifndef _MemoryDebug_ON
-void *VLACacheMalloc(PyMOLGlobals *G,unsigned int initSize,unsigned int recSize,unsigned int growFactor,int autoZero,int thread,int id)
-#else
-void *_VLACacheMalloc(PyMOLGlobals *G,const char *file,int line,unsigned int initSize,unsigned int recSize,unsigned int growFactor,int autoZero,int thread,int id)
 #endif
-{
-  VLARec *vla;
-  char *start,*stop;
-
-  vla=(void*)MemoryCacheMalloc(G,(initSize*recSize)+sizeof(VLARec),thread,id);
-
-  if(!vla)
-	 {
-		printf("VLAMalloc-ERR: realloc failed\n");
-      DieOutOfMemory();
-	 }
-  vla->nAlloc=initSize;
-  vla->recSize=recSize;
-  vla->growFactor=growFactor;
-  vla->autoZero=autoZero;
-  if(vla->autoZero)
-	 {
-		start = ((char*)vla)+sizeof(VLARec);
-		stop = ((char*)vla)+sizeof(VLARec)+(vla->recSize*vla->nAlloc);
-		MemoryZero(start,stop);
-	 }
-  return((void*)&(vla[1]));
-}
-
 
 void VLAFree(void *ptr)
 {
@@ -235,6 +264,7 @@ void VLAFree(void *ptr)
   mfree(vla);
 }
 
+#ifdef _MemoryCache_ON
 void VLACacheFree(PyMOLGlobals *G,void *ptr,int thread,int id,int force)
 {
   VLARec *vla;
@@ -244,88 +274,159 @@ void VLACacheFree(PyMOLGlobals *G,void *ptr,int thread,int id,int force)
 		exit(EXIT_FAILURE);
 	 }
   vla = &(((VLARec*)ptr)[-1]);
-  MemoryCacheFree(G,vla,thread,id,force);
+  _MemoryCacheFree(G,vla,thread,id,force MD_FILE_LINE_Call);
 }
+#endif
 
 unsigned int VLAGetSize(void *ptr)
 {
   VLARec *vla;
   vla = &((VLARec*)ptr)[-1];
-  return(vla->nAlloc);
+  return(vla->size);
 }
 
 void *VLANewCopy(void *ptr)
 {
-  VLARec *vla,*new_vla;
-  unsigned int size;
-  vla = &((VLARec*)ptr)[-1];
-  size = (vla->recSize*vla->nAlloc)+sizeof(VLARec);
-  new_vla=(void*)mmalloc(size);
-  if(!new_vla)
-	 {
+  if(ptr) { /* NULL protected */
+    VLARec *vla,*new_vla;
+    unsigned int size;
+    vla = &((VLARec*)ptr)[-1];
+    size = (vla->unit_size*vla->size)+sizeof(VLARec);
+    new_vla=(void*)mmalloc(size);
+    if(!new_vla)
+      {
 		printf("VLACopy-ERR: mmalloc failed\n");
 		exit(EXIT_FAILURE);
-	 }
-  else
-    {
-      memcpy(new_vla,vla,size);
-    }
-  return((void*)&(new_vla[1]));
+      }
+    else
+      {
+        memcpy(new_vla,vla,size);
+      }
+    return((void*)&(new_vla[1]));
+  } else {
+    return NULL;
+  }
 }
-
-void *VLACacheSetSize(PyMOLGlobals *G,void *ptr,unsigned int newSize,int group_id,int block_id)
+#ifdef _MemoryCache_ON
+void *VLACacheSetSize(PyMOLGlobals *G,void *ptr,unsigned int new_size,int group_id,int block_id)
 {
   VLARec *vla;
   char *start=NULL;
   char *stop;
   unsigned int soffset=0;
   vla = &((VLARec*)ptr)[-1];
-  if(vla->autoZero) {
-	 soffset = sizeof(VLARec)+(vla->recSize*vla->nAlloc);
+  if(vla->auto_zero) {
+	 soffset = sizeof(VLARec)+(vla->unit_size*vla->size);
   }
-  vla->nAlloc = newSize;
-  vla=(void*)MemoryCacheRealloc(G,vla,(vla->recSize*vla->nAlloc)+sizeof(VLARec),group_id,block_id);
+  vla->size = new_size;
+  vla=(void*)_MemoryCacheRealloc(G,vla,(vla->unit_size*vla->size)+sizeof(VLARec),
+                                 group_id,block_id MD_FILE_LINE_Call);
   if(!vla)
 	 {
 		printf("VLASetSize-ERR: realloc failed.\n");
       DieOutOfMemory();
 	 }
-  if(vla->autoZero)
+  if(vla->auto_zero)
 	 {
       start = ((char*)vla)+soffset;
-		stop = ((char*)vla)+sizeof(VLARec)+(vla->recSize*vla->nAlloc);
+		stop = ((char*)vla)+sizeof(VLARec)+(vla->unit_size*vla->size);
+		if(start<stop)
+		  MemoryZero(start,stop);
+	 }
+  return((void*)&(vla[1]));
+}
+void *VLACacheSetSizeForSure(PyMOLGlobals *G,void *ptr,unsigned int new_size,int group_id,int block_id)
+{
+  VLARec *vla;
+  char *start=NULL;
+  char *stop;
+  unsigned int soffset=0;
+  vla = &((VLARec*)ptr)[-1];
+  if(vla->auto_zero) {
+	 soffset = sizeof(VLARec)+(vla->unit_size*vla->size);
+  }
+  if(new_size<vla->size) {
+    vla->size = new_size;
+    vla=(void*)_MemoryCacheShrinkForSure(G,vla,(vla->unit_size*vla->size)+sizeof(VLARec),
+                                         group_id,block_id MD_FILE_LINE_Call);
+  } else {
+    vla->size = new_size;
+    vla=(void*)_MemoryCacheRealloc(G,vla,(vla->unit_size*vla->size)+sizeof(VLARec),
+                                   group_id,block_id MD_FILE_LINE_Call);
+  }
+  if(!vla)
+	 {
+		printf("VLASetSize-ERR: realloc failed.\n");
+      DieOutOfMemory();
+	 }
+  if(vla->auto_zero)
+	 {
+      start = ((char*)vla)+soffset;
+		stop = ((char*)vla)+sizeof(VLARec)+(vla->unit_size*vla->size);
+		if(start<stop)
+		  MemoryZero(start,stop);
+	 }
+  return((void*)&(vla[1]));
+}
+#endif
+
+
+void *VLASetSize(void *ptr,unsigned int new_size)
+{
+  VLARec *vla;
+  char *start=NULL;
+  char *stop;
+  unsigned int soffset=0;
+  vla = &((VLARec*)ptr)[-1];
+  if(vla->auto_zero) {
+	 soffset = sizeof(VLARec)+(vla->unit_size*vla->size);
+  }
+  vla->size = new_size;
+  vla=(void*)mrealloc(vla,(vla->unit_size*vla->size)+sizeof(VLARec));
+  if(!vla)
+	 {
+		printf("VLASetSize-ERR: realloc failed.\n");
+      DieOutOfMemory();
+	 }
+  if(vla->auto_zero)
+	 {
+      start = ((char*)vla)+soffset;
+		stop = ((char*)vla)+sizeof(VLARec)+(vla->unit_size*vla->size);
 		if(start<stop)
 		  MemoryZero(start,stop);
 	 }
   return((void*)&(vla[1]));
 }
 
-
-
-void *VLASetSize(void *ptr,unsigned int newSize)
+void *VLASetSizeForSure(void *ptr,unsigned int new_size)
 {
   VLARec *vla;
   char *start=NULL;
   char *stop;
   unsigned int soffset=0;
   vla = &((VLARec*)ptr)[-1];
-  if(vla->autoZero) {
-	 soffset = sizeof(VLARec)+(vla->recSize*vla->nAlloc);
+  if(vla->auto_zero) {
+    soffset = sizeof(VLARec)+(vla->unit_size*vla->size);
+  }
+  if(new_size<vla->size) {
+    vla=MemoryReallocForSureSafe(vla,
+                                 (vla->unit_size*new_size)+sizeof(VLARec),
+                                 (vla->unit_size*vla->size)+sizeof(VLARec));
+    vla->size = new_size;
+  } else {
+    vla->size = new_size;
+    vla=(void*)mrealloc(vla,(vla->unit_size*vla->size)+sizeof(VLARec));
+  }
+  if(!vla) {
+    printf("VLASetSize-ERR: realloc failed.\n");
+    DieOutOfMemory();
+  }
+  if(vla->auto_zero) {
+    start = ((char*)vla)+soffset;
+    stop = ((char*)vla)+sizeof(VLARec)+(vla->unit_size*vla->size);
+    if(start<stop)
+      MemoryZero(start,stop);
   }
-  vla->nAlloc = newSize;
-  vla=(void*)mrealloc(vla,(vla->recSize*vla->nAlloc)+sizeof(VLARec));
-  if(!vla)
-	 {
-		printf("VLASetSize-ERR: realloc failed.\n");
-      DieOutOfMemory();
-	 }
-  if(vla->autoZero)
-	 {
-      start = ((char*)vla)+soffset;
-		stop = ((char*)vla)+sizeof(VLARec)+(vla->recSize*vla->nAlloc);
-		if(start<stop)
-		  MemoryZero(start,stop);
-	 }
   return((void*)&(vla[1]));
 }
 
@@ -379,80 +480,6 @@ void MemoryDebugInit(void)
   Count=0;
   MaxCount=0;
 }
-void MemoryDebugRegister(void *addr,const char *note,
-			 const char *file,int line)
-{
-  DebugRec *rec,*str;
-  int hash;
-
-  if(InitFlag) MemoryDebugInit();
-
-  rec=(DebugRec*)malloc(sizeof(DebugRec)+strlen(note));
-  if(!rec)
-    {
-      printf("MemoryDebugRegister-ERR: memory allocation failure\n"); 
-#ifdef GDB_ENTRY
-  MemoryDebugDump();
-  abort();
-#endif
-  DieOutOfMemory();
-    }
-  rec->size=(size_t)addr;
-  rec->type=_MDMarker;
-  rec->line=line;
-  strcpy(rec->file,file);
-  str=rec+1;
-  strcpy((char*)str,note);
-  hash=(int)addr;
-  hash=HASH(hash);
-  rec->next=HashTable[hash];
-  HashTable[hash]=rec;
-  Count++;
-  if(MaxCount<Count) MaxCount=Count;
-}
-
-void MemoryDebugForget(void *addr,const char *file,int line)
-{
-  DebugRec *rec = NULL;
-  DebugRec *cur,*last;
-  int hash;
-
-  if(InitFlag) MemoryDebugInit();
-  hash=(int)addr;
-  hash=HASH(hash);
-  last=NULL;
-  cur=HashTable[hash];
-  while(cur)
-    {
-      if((cur->size==(size_t)addr)&&(cur->type==_MDMarker))
-	{
-	  rec=cur;
-	  if(last)
-	    last->next=cur->next;
-	  else
-	    HashTable[hash]=cur->next;
-	  break;
-	}
-      last=cur;
-      cur=cur->next;
-    }  
-   if(rec)
-    {
-      free(rec);
-    }
-  else
-    {
-      printf(
-   "MemoryDebug-ERR: free(): corrupted tree or bad ptr! (%s:%i @%p)\n",
-	     file,line,addr);
-#ifdef GDB_ENTRY
-  MemoryDebugDump();
-  abort();
-#endif
-      exit(EXIT_FAILURE);
-    }
-  Count--;
-}
 
 int MemoryDebugUsage(void) 
 {
@@ -460,16 +487,12 @@ int MemoryDebugUsage(void)
   unsigned int tot  = 0;
   DebugRec *rec;
   if(InitFlag) MemoryDebugInit();
-  for(a=0;a<1024;a++)
-    {
-      rec=HashTable[a];
-      while(rec)
-        {
-          if(rec->type!=_MDMarker)
-            tot+=rec->size;
-          rec=rec->next;
-        }
+  for(a=0;a<1024;a++) {
+    rec=HashTable[a];
+    while(rec) {
+      rec=rec->next;
     }
+  }
   return(tot);
 }
 
@@ -478,31 +501,23 @@ void MemoryDebugDump(void)
   int a;
   int cnt=0;
   unsigned int tot  = 0;
-  DebugRec *rec,*str;
+  DebugRec *rec;
   if(InitFlag) MemoryDebugInit();
-  for(a=0;a<1024;a++)
-    {
-      rec=HashTable[a];
-      while(rec)
-	{
-	  if(rec->type==_MDMarker)
-	    {
-	      str=rec+1;
-	    printf(" MemoryDebug: %s:%i <%s> \n",
-		   rec->file,rec->line,(char*)str);
-	    }
-	  else {
-       tot+=rec->size;
-	    printf(" MemoryDebug: @%10p-%10p:%7x:%i %s:%i     \n",
-				  rec+1,((char*)(rec+1)+rec->size),rec->size,rec->type,rec->file,rec->line);
-     }
+  for(a=0;a<1024;a++)  {
+    rec=HashTable[a];
+    while(rec)	{
+	  tot+=rec->size;
+      printf("Memory: %12p %12p %8x %3.1f %s:%i\n",
+             (void*)(rec+1),
+             ((char*)(rec+1)+rec->size),(unsigned int)rec->size,
+             rec->size/1048576.0F,rec->file,rec->line);
 	  rec=rec->next;
 	  cnt++;
 	}
-    }
-  printf(" Memory: %d blocks expected, %d found, %d maximum allocated.\n",
-			Count,cnt,MaxCount);
-  printf(" Memory: current memory allocated %x bytes (%0.1f MB).\n",tot,tot/(1024.0*1024));
+  }
+  printf("Memory: %d blocks expected, %d found, %d maximum allocated.\n",
+         Count,cnt,MaxCount);
+  printf("Memory: current memory allocated %x bytes (%0.1f MB).\n",tot,tot/(1024.0*1024));
 
 }
 
@@ -513,7 +528,7 @@ void MemoryDebugHashAdd(DebugRec *rec)
 {
   int hash;
 
-  hash=(int)rec;
+  hash=(int)rec; 
   hash=HASH(hash);
   rec->next=HashTable[hash];
   HashTable[hash]=rec;
@@ -744,6 +759,76 @@ void *MemoryDebugReallocForSure(void *ptr,size_t size,const char *file,
   return(ptr);
 }
 
+void *MemoryDebugReallocForSureSafe(void *ptr,size_t size,size_t old_size,
+                                    const char *file,int line,int type)
+{
+  DebugRec *rec,*new_rec;
+
+  if(InitFlag) MemoryDebugInit();
+  if((!ptr)&&(!size)) {
+    printf(
+           "MemoryDebug-ERR: realloc given (NULL,zero) (%s:%i)\n",
+           file,line);
+#ifdef GDB_ENTRY
+    MemoryDebugDump();
+    abort();
+#endif
+    exit(EXIT_FAILURE);
+  }
+  if(!ptr)
+    return(MemoryDebugMalloc(size,file,line,type));
+  else if(!size) {
+    MemoryDebugFree(ptr,file,line,type);
+    return(NULL);
+  }  else    {
+    rec=MemoryDebugHashRemove(ptr);
+    if(!rec) {
+      printf(
+             "MemoryDebug-ERR: realloc() corrupted tree or bad ptr! (%s:%i @%p)\n",
+             file,line,ptr);
+#ifdef GDB_ENTRY
+      MemoryDebugDump();
+      abort();
+#endif
+      exit(EXIT_FAILURE);
+    } else {
+      if(rec->type!=type) {
+        printf("MemoryDebug-ERR: ptr %p is of wrong type: %i!=%i (%s:%i)\n",
+               ptr,rec->type,type,file,line);
+#ifdef GDB_ENTRY
+        MemoryDebugDump();
+        abort();
+#endif
+        exit(EXIT_FAILURE);
+      }
+      if(old_size>size) {
+        new_rec=malloc(size+sizeof(DebugRec));
+        if(new_rec)
+          memcpy(new_rec,rec,size+sizeof(DebugRec));
+        free(rec);
+        rec=new_rec;
+      } else {
+        rec=realloc(rec,size+sizeof(DebugRec));
+      }
+      if(!rec) {
+        printf("MemoryDebug-ERR: realloc() failed reallocation! (%s:%i)\n",
+               file,line);
+#ifdef GDB_ENTRY
+        MemoryDebugDump();
+        abort();
+#endif
+        DieOutOfMemory();
+      } else {
+        MemoryDebugHashAdd(rec);
+        rec->size=size;
+        rec++;
+        return((void*)rec);
+      }
+    }
+  }
+  return(ptr);
+}
+
 
 void MemoryDebugQuietFree(void *ptr,int type)
 {
@@ -821,24 +906,11 @@ void MemoryDebugFree(void *ptr,const char*file,int line,int type)
 
 #ifdef __cplusplus
 }
-
-#undef new
-
-void *operator new(size_t size, const char *file,int line)
-{
-  if(InitFlag) MemoryDebugInit();
-  return(MemoryDebugMalloc(size,file,line,_MDObject));
-}
-
-void operator delete(void *ptr)
-{
-  if(InitFlag) MemoryDebugInit();
-  MemoryDebugQuietFree(ptr,_MDObject);
-}
 #endif
 
 
 #endif
+#endif
 
 
 
@@ -848,4 +920,3 @@ void operator delete(void *ptr)
 
 
 
-
