@@ -14,7 +14,19 @@ I* Additional authors of this source file include:
 Z* -------------------------------------------------------------------
 */
 
+#include"os_predef.h"
+
+/* backwards compatibility */
+
 #ifdef _HAVE_LIBPNG
+#ifndef _PYMOL_LIBPNG
+#define _PYMOL_LIBPNG
+#endif
+#endif
+
+/* do we have libpng? */
+
+#ifdef _PYMOL_LIBPNG
 #include<png.h>
 
  /* The png_jmpbuf() macro, used in error handling, became available in
@@ -29,7 +41,6 @@ Z* -------------------------------------------------------------------
 
 #endif
 
-#include"os_predef.h"
 #include"os_std.h"
 
 #include"Base.h"
@@ -41,7 +52,7 @@ Z* -------------------------------------------------------------------
 int MyPNGWrite(PyMOLGlobals *G,char *file_name,unsigned char *p,
                unsigned int width,unsigned int height,float dpi)
 {
-#ifdef _HAVE_LIBPNG
+#ifdef _PYMOL_LIBPNG
 
    FILE *fp;
    png_structp png_ptr;
@@ -115,9 +126,22 @@ int MyPNGWrite(PyMOLGlobals *G,char *file_name,unsigned char *p,
      png_set_pHYs(png_ptr, info_ptr, dots_per_meter, dots_per_meter, PNG_RESOLUTION_METER);
    }
 
+
    png_set_gamma(png_ptr, SettingGet(G,cSetting_png_screen_gamma), 
                  SettingGet(G,cSetting_png_file_gamma));
+   
+   /* stamp the image as being created by PyMOL we could consider
+    * supporting optional annotations as well: PDB codes, canonical
+    * smiles, INCHIs, and other common identifiers */
 
+   {
+     png_text text;
+     text.compression = PNG_TEXT_COMPRESSION_NONE;
+     text.key = (png_charp) "Software";
+     text.text = (png_charp) "PyMOL";
+     text.text_length = 5;
+     png_set_text(png_ptr, info_ptr, &text, 1);
+   }
 
    /* Write the file header information.  REQUIRED */
    png_write_info(png_ptr, info_ptr);
@@ -153,7 +177,7 @@ int MyPNGWrite(PyMOLGlobals *G,char *file_name,unsigned char *p,
 int MyPNGRead(char *file_name,unsigned char **p_ptr,unsigned int *width_ptr,unsigned int *height_ptr)
 {
 
-#ifdef _HAVE_LIBPNG
+#ifdef _PYMOL_LIBPNG
 
   FILE *png_file=NULL;
   png_struct    *png_ptr = NULL;
