@@ -73,6 +73,11 @@ typedef struct _OVContext OVContext;
 #define OVCONTEXT_DEFINED
 #endif
 
+#ifndef CObject_DEFINED
+typedef struct _CObject CObject;
+#define CObject_DEFINED
+#endif
+
 #ifndef CPyMOL_DEFINED
 typedef struct _CPyMOL CPyMOL;
 #define CPyMOL_DEFINED
@@ -106,7 +111,7 @@ struct _PyMOLGlobals {
   CScene    *Scene;
   CGO       *DebugCGO; /* for debugging rendering */
   CSeq      *Seq;
-  CSetting  *Setting;
+  CSetting  *Setting, *Default;
   CSettingUnique *SettingUnique;
   CText     *Text;
   CWizard   *Wizard;
