@@ -679,6 +679,28 @@ void transpose44f44f ( float  *m1, float  *m2)
   m2[14] = m1[11];
   m2[15] = m1[15];
 }
+void transpose44d44d ( double *m1, double  *m2)
+{
+  m2[0 ] = m1[0 ];
+  m2[1 ] = m1[4 ];
+  m2[2 ] = m1[8 ];
+  m2[3 ] = m1[12];
+
+  m2[4 ] = m1[1 ];
+  m2[5 ] = m1[5 ];
+  m2[6 ] = m1[9 ];
+  m2[7 ] = m1[13];
+
+  m2[8 ] = m1[2 ];
+  m2[9 ] = m1[6 ];
+  m2[10] = m1[10];
+  m2[11] = m1[14];
+
+  m2[12] = m1[3 ];
+  m2[13] = m1[7 ];
+  m2[14] = m1[11];
+  m2[15] = m1[15];
+}
 
 void transform33Tf3f (float *m1, float *m2, float *m3) 
 {
@@ -1292,7 +1314,7 @@ static void normalize3dp( double *v1, double *v2, double *v3 )
 		v3[2]=_0;
 	 }
 } 
-
+/* unused at present
 static void normalize3df( float *v1, float *v2, float *v3 )
 {
   float vlen = (float)sqrt1f((v1[0]*v1[0]) + 
@@ -1311,7 +1333,7 @@ static void normalize3df( float *v1, float *v2, float *v3 )
       v3[2]=_0;
     }
 } 
-
+*/
 void scale3d ( double *v1,double v0,double *v2)
 {
   v2[0]=v1[0]*v0;
@@ -1717,8 +1739,6 @@ void normalize3d( double *v1 )
 	 }
 } 
 
-
-
 double length3d ( double *v1 )
 {
   return(sqrt1d((v1[0]*v1[0]) + 
@@ -1735,18 +1755,17 @@ double slow_diff3f ( float *v1, float *v2 )
   return(sqrt1d(dx*dx + dy*dy + dz*dz));
 }
 
-double slow_diffsq3f ( float *v1, float *v2 )
+float slow_diffsq3f ( float *v1, float *v2 )
 {
-  register double dx,dy,dz;
+  register float dx,dy,dz;
   dx = (v1[0]-v2[0]);
   dy = (v1[1]-v2[1]);
   dz = (v1[2]-v2[2]);
 
-  return( dx*dx + dy*dy + dz*dz );
+  return ( dx*dx + dy*dy + dz*dz );
 
 }
 
-
 int slow_within3f(float *v1,float *v2,float dist)
 {
   register float dx,dy,dz;
