@@ -77,7 +77,7 @@ void add3d ( double *v1, double *v0, double *v2);
 double distance_line2point3f(float *base,float *normal,float *point,float *alongNormalSq);
 double distance_halfline2point3f(float *base,float *normal,float *point,float *alongNormalSq);
 
-double slow_diffsq3f ( float *v1, float *v2 );
+float slow_diffsq3f ( float *v1, float *v2 );
 double slow_diff3f ( float *v1, float *v2 );
 int slow_within3f(float *v1,float *v2,float dist);
 int slow_within3fsq(float *v1,float *v2,float dist,float dist2);
@@ -128,6 +128,8 @@ void copy3f3d ( float *v1,double *v2);
 
 void transpose33f33f ( float  *m1, float  *m2);
 void transpose44f44f ( float  *m1, float  *m2);
+void transpose44d44d ( double  *m1, double  *m2);
+
 void transform33f3f ( float  *m1, float  *m2,  float  *m3 );
 void transform33Tf3f ( float  *m1, float  *m2,  float  *m3 ); /* uses transpose */
 
@@ -335,15 +337,15 @@ __inline__ static double inline_diff3f ( float *v1, float *v2 )
   return(sqrt1d(dx*dx + dy*dy + dz*dz));
 }
 
-__inline__ static double inline_diffsq3f ( float *v1, float *v2 )
+__inline__ static float inline_diffsq3f ( float *v1, float *v2 )
 {
-  register double dx,dy,dz;
+  register float dx,dy,dz;
   dx = (v1[0]-v2[0]);
   dy = (v1[1]-v2[1]);
   dx = dx * dx;
   dz = (v1[2]-v2[2]);
   dy = dy*dy;
-  return( dz*dz + (dx + dy) );
+  return ( dz*dz + (dx + dy) );
 }
 
 __inline__ static int inline_within3f(float *v1,float *v2,float dist)
