@@ -1,5 +1,9 @@
 #ifndef _PyMOL_VERSION
-#define _PyMOL_VERSION "1.0r1"
+#ifndef PYMOL_EVAL
+#define _PyMOL_VERSION "1.1r2pre"
+#else
+#define _PyMOL_VERSION "1.1eval"
+#endif
 #endif
 
 #ifndef _PYMOL_1_x
@@ -7,13 +11,13 @@
 #endif
 
 #ifndef _PyMOL_VERSION_double
-#define _PyMOL_VERSION_double 1.00
+#define _PyMOL_VERSION_double 1.10
 #endif
 
 /* for session file compatibility */
 
 #ifndef _PyMOL_VERSION_int 
-#define _PyMOL_VERSION_int 100
+#define _PyMOL_VERSION_int 110
 #endif
 
 
