@@ -67,6 +67,46 @@ static void WordMatcherDump(CWordMatcher *I)
 }
 #endif
 
+#ifndef _PYMOL_INLINE
+int WordCompare(PyMOLGlobals *G,char *p,char *q,int ignCase) 
+/* all things equal, shorter is smaller */
+{
+  int result=0;
+  register char cp,cq,tlp,tlq;
+  if(ignCase) {
+    while((cp=*p)&&(cq=*q))	{
+      p++;
+      q++;
+      if(cp!=cq) {
+        (tlp=tolower(cp));
+	(tlq=tolower(cq));
+	if(tlp<tlq) 
+          return -1;
+        else if(tlp>tlq) {
+          return 1;
+        }
+      }
+    }
+  } else {
+    while((cp=*p)&&(cq=*q))	{
+      p++;
+      q++;
+      if(cp!=cq) {
+        if(cp<cq) {
+          return -1;
+        } else if(cp>cq) {
+          return 1;
+        }
+      }
+    }
+  }
+  if((!result)&&(!*p)&&(*q))
+    return -1;
+  else if((!result)&&(*p)&&(!*q))
+    return 1;
+  return 0;
+}
+#endif
 
 void WordMatchOptionsConfigInteger(CWordMatchOptions *I)
 {
@@ -75,6 +115,8 @@ void WordMatchOptionsConfigInteger(CWordMatchOptions *I)
   I->ignore_case = true;
   I->wildcard = 0; /* no wildcard for numbers */
   I->allow_hyphen = true;
+  I->allow_plus = true;
+  I->space_lists = false;
 }
 
 void WordMatchOptionsConfigAlpha(CWordMatchOptions *I, char wildcard, int ignore_case)
@@ -84,6 +126,19 @@ void WordMatchOptionsConfigAlpha(CWordMatchOptions *I, char wildcard, int ignore
   I->ignore_case = ignore_case;
   I->wildcard = wildcard;
   I->allow_hyphen = false;
+  I->allow_plus = false;
+  I->space_lists = false;
+}
+
+void WordMatchOptionsConfigAlphaList(CWordMatchOptions *I, char wildcard, int ignore_case)
+{ /* here we expect '+' to be used in lists */
+  I->range_mode = cWordMatchOptionAlphaRanges;
+  I->lists = true;
+  I->ignore_case = ignore_case;
+  I->wildcard = wildcard;
+  I->allow_hyphen = false;
+  I->allow_plus = true;
+  I->space_lists = false;
 }
 
 void WordMatchOptionsConfigMixed(CWordMatchOptions *I, char wildcard, int ignore_case )
@@ -93,6 +148,19 @@ void WordMatchOptionsConfigMixed(CWordMatchOptions *I, char wildcard, int ignore
   I->ignore_case = ignore_case;
   I->wildcard = wildcard; 
   I->allow_hyphen = true;
+  I->allow_plus = true;
+  I->space_lists = false;
+}
+
+void WordMatchOptionsConfigNameList(CWordMatchOptions *I, char wildcard, int ignore_case)
+{
+  I->range_mode = cWordMatchOptionAlphaRanges;
+  I->lists = true;
+  I->ignore_case = ignore_case;
+  I->wildcard = wildcard;
+  I->allow_hyphen = false;
+  I->allow_plus = false;
+  I->space_lists = true;
 }
 
 CWordMatcher *WordMatcherNew(PyMOLGlobals *G, char *st, CWordMatchOptions *option,int force)
@@ -116,8 +184,10 @@ CWordMatcher *WordMatcherNew(PyMOLGlobals *G, char *st, CWordMatchOptions *optio
           escape=true;
           needed=true;
           break;
-        case ',': /* list operators */
         case '+':
+          if((option->lists)&&(option->allow_plus))
+            needed=true;
+        case ',': /* list operators */
           if(option->lists)
             needed=true;
           break;
@@ -129,6 +199,10 @@ CWordMatcher *WordMatcherNew(PyMOLGlobals *G, char *st, CWordMatchOptions *optio
           if(option->range_mode)
             needed=true;
           break;
+        case ' ':
+          if(option->space_lists)
+            needed=true;
+          break;
         default:
           if(*p == wildcard)
             needed=true;
@@ -174,8 +248,20 @@ CWordMatcher *WordMatcherNew(PyMOLGlobals *G, char *st, CWordMatchOptions *optio
               token_active = false;
             }
             break;
-          case '+':
-          case ',': /* list operators */
+          case '+': /* list operator */
+            if(option->lists&&option->allow_plus) {
+              if(n_node<expectation) { /* create empty node */
+                VLACheck(I->node, MatchNode, n_node);  
+                n_node++;
+              } else {
+                expectation = n_node+1;
+              }
+              char_handled = true;
+              node_active = false;
+              token_active = false;
+            }
+            break;
+          case ',': /* list operator */
             if(option->lists) {
               if(n_node<expectation) { /* create empty node */
                 VLACheck(I->node, MatchNode, n_node);  
@@ -188,6 +274,19 @@ CWordMatcher *WordMatcherNew(PyMOLGlobals *G, char *st, CWordMatchOptions *optio
               token_active = false;
             }
             break;
+          case ' ': /* space list */
+            if(option->space_lists) {
+              if(n_node<expectation) { /* create empty node */
+                VLACheck(I->node, MatchNode, n_node);  
+                n_node++;
+              } else {
+                expectation = n_node+1;
+              }
+              char_handled = true;
+              node_active = false;
+              token_active = false;
+            }
+            break;
           case '-': /* range operators */
             if(option->allow_hyphen && option->range_mode) {
               if(!node_active) {
@@ -404,12 +503,14 @@ int WordMatcherMatchAlpha(CWordMatcher *I, char *text)
   register MatchNode *cur_node = I->node;
   register int n_node = I->n_node;
   
-  while(n_node--) {
+  while((n_node--)>0) {
     if(recursive_match(I, cur_node, text, NULL))
       return true;
     else {
-      while(cur_node->continued)
+      while(cur_node->continued) {
         cur_node++;
+        n_node--;
+      }
       cur_node++;
     }
   }
@@ -421,12 +522,14 @@ int WordMatcherMatchMixed(CWordMatcher *I, char *text,int value)
   register MatchNode *cur_node = I->node;
   register int n_node = I->n_node;
   
-  while(n_node--) {
+  while((n_node--)>0) {
     if(recursive_match(I, cur_node, text, &value))
       return true;
     else {
-      while(cur_node->continued)
+      while(cur_node->continued) {
         cur_node++;
+        n_node--;
+      }
       cur_node++;
     }
   }
@@ -456,12 +559,14 @@ int WordMatcherMatchInteger(CWordMatcher *I,int value)
   register MatchNode *cur_node = I->node;
   register int n_node = I->n_node;
   
-  while(n_node--) {
+  while((n_node--)>0) {
     if(integer_match(I, cur_node, value))
       return true;
     else {
-      while(cur_node->continued)
+      while(cur_node->continued) {
         cur_node++;
+        n_node--;
+      }
       cur_node++;
     }
   }
@@ -547,6 +652,19 @@ void WordListDump(CWordList *I,char *prefix)
   }
 }
 
+int WordListIterate(PyMOLGlobals *G,CWordList *I,char **ptr, int *hidden)
+{
+  int result = true;
+  if(*hidden>=0) {
+    if(*hidden<I->n_word) {
+      (*ptr)=I->start[(*hidden)++];
+    } else {
+      result=false;
+    }
+  }
+  return result;
+}
+
 int WordListMatch(PyMOLGlobals *G,CWordList *I,char *name, int ignore_case)
 {
   int result = -1;
@@ -613,7 +731,7 @@ int WordMatchExact(PyMOLGlobals *G,char *p,char *q,int ignCase)
   return 1;
 }
 
-static int WordMatchNoWild(PyMOLGlobals *G,char *p,char *q,int ignCase) 
+int WordMatchNoWild(PyMOLGlobals *G,char *p,char *q,int ignCase) 
 /* allows for p to match when shorter than q.
 
 Returns:
@@ -864,43 +982,6 @@ int WordMatchCommaInt(PyMOLGlobals *G,char *p,int number)
   return(WordMatchComma(G,p,buffer,1));
 }
 
-int WordCompare(PyMOLGlobals *G,char *p,char *q,int ignCase) 
-/* all things equal, shorter is smaller */
-{
-  int result=0;
-  if(ignCase) {
-    while((*p)&&(*q))	{
-      if(*p!=*q) {
-        if(tolower(*p)<tolower(*q)) {
-          return -1;
-        }
-        else if(tolower(*p)>tolower(*q)) {
-          return 1;
-        }
-      }
-      p++;
-      q++;
-    }
-  } else {
-    while((*p)&&(*q))	{
-      if(*p!=*q) {
-        if(*p<*q) {
-          return -1;
-        } else if(*p>*q) {
-          return 1;
-        }
-      }
-      p++;
-      q++;
-    }
-  }
-  
-  if((!result)&&(!*p)&&(*q))
-    return -1;
-  else if((!result)&&(*p)&&(!*q))
-    return 1;
-  return 0;
-}
 
 int WordIndex(PyMOLGlobals *G,WordType *list,char *word,int minMatch,int ignCase)
 {
