@@ -16,11 +16,17 @@ Z* -------------------------------------------------------------------
 #ifndef _H_os_python
 #define _H_os_python
 
+#include "os_predef.h"
+
 #ifdef PYMOL_ICC_LINUX
 #include"/usr/include/bits/types.h" 
 #endif
 
+#ifdef _PYMOL_NOPY
+typedef int PyObject;
+#else
 #include"Python.h"
+#endif
 
 #endif
 
