@@ -41,9 +41,10 @@ Z* -------------------------------------------------------------------
 
 #define cControlMinWidth 5
 
+#define SDOF_QUEUE_MASK 0x1F
+
 struct _CControl {
   Block *Block;
-  int Rocking;
   int DragFlag;
   int LastPos;
   int ExtraSpace;
@@ -54,12 +55,130 @@ struct _CControl {
   double LastClickTime;
   int SkipRelease;
   int NButton;
+
+  /* not saved */
+
+  int sdofActive;
+  double sdofLastIterTime;
+  float sdofTrans[3];
+  float sdofRot[3];
+  unsigned int sdofWroteTo, sdofReadFrom; /* queue synchronization fields */
+  float sdofBuffer[(SDOF_QUEUE_MASK+1)*6];
 };
 
+int ControlSdofUpdate(PyMOLGlobals *G, float tx,float ty, float tz, float rx, float ry, float rz)
+{ 
+  /* may be called asynchronously anytime after CControl has been initialized */
+
+  CControl *I=G->Control;
+  if(I) {
+    if(((I->sdofWroteTo - I->sdofReadFrom) & SDOF_QUEUE_MASK) < SDOF_QUEUE_MASK) { 
+      /* a free slot exists */
+      int slot = (I->sdofWroteTo + 1) & SDOF_QUEUE_MASK;
+      float *buffer = I->sdofBuffer + (6*slot);
+
+      buffer[0] = tx;
+      buffer[1] = ty;
+      buffer[2] = tz;
+      buffer[3] = rx;
+      buffer[4] = ry;
+      buffer[5] = rz;
+      
+      I->sdofWroteTo = slot;
+      
+      {
+        float tol = 0.0001;
+        int active = (fabs(buffer[0])>=tol) || (fabs(buffer[1])>=tol) || (fabs(buffer[2])>=tol)
+          || (fabs(buffer[3])>=tol) || (fabs(buffer[4])>=tol) || (fabs(buffer[5])>=tol);
+        if(active && !I->sdofActive) {
+          I->sdofLastIterTime = UtilGetSeconds(G);
+        }
+        I->sdofActive = active;
+      }
+      /*printf("wrote %8.3f %8.3f %8.3f %8.3f %8.3f %8.3f %d %d %d\n",tx,ty,tz,rx,ry,rz,I->sdofReadFrom,I->sdofWroteTo,slot);*/
+    }
+  }
+  return 1;
+ }
+
+int ControlSdofIterate(PyMOLGlobals *G)
+{
+  CControl *I=G->Control;
+  if(I->sdofWroteTo != I->sdofReadFrom) {
+    int slot = I->sdofWroteTo;
+
+    /* new data available */
+    
+    float *buffer = I->sdofBuffer + (6*slot);
+    
+    I->sdofTrans[0] = buffer[0];
+    I->sdofTrans[1] = buffer[1];
+    I->sdofTrans[2] = buffer[2];
+    I->sdofRot[0] = buffer[3];
+    I->sdofRot[1] = buffer[4];
+    I->sdofRot[2] = buffer[5];
+
+    I->sdofReadFrom = slot;
+  }
+  
+
+  if(I->sdofActive) {
+    double now = UtilGetSeconds(G);
+    double delta = now - I->sdofLastIterTime;  
+    I->sdofLastIterTime = now;
+	
+    {
+      /* suppress small amounts of combined motion using a truncated switching function */
+
+      float len_rot = length3f(I->sdofRot);
+      float len_trans = length3f(I->sdofTrans);
+      float *dom,*sub;
+      if(len_rot>len_trans) {
+        dom = &len_rot;
+        sub = &len_trans;
+      } else {
+        dom = &len_trans;
+        sub = &len_rot;
+      }
+
+      {
+        float expo = 2.0F;
+        float trnc = 0.05F;
+        float sub_fxn = (*sub)/(*dom);
+        if(sub_fxn< trnc) {
+          sub_fxn = 0.0F;
+        } else if(sub_fxn<0.5F) {
+          sub_fxn = (sub_fxn-trnc)/(0.5F-trnc);
+          sub_fxn = (float)pow(sub_fxn,expo);
+        } else {
+          sub_fxn = 1.0F - (float)pow(1.0F - sub_fxn,expo);
+        }
+        *dom = 1.0F;
+        *sub = sub_fxn;
+        scale3f(I->sdofTrans,len_trans,I->sdofTrans);
+        scale3f(I->sdofRot,len_rot,I->sdofRot);
+      }
+    }
+    /* translate */
+    SceneTranslateScaled(G,
+                         delta * I->sdofTrans[0],
+                         -delta * I->sdofTrans[1],
+                         -delta * I->sdofTrans[2]);
+
+    /* rotate */
+    SceneRotateScaled(G,
+                       2.0F * delta * I->sdofRot[0],
+                      -2.0F * delta * I->sdofRot[1],
+                      -2.0F * delta * I->sdofRot[2]);
+  
+    SceneDirty(G);
+	}
+return 1;
+ }
+
 int ControlRocking(PyMOLGlobals *G)
 {
-  register CControl *I=G->Control;
-  return I->Rocking;
+  return SettingGetGlobal_b(G,cSetting_rock);
 }
 
 static void ControlReshape(Block *block,int width, int height)
@@ -139,7 +258,7 @@ static int ControlRelease(Block *block,int button,int x,int y,int mod)
   case 2:
     MoviePlay(G,cMovieStop);
     if(SettingGet(G,cSetting_sculpting)) SettingSet(G,cSetting_sculpting,0);
-    if(I->Rocking) I->Rocking=false;
+    if(SettingGetGlobal_b(G,cSetting_rock)) SettingSetGlobal_b(G,cSetting_rock,false);
     ExecutiveDrawNow(G);
     OrthoDirty(G);
     PLog(G,"cmd.mstop()",cPLog_pym);
@@ -188,10 +307,11 @@ static int ControlRelease(Block *block,int button,int x,int y,int mod)
     OrthoDirty(G);
     break;
   case 7:
-    I->Rocking=!I->Rocking;
-    if(I->Rocking)
+    SettingSetGlobal_b(G,cSetting_rock,!SettingGetGlobal_b(G,cSetting_rock));
+    if(SettingGetGlobal_b(G,cSetting_rock)) {
+      SceneRestartSweepTimer(G);
       PLog(G,"cmd.rock(1)",cPLog_pym);
-    else
+    } else
       PLog(G,"cmd.rock(0)",cPLog_pym);
     SceneRestartFrameTimer(G);
     OrthoDirty(G);
@@ -219,8 +339,11 @@ Block *ControlGetBlock(PyMOLGlobals *G)
 /*========================================================================*/
 int ControlIdling(PyMOLGlobals *G)
 {
-  register CControl *I=G->Control;
-  return(MoviePlaying(G)||I->Rocking||SettingGet(G,cSetting_sculpting));
+ CControl *I=G->Control;
+ return(I->sdofActive||
+        MoviePlaying(G)||
+        SettingGetGlobal_b(G,cSetting_rock)||
+        SettingGet(G,cSetting_sculpting));
 }
 /*========================================================================*/
 void ControlInterrupt(PyMOLGlobals *G)
@@ -239,25 +362,28 @@ void ControlFree(PyMOLGlobals *G)
 /*========================================================================*/
 int ControlRock(PyMOLGlobals *G,int mode)
 {
-  register CControl *I=G->Control;
   switch(mode) {
   case -2: 
     break;
   case -1:
-	I->Rocking=!I->Rocking;
+    SettingSetGlobal_b(G,cSetting_rock,!SettingGetGlobal_b(G,cSetting_rock));
+    if(SettingGetGlobal_b(G,cSetting_rock)) {
+      SceneRestartSweepTimer(G);
+    }
 	break;
   case 0:
-	I->Rocking=false;
+	SettingSetGlobal_b(G,cSetting_rock,false);
 	break;
   case 1:
-	I->Rocking=true;
+	SettingSetGlobal_b(G,cSetting_rock,true);
+    SceneRestartSweepTimer(G);
 	break;
   }
   if(mode!=-2) {
     SceneRestartFrameTimer(G);
     OrthoDirty(G);
   }
-  return I->Rocking;
+  return SettingGetGlobal_b(G,cSetting_rock);
 }
 
 /*========================================================================*/
@@ -400,7 +526,7 @@ static void ControlDraw(Block *block)
                     but_width, but_height, lightEdge,darkEdge,pushed);
       } else if(((but_num==6)&&((int)SettingGet(G,cSetting_seq_view))) ||
                 ((but_num==3)&&(MoviePlaying(G))) ||
-                ((but_num==7)&&(I->Rocking))||
+                ((but_num==7)&&(SettingGetGlobal_b(G,cSetting_rock))) ||
                 ((but_num==8)&&(SettingGetGlobal_b(G,cSetting_full_screen)))) {
         draw_button(but_left,but_bottom,
                     but_width, but_height, lightEdge,darkEdge,I->ActiveColor);
@@ -538,11 +664,9 @@ int ControlInit(PyMOLGlobals *G)
     I->Active = -1;
     OrthoAttach(G,I->Block,cOrthoTool);
     I->SaveWidth = 0;
-    I->Rocking=false;
     I->LastClickTime = UtilGetSeconds(G);
     I->NButton=9;
     return 1;
   } else 
     return 0;
-
 }
