@@ -38,6 +38,8 @@ static float smooth(float x,float power)
   }
 }
 
+#define CopyArray(dst,src,type,count) memcpy(dst,src,sizeof(type)*(count))
+
 CExtrude *ExtrudeCopyPointsNormalsColors(CExtrude *orig)
 {
   OOAlloc(orig->G,CExtrude);
@@ -94,7 +96,8 @@ void ExtrudeCircle(CExtrude *I, int n,float size)
   I->tv = Alloc(float,3*(n+1));
   I->tn = Alloc(float,3*(n+1));
   I->Ns = n;
-  
+  I->r = size;
+
   v = I->sv;
   vn = I->sn;
 
@@ -668,7 +671,7 @@ void ExtrudeCGOSurfaceTube(CExtrude *I,CGO *cgo,int cap,float *color_override)
           CGOColorv(cgo,color_override);
         else
           CGOColorv(cgo,c);
-        CGOPickColor(cgo,*i,-1);
+        CGOPickColor(cgo,*i,cPickableAtom);
         CGONormalv(cgo,tn);
         CGOVertexv(cgo,tv);
         tn+=3;
@@ -687,8 +690,9 @@ void ExtrudeCGOSurfaceTube(CExtrude *I,CGO *cgo,int cap,float *color_override)
       CGOEnable(cgo,GL_LIGHTING);
     }
     
-    if(cap) {
-
+    switch(cap) {
+    case 1:
+      
       n = I->n;
       v = I->p;
 
@@ -708,7 +712,7 @@ void ExtrudeCGOSurfaceTube(CExtrude *I,CGO *cgo,int cap,float *color_override)
         CGOColorv(cgo,color_override);
       else
         CGOColorv(cgo,I->c);
-      CGOPickColor(cgo,I->i[0],-1);
+      CGOPickColor(cgo,I->i[0],cPickableAtom);
       CGONormalv(cgo,v0);
       CGOVertexv(cgo,v);
       /* trace shape */
@@ -735,7 +739,7 @@ void ExtrudeCGOSurfaceTube(CExtrude *I,CGO *cgo,int cap,float *color_override)
         CGOColorv(cgo,color_override);
       else
         CGOColorv(cgo,I->c+3*(I->N-1));
-      CGOPickColor(cgo,I->i[I->N-1],-1);
+      CGOPickColor(cgo,I->i[I->N-1],cPickableAtom);
       CGONormalv(cgo,n);
       CGOVertexv(cgo,v);
       /* trace shape */
@@ -744,7 +748,26 @@ void ExtrudeCGOSurfaceTube(CExtrude *I,CGO *cgo,int cap,float *color_override)
       }
       CGOVertexv(cgo,I->tv);
       CGOEnd(cgo);
-      
+      break;
+    case 2:
+      {
+        float factor = (float) cos(0.75*PI/I->Ns);
+        if(color_override)
+          CGOColorv(cgo,color_override);
+        else
+          CGOColorv(cgo,I->c);
+        CGOPickColor(cgo,I->i[0],cPickableAtom);
+        v = I->p;
+        CGOSphere(cgo,v,I->r*factor);
+        v = I->p+3*(I->N-1);
+        if(color_override)
+          CGOColorv(cgo,color_override);
+        else
+          CGOColorv(cgo,I->c+3*(I->N-1));
+        CGOPickColor(cgo,I->i[I->N-1],cPickableAtom);
+        CGOSphere(cgo,v,I->r*factor); 
+      }
+      break;
     }
     FreeP(TV);
     FreeP(TN);
@@ -897,7 +920,7 @@ void ExtrudeCGOSurfaceVariableTube(CExtrude *I,CGO *cgo,int cap)
       i = I->i;
       for(a=0;a<I->N;a++) {
         CGOColorv(cgo,c);
-        CGOPickColor(cgo,*i,-1);
+        CGOPickColor(cgo,*i,cPickableAtom);
         CGONormalv(cgo,tn);
         CGOVertexv(cgo,tv);
         tn+=3;
@@ -980,7 +1003,7 @@ void ExtrudeCGOSurfaceVariableTube(CExtrude *I,CGO *cgo,int cap)
       copy3f(I->n,v0);
       invert3f(v0);
       CGOColorv(cgo,I->c);
-      CGOPickColor(cgo,I->i[0],-1);
+      CGOPickColor(cgo,I->i[0],cPickableAtom);
       CGONormalv(cgo,v0);
       CGOVertexv(cgo,v);
       /* trace shape */
@@ -1010,7 +1033,7 @@ void ExtrudeCGOSurfaceVariableTube(CExtrude *I,CGO *cgo,int cap)
 
       CGOBegin(cgo,GL_TRIANGLE_FAN);
       CGOColorv(cgo,I->c+3*(I->N-1));
-      CGOPickColor(cgo,I->i[I->N-1],-1);
+      CGOPickColor(cgo,I->i[I->N-1],cPickableAtom);
       CGONormalv(cgo,n);
       CGOVertexv(cgo,v);
       /* trace shape */
@@ -1103,7 +1126,7 @@ void ExtrudeCGOSurfacePolygon(CExtrude *I,CGO *cgo,int cap,float *color_override
       for(a=0;a<I->N;a++) {
         if(!color_override)
           CGOColorv(cgo,c);
-        CGOPickColor(cgo,*i,-1);
+        CGOPickColor(cgo,*i,cPickableAtom);
         CGONormalv(cgo,tn);
         CGOVertexv(cgo,tv);
         tn+=3;
@@ -1147,7 +1170,7 @@ void ExtrudeCGOSurfacePolygon(CExtrude *I,CGO *cgo,int cap,float *color_override
       invert3f(v0);
       if(!color_override)
         CGOColorv(cgo,I->c);
-      CGOPickColor(cgo,I->i[0],-1);
+      CGOPickColor(cgo,I->i[0],cPickableAtom);
       CGONormalv(cgo,v0);
       CGOVertexv(cgo,v);
       /* trace shape */
@@ -1171,7 +1194,7 @@ void ExtrudeCGOSurfacePolygon(CExtrude *I,CGO *cgo,int cap,float *color_override
       CGOBegin(cgo,GL_TRIANGLE_FAN);
       if(!color_override)
         CGOColorv(cgo,I->c+3*(I->N-1));
-      CGOPickColor(cgo,I->i[I->N-1],-1);
+      CGOPickColor(cgo,I->i[I->N-1],cPickableAtom);
       CGONormalv(cgo,n);
       CGOVertexv(cgo,v);
       /* trace shape */
@@ -1288,7 +1311,7 @@ void ExtrudeCGOSurfacePolygonTaper(CExtrude *I,CGO *cgo,int sampling,float *colo
       for(a=0;a<I->N;a++) {
         if(!color_override)
           CGOColorv(cgo,c);
-        CGOPickColor(cgo,*i,-1);
+        CGOPickColor(cgo,*i,cPickableAtom);
         CGONormalv(cgo,tn);
         CGOVertexv(cgo,tv);
         tn+=3;
@@ -1402,7 +1425,7 @@ void ExtrudeCGOSurfaceStrand(CExtrude *I,CGO *cgo,int sampling,float *color_over
             CGOColorv(cgo,color_override);
           else
             CGOColorv(cgo,c);
-          CGOPickColor(cgo,*i,-1);
+          CGOPickColor(cgo,*i,cPickableAtom);
           CGONormalv(cgo,tn);
           CGOVertexv(cgo,tv);
         }
@@ -1448,7 +1471,7 @@ void ExtrudeCGOSurfaceStrand(CExtrude *I,CGO *cgo,int sampling,float *color_over
         CGOColorv(cgo,color_override);
       else
         CGOColorv(cgo,I->c);
-      CGOPickColor(cgo,I->i[0],-1);
+      CGOPickColor(cgo,I->i[0],cPickableAtom);
       CGONormalv(cgo,v0);
       CGOVertexv(cgo,v);
       /* trace shape */
@@ -1515,7 +1538,7 @@ void ExtrudeCGOSurfaceStrand(CExtrude *I,CGO *cgo,int sampling,float *color_over
             CGOColorv(cgo,color_override);
           else
             CGOColorv(cgo,c);
-          CGOPickColor(cgo,*i,-1);
+          CGOPickColor(cgo,*i,cPickableAtom);
           CGONormalv(cgo,tn);
           CGOVertexv(cgo,tv);
         }
@@ -1559,7 +1582,7 @@ void ExtrudeCGOSurfaceStrand(CExtrude *I,CGO *cgo,int sampling,float *color_over
       CGOColorv(cgo,color_override);
     else
       CGOColorv(cgo,I->c+3*(subN-1));
-    CGOPickColor(cgo,I->i[(subN-1)],-1);
+    CGOPickColor(cgo,I->i[(subN-1)],cPickableAtom);
     CGONormalv(cgo,v0);
     CGOVertexv(cgo,v);
 
@@ -1581,16 +1604,20 @@ void ExtrudeCGOSurfaceStrand(CExtrude *I,CGO *cgo,int sampling,float *color_over
 
 }
 
-void ExtrudeComputeScaleFactors(CExtrude *I,ObjectMolecule *obj,int source_field,
-                                float mean, float stdev, float power, float range,
-                                float min_scale, float max_scale,
-                                int window)
+void ExtrudeComputePuttyScaleFactors(CExtrude *I,ObjectMolecule *obj,int transform,
+                                     float mean, float stdev, float min, float max, 
+                                     float power, float range,
+                                     float min_scale, float max_scale,
+                                     int window)
 {
   float *sf;
   int a;
   int *i;
   AtomInfoType *at;
   float scale;
+  float data_range = max - min;
+
+  if(data_range==0.0F) data_range = 1.0F;
 
   if(I->N&&I->Ns) {
 
@@ -1601,20 +1628,63 @@ void ExtrudeComputeScaleFactors(CExtrude *I,ObjectMolecule *obj,int source_field
       for(a=0;a<I->N;a++) {
         at = obj->AtomInfo + (*i);
         
-        switch(source_field) {
-        default: /* b*/
+        switch(transform) {
+        case cPuttyTransformNormalizedNonlinear:  
+          /* normalized by Z-score, with the range affecting the distribution width */
           scale = (range+(at->b - mean)/stdev)/range;
           if(scale<0.0F)
             scale = 0.0F;
           scale=(float)pow(scale,power);
-          if(scale<min_scale)
-            scale=min_scale;
-          if(scale>max_scale)
-            scale=max_scale;
+          break;
+        case cPuttyTransformRelativeNonlinear: 
+          scale = (at->b - min) / (data_range * range);
+          if(scale<0.0F) scale = 0.0F;
+          scale=(float)pow(scale,power);
           *sf = scale;
           break;
+        case cPuttyTransformScaledNonlinear: 
+          scale = at->b / range;
+          if(scale<0.0F) scale = 0.0F;
+          scale=(float)pow(scale,power);
+          *sf = scale;
+          break;
+        case cPuttyTransformAbsoluteNonlinear: 
+          scale = at->b;
+          if(scale<0.0F) scale = 0.0F;
+          scale=(float)pow(scale,power);
+          *sf = scale;
+          break;
+        case cPuttyTransformNormalizedLinear:  
+          /* normalized by Z-score, with the range affecting the distribution width */
+          scale = (range+(at->b - mean)/stdev)/range;
+          if(scale<0.0F)
+            scale = 0.0F;
+          break;
+        case cPuttyTransformRelativeLinear: 
+          scale = (at->b - min) / (data_range * range);
+          if(scale<0.0F) scale = 0.0F;
+          *sf = scale;
+          break;
+        case cPuttyTransformScaledLinear: 
+          scale = at->b / range;
+          if(scale<0.0F) scale = 0.0F;
+          *sf = scale;
+          break;
+        case cPuttyTransformAbsoluteLinear: 
+          scale = at->b;
+          if(scale<0.0F) scale = 0.0F;
+          *sf = scale;
+          break;
+        case cPuttyTransformImpliedRMS:
+          if(scale<0.0F) scale = 0.0F;
+          scale = (float)(sqrt1d(at->b/8.0)/PI);
+          break;
         }
-        sf++;
+        if(scale<min_scale)
+          scale=min_scale;
+        if((scale>max_scale) && (max_scale>=0.0)) 
+          scale=max_scale;
+        *(sf++) = scale;
         i++;
       }
     } else {
