@@ -36,8 +36,8 @@ typedef struct {
 __inline__ 
 #endif
 static char *_FontTypeRenderOpenGL(RenderInfo *info, 
-                                              CFontType *I,char *st,
-                                              float size,int flat, float *rpos)
+                                   CFontType *I,char *st,
+                                   float size,int flat, float *rpos)
 {
   register PyMOLGlobals *G = I->Font.G;
   if(G->ValidContext) {
@@ -149,7 +149,13 @@ static char *_FontTypeRenderOpenGL(RenderInfo *info,
         float loc[3];
         float zero[3]= {0.0F,0.0F,0.0F};
         if(rpos) {
-          SceneGetEyeNormal(G,v,loc);
+          if(info->ortho) {
+            float orig[3];
+            SceneOriginGet(G,orig);
+            SceneGetEyeNormal(G,orig,loc);
+          } else {
+            SceneGetEyeNormal(G,v,loc);
+          }
           scale3f(loc,z_indent,loc);
           add3f(v,loc,loc);
           v = loc;
@@ -160,6 +166,7 @@ static char *_FontTypeRenderOpenGL(RenderInfo *info,
       if(rpos) {
         TextIndent(G,x_indent,y_indent);
       }
+      CharacterRenderOpenGLPrime(G,info);
       while((c=*(st++))) {
         if(unicnt) {
           if(!(c&0x80)) /* corrupt UTF8 */
@@ -207,6 +214,7 @@ static char *_FontTypeRenderOpenGL(RenderInfo *info,
           last_c = c;
         }
       }
+      CharacterRenderOpenGLDone(G,info);
       if(!pushed) {
         ScenePopRasterMatrix(G);
       }
@@ -254,7 +262,14 @@ static char *FontTypeRenderRay(CRay *ray, CFontType *I,char *st,float size, floa
       }
 
       v = TextGetPos(I->G);
-      SceneGetEyeNormal(G,v,loc);
+
+      if(ray->Ortho) {
+        float orig[3];
+        SceneOriginGet(G,orig);
+        SceneGetEyeNormal(G,orig,loc);
+      } else { 
+        SceneGetEyeNormal(G,v,loc);
+      }
       scale3f(loc,z_indent,loc);
       add3f(v,loc,loc);
       TextSetPos(I->G,loc);
