@@ -55,7 +55,8 @@ Z* -------------------------------------------------------------------
 #define cOrthoLeftMargin 3
 #define cOrthoBottomMargin 5
 
-#define WizardMargin 144
+#define WizardMargin1 144
+#define WizardMargin2 60
 
 #define ButModeMargin 20
 #define ControlMargin 0
@@ -97,7 +98,7 @@ struct _COrtho {
   int WrapXFlag;
   GLenum ActiveGLBuffer;
   double DrawTime, LastDraw;
-
+  int WrapClickSide; /* ugly kludge for finding click side in geowall stereo mode */
 };
 
 
@@ -120,18 +121,27 @@ void OrthoKeyAlt(PyMOLGlobals *G,unsigned char k);
 #define cWizardLeftMargin 15
 #define cWizardBorder 7
 
-static int get_wrap_x(int x, int *last_x, int width)
+static int get_wrap_x(int x, int *last_x, int width, int *click_side)
 {
   int width_2 = width/2;
   int width_3 = width/3;
   if(!last_x) {
-    if(x>width_2)
+    if(x>width_2) {
       x-=width_2;
+      if(click_side) *click_side = 1;
+    } else {
+      if(click_side) *click_side = -1;
+    }
   } else {
-    if((x-(*last_x))>width_3)
+    if((x-(*last_x))>width_3) {
       x-=width_2;
-    else if(((*last_x)-x)>width_3)
+      if(click_side) *click_side = 1;
+    } else if(((*last_x)-x)>width_3) {
       x+=width_2;
+      if(click_side) *click_side = 1;
+    } else {
+      if(click_side) *click_side = -1;
+    }
   }
   return x;
 }
@@ -296,7 +306,7 @@ int OrthoTextVisible(PyMOLGlobals *G) {
 int OrthoArrowsGrabbed(PyMOLGlobals *G)
 {
   register COrtho *I=G->Ortho;
-  return(I->CurChar>I->PromptChar&&OrthoTextVisible(G)); 
+  return((I->CurChar>I->PromptChar)&&OrthoTextVisible(G)); 
   /* arrows can't be grabbed if text isn't visible */
 }
 /*========================================================================*/
@@ -361,7 +371,7 @@ void OrthoDirty(PyMOLGlobals *G) {
     " OrthoDirty: called.\n"
     ENDFD;
   if(!I->DirtyFlag) {
-	 I->DirtyFlag = true;
+    I->DirtyFlag = true;
   }
 
   PyMOL_NeedRedisplay(G->PyMOL);
@@ -371,63 +381,63 @@ void OrthoBusyMessage(PyMOLGlobals *G,char *message)
 {
   register COrtho *I=G->Ortho;
   if(strlen(message)<255)
-	 strcpy(I->BusyMessage,message);
+    strcpy(I->BusyMessage,message);
 }
 /*========================================================================*/
 void OrthoBusySlow(PyMOLGlobals *G,int progress,int total)
 {
-	register COrtho *I=G->Ortho;
-    double   time_yet = (-I->BusyLastUpdate) + UtilGetSeconds(G);
+  register COrtho *I=G->Ortho;
+  double   time_yet = (-I->BusyLastUpdate) + UtilGetSeconds(G);
 
-	PRINTFD(G,FB_Ortho)
-		" OrthoBusySlow-DEBUG: progress %d total %d\n",progress,total
-		ENDFD;
-	I->BusyStatus[0]=progress;
-	I->BusyStatus[1]=total;
-	if(SettingGetGlobal_b(G,cSetting_show_progress)&&(time_yet>0.15F)) {
-		if(PyMOL_GetBusy(G->PyMOL,false)) { /* harmless race condition */
+  PRINTFD(G,FB_Ortho)
+    " OrthoBusySlow-DEBUG: progress %d total %d\n",progress,total
+    ENDFD;
+  I->BusyStatus[0]=progress;
+  I->BusyStatus[1]=total;
+  if(SettingGetGlobal_b(G,cSetting_show_progress)&&(time_yet>0.15F)) {
+    if(PyMOL_GetBusy(G->PyMOL,false)) { /* harmless race condition */
 #ifndef _PYMOL_NOPY
-			int blocked = PAutoBlock(G);
-			if(PLockStatusAttempt(G)) {
+      int blocked = PAutoBlock(G);
+      if(PLockStatusAttempt(G)) {
 #endif
-			PyMOL_SetProgress(G->PyMOL,PYMOL_PROGRESS_SLOW,progress,total);
-            I->BusyLastUpdate = UtilGetSeconds(G);
+        PyMOL_SetProgress(G->PyMOL,PYMOL_PROGRESS_SLOW,progress,total);
+        I->BusyLastUpdate = UtilGetSeconds(G);
 
 #ifndef _PYMOL_NOPY
-			PUnlockStatus(G);
-            }
-			PAutoUnblock(G,blocked);
+        PUnlockStatus(G);
+      }
+      PAutoUnblock(G,blocked);
 #endif
-		}
-	}
-	OrthoBusyDraw(G,false);
+    }
+    OrthoBusyDraw(G,false);
+  }
 }
 /*========================================================================*/
 void OrthoBusyFast(PyMOLGlobals *G,int progress,int total)
 {
-	register COrtho *I=G->Ortho;
-    double   time_yet = (-I->BusyLastUpdate) + UtilGetSeconds(G);
-	PRINTFD(G,FB_Ortho)
-		" OrthoBusyFast-DEBUG: progress %d total %d\n",progress,total
-		ENDFD;
-	I->BusyStatus[2]=progress;
-	I->BusyStatus[3]=total;
-	if(SettingGetGlobal_b(G,cSetting_show_progress)&&(time_yet>0.15F)) {
-		if(PyMOL_GetBusy(G->PyMOL,false)) { /* harmless race condition */
+  register COrtho *I=G->Ortho;
+  double   time_yet = (-I->BusyLastUpdate) + UtilGetSeconds(G);
+  PRINTFD(G,FB_Ortho)
+    " OrthoBusyFast-DEBUG: progress %d total %d\n",progress,total
+    ENDFD;
+  I->BusyStatus[2]=progress;
+  I->BusyStatus[3]=total;
+  if(SettingGetGlobal_b(G,cSetting_show_progress)&&(time_yet>0.15F)) {
+    if(PyMOL_GetBusy(G->PyMOL,false)) { /* harmless race condition */
 #ifndef _PYMOL_NOPY
-			int blocked = PAutoBlock(G);
-			if(PLockStatusAttempt(G)) {
+      int blocked = PAutoBlock(G);
+      if(PLockStatusAttempt(G)) {
 #endif
-			PyMOL_SetProgress(G->PyMOL,PYMOL_PROGRESS_FAST,progress,total);
-            I->BusyLastUpdate = UtilGetSeconds(G);
+        PyMOL_SetProgress(G->PyMOL,PYMOL_PROGRESS_FAST,progress,total);
+        I->BusyLastUpdate = UtilGetSeconds(G);
 #ifndef _PYMOL_NOPY
-			PUnlockStatus(G);
-            }
-			PAutoUnblock(G,blocked);
+        PUnlockStatus(G);
+      }
+      PAutoUnblock(G,blocked);
 #endif
-		}
-	}
-  OrthoBusyDraw(G,false);
+    }
+    OrthoBusyDraw(G,false);
+  }
 }
 /*========================================================================*/
 void OrthoBusyPrime(PyMOLGlobals *G)
@@ -435,7 +445,7 @@ void OrthoBusyPrime(PyMOLGlobals *G)
   register COrtho *I=G->Ortho;
   int a;
   for(a=0;a<4;a++)
-	 I->BusyStatus[a]=0;
+    I->BusyStatus[a]=0;
   I->BusyMessage[0]=0;
   I->BusyLast = UtilGetSeconds(G);
   I->BusyLastUpdate = UtilGetSeconds(G);
@@ -465,7 +475,7 @@ void OrthoBusyDraw(PyMOLGlobals *G,int force)
     if(PIsGlutThread()) {
 
 #ifdef _MACPYMOL_XCODE
-/* BEGIN PROPRIETARY CODE SEGMENT (see disclaimer in "os_proprietary.h") */ 
+      /* BEGIN PROPRIETARY CODE SEGMENT (see disclaimer in "os_proprietary.h") */ 
       float busyValue;
       if(I->BusyStatus[1]) {
         busyValue=(I->BusyStatus[0]*1.0F/I->BusyStatus[1]);
@@ -474,7 +484,7 @@ void OrthoBusyDraw(PyMOLGlobals *G,int force)
         busyValue=(I->BusyStatus[2]*1.0F/I->BusyStatus[3]);
       }
       MacPyMOLSetProgress(busyValue);
-/* END PROPRIETARY CODE SEGMENT */
+      /* END PROPRIETARY CODE SEGMENT */
 #else
       if(G->HaveGUI && G->ValidContext) {      
         char *c;
@@ -593,11 +603,11 @@ void OrthoRestorePrompt(PyMOLGlobals *G)
   register COrtho *I=G->Ortho;
   int curLine;
   if(!I->InputFlag) 
-	 {
-	 if(I->Saved[0]) 
+    {
+      if(I->Saved[0]) 
 		{
 		  if(I->CurChar) {
-			 OrthoNewLine(G,NULL,true);
+            OrthoNewLine(G,NULL,true);
 		  }
 		  curLine = I->CurLine&OrthoSaveLines;
 		  strcpy(I->Line[curLine],I->Saved);
@@ -605,19 +615,19 @@ void OrthoRestorePrompt(PyMOLGlobals *G)
 		  I->CurChar = I->SavedCC;
 		  I->PromptChar = I->SavedPC;
 		} 
-	 else 
+      else 
 		{
 		  if(I->CurChar) 
-			 OrthoNewLine(G,I->Prompt,true);
+            OrthoNewLine(G,I->Prompt,true);
 		  else
-			 {
-				curLine = I->CurLine&OrthoSaveLines;
-				strcpy(I->Line[curLine],I->Prompt);
-				I->CurChar = (I->PromptChar = strlen(I->Prompt));
-			 }
+            {
+              curLine = I->CurLine&OrthoSaveLines;
+              strcpy(I->Line[curLine],I->Prompt);
+              I->CurChar = (I->PromptChar = strlen(I->Prompt));
+            }
 		}
-	 I->InputFlag=1;
-	 }
+      I->InputFlag=1;
+    }
 }
 /*========================================================================*/
 void OrthoKeyControl(PyMOLGlobals *G,unsigned char k) {
@@ -626,6 +636,7 @@ void OrthoKeyControl(PyMOLGlobals *G,unsigned char k) {
   /* safer...*/
 
   sprintf(buffer,"cmd._ctrl(chr(%d))",k);
+  /* sprintf(buffer,"_ctrl %c",k); */
   PLog(G,buffer,cPLog_pym);
   PParse(G,buffer);
   PFlush(G);
@@ -643,12 +654,30 @@ void OrthoKeyAlt(PyMOLGlobals *G,unsigned char k) {
     OrthoKey(G,k,0,0,0);
   } else {
     sprintf(buffer,"cmd._alt(chr(%d))",k);
+    /* sprintf(buffer,"_alt %c",k); */
     PLog(G,buffer,cPLog_pym);
     PParse(G,buffer);
     PFlush(G);
   }
 
 }
+static int add_normal_char(COrtho *I,unsigned char k)
+{
+  char buffer[OrthoLineLength];
+  int curLine=I->CurLine&OrthoSaveLines;
+  if(I->CursorChar>=0) {
+    strcpy(buffer,I->Line[curLine]+I->CursorChar);
+    I->Line[curLine][I->CursorChar]=k;
+    I->CursorChar++;
+    I->CurChar++;
+    strcpy(I->Line[curLine]+I->CursorChar,buffer);
+  } else {
+    I->Line[curLine][I->CurChar]=k;
+    I->CurChar++;
+    I->Line[curLine][I->CurChar]=0;
+  }
+  return curLine;
+}
 /*========================================================================*/
 void OrthoKey(PyMOLGlobals *G,unsigned char k,int x,int y,int mod)
 {
@@ -661,11 +690,11 @@ void OrthoKey(PyMOLGlobals *G,unsigned char k,int x,int y,int mod)
     ENDFD;
     
   if(!I->InputFlag) 
-	 {
-	 if(I->Saved[0]) 
+    {
+      if(I->Saved[0]) 
 		{
 		  if(I->CurChar) {
-			 OrthoNewLine(G,NULL,true);
+            OrthoNewLine(G,NULL,true);
 		  }
 		  curLine = I->CurLine&OrthoSaveLines;
 		  strcpy(I->Line[curLine],I->Saved);
@@ -673,76 +702,48 @@ void OrthoKey(PyMOLGlobals *G,unsigned char k,int x,int y,int mod)
 		  I->CurChar = I->SavedCC;
 		  I->PromptChar = I->SavedPC;
 		} 
-	 else 
+      else 
 		{
 		  if(I->CurChar) 
-			 OrthoNewLine(G,I->Prompt,true);
+            OrthoNewLine(G,I->Prompt,true);
 		  else
-			 {
-				curLine = I->CurLine&OrthoSaveLines;
-				strcpy(I->Line[curLine],I->Prompt);
-				I->CurChar = (I->PromptChar = strlen(I->Prompt));
-			 }
+            {
+              curLine = I->CurLine&OrthoSaveLines;
+              strcpy(I->Line[curLine],I->Prompt);
+              I->CurChar = (I->PromptChar = strlen(I->Prompt));
+            }
 		}
-	 I->InputFlag=1;
-  }
+      I->InputFlag=1;
+    }
   if(mod==4) { /* alt */
     OrthoKeyAlt(G,k);
-  } else if((k>=32)&&(k!=127))
-	 {
-      curLine=I->CurLine&OrthoSaveLines;
-      
-      if(I->CursorChar>=0) {
-        strcpy(buffer,I->Line[curLine]+I->CursorChar);
-        I->Line[curLine][I->CursorChar]=k;
-        I->CursorChar++;
-        I->CurChar++;
-        strcpy(I->Line[curLine]+I->CursorChar,buffer);
-      } else {
-        I->Line[curLine][I->CurChar]=k;
-        I->CurChar++;
-        I->Line[curLine][I->CurChar]=0;
-      }
-	 }
-  else switch(k)
-	 {
-    case 127: /* delete */     
+  } else if((k>32)&&(k!=127)) {
+    curLine=add_normal_char(I,k);
+  } else switch(k) {
+  case 32: /* spacebar */
+    if(SettingGetGlobal_b(G,cSetting_presentation)&&!OrthoTextVisible(G)&&(I->CurChar==I->PromptChar)) {
+      PParse(G,"cmd.scene('','next')");
+    } else {
+      curLine=add_normal_char(I,k);
+    }
+    break;
+  case 127: /* delete */     
 #ifndef _PYMOL_OSX
-      if((!I->CurChar)||(I->CurChar==I->PromptChar)||!OrthoTextVisible(G)) {
-        OrthoKeyControl(G,4+64);
-      } else {
-        if(I->CursorChar>=0) {
-          if(I->CursorChar<I->CurChar)
-            I->CursorChar++;
-          if(I->CursorChar==I->CurChar)
-            I->CursorChar=-1;
-        }
-        if(I->CurChar>I->PromptChar)
-          {
-            curLine=I->CurLine&OrthoSaveLines;
-            if(I->CursorChar>=0) {
-              if(I->CursorChar>I->PromptChar) {
-                strcpy(buffer,I->Line[curLine]+I->CursorChar);
-                I->CursorChar--;
-                I->CurChar--;
-                strcpy(I->Line[curLine]+I->CursorChar,buffer);
-              }
-            } else {
-              I->CurChar--;
-              I->Line[curLine][I->CurChar]=0;
-            }
-          }
-      } 
-      break;
-	 case 8: /* backspace */
-#endif
-		if(I->CurChar>I->PromptChar)
-		  {
+    if((!I->CurChar)||(I->CurChar==I->PromptChar)||!OrthoTextVisible(G)) {
+      OrthoKeyControl(G,4+64);
+    } else {
+      if(I->CursorChar>=0) {
+        if(I->CursorChar<I->CurChar)
+          I->CursorChar++;
+        if(I->CursorChar==I->CurChar)
+          I->CursorChar=-1;
+      }
+      if(I->CurChar>I->PromptChar)
+        {
           curLine=I->CurLine&OrthoSaveLines;
           if(I->CursorChar>=0) {
             if(I->CursorChar>I->PromptChar) {
               strcpy(buffer,I->Line[curLine]+I->CursorChar);
-              I->Line[curLine][I->CursorChar]=k;
               I->CursorChar--;
               I->CurChar--;
               strcpy(I->Line[curLine]+I->CursorChar,buffer);
@@ -751,95 +752,120 @@ void OrthoKey(PyMOLGlobals *G,unsigned char k,int x,int y,int mod)
             I->CurChar--;
             I->Line[curLine][I->CurChar]=0;
           }
-		  }
-		break;
-    case 5: /* CTRL E -- ending */
-      if(OrthoArrowsGrabbed(G)) {
-        I->CursorChar=-1;
-      } else 
-        OrthoKeyControl(G,(unsigned char)(k+64));
-      break;
-    case 1: /* CTRL A -- beginning */
-      if(OrthoArrowsGrabbed(G)) {
-        if(I->CurChar)
-          I->CursorChar=I->PromptChar;        
-      } else 
-        OrthoKeyControl(G,(unsigned char)(k+64));
-      break;
-    case 4: /* CTRL D */
-      if((!I->CurChar)||(I->CurChar==I->PromptChar)||!OrthoTextVisible(G)) {
-        OrthoKeyControl(G,(unsigned char)(4+64));
-      } else if((I->CurChar>I->PromptChar)&&
-                (I->CursorChar>=0)&&
-                (I->CursorChar<I->CurChar)) { /* deleting */
+        }
+    } 
+    break;
+  case 8: /* backspace */
+#endif
+    if(I->CurChar>I->PromptChar)
+      {
         curLine=I->CurLine&OrthoSaveLines;
-        strcpy(buffer,I->Line[curLine]+I->CursorChar+1);
-        I->CurChar--;
-        strcpy(I->Line[curLine]+I->CursorChar,buffer);
-      } else { /* filename completion query */
-        curLine=I->CurLine&OrthoSaveLines;
-        if(I->PromptChar) {
-          strcpy(buffer,I->Line[curLine]);
-          if(PComplete(G,buffer+I->PromptChar,
-                    sizeof(OrthoLineType)-I->PromptChar)); /* just print, don't complete */
+        if(I->CursorChar>=0) {
+          if(I->CursorChar>I->PromptChar) {
+            strcpy(buffer,I->Line[curLine]+I->CursorChar);
+            I->Line[curLine][I->CursorChar]=k;
+            I->CursorChar--;
+            I->CurChar--;
+            strcpy(I->Line[curLine]+I->CursorChar,buffer);
+          }
+        } else {
+          I->CurChar--;
+          I->Line[curLine][I->CurChar]=0;
         }
       }
-      break;
-	 case 9: /* CTRL I -- tab */
-      if(mod&cOrthoCTRL) {
-        OrthoKeyControl(G,(unsigned char)(k+64)); 
-      } else {
-        curLine=I->CurLine&OrthoSaveLines;
-        if(I->PromptChar) {
-          strcpy(buffer,I->Line[curLine]);
+    break;
+  case 5: /* CTRL E -- ending */
+    if(OrthoArrowsGrabbed(G)) {
+      I->CursorChar=-1;
+    } else 
+      OrthoKeyControl(G,(unsigned char)(k+64));
+    break;
+  case 1: /* CTRL A -- beginning */
+    if(OrthoArrowsGrabbed(G)) {
+      if(I->CurChar)
+        I->CursorChar=I->PromptChar;        
+    } else 
+      OrthoKeyControl(G,(unsigned char)(k+64));
+    break;
+  case 4: /* CTRL D */
+    if((!I->CurChar)||(I->CurChar==I->PromptChar)||!OrthoTextVisible(G)) {
+      OrthoKeyControl(G,(unsigned char)(4+64));
+    } else if((I->CurChar>I->PromptChar)&&
+              (I->CursorChar>=0)&&
+              (I->CursorChar<I->CurChar)) { /* deleting */
+      curLine=I->CurLine&OrthoSaveLines;
+      strcpy(buffer,I->Line[curLine]+I->CursorChar+1);
+      I->CurChar--;
+      strcpy(I->Line[curLine]+I->CursorChar,buffer);
+    } else { /* filename completion query */
+      curLine=I->CurLine&OrthoSaveLines;
+      if(I->PromptChar) {
+        strcpy(buffer,I->Line[curLine]);
+        if(PComplete(G,buffer+I->PromptChar,
+                     sizeof(OrthoLineType)-I->PromptChar)); /* just print, don't complete */
+      }
+    }
+    break;
+  case 9: /* CTRL I -- tab */
+    if(mod&cOrthoCTRL) {
+      OrthoKeyControl(G,(unsigned char)(k+64)); 
+    } else {
+      curLine=I->CurLine&OrthoSaveLines;
+      if(I->PromptChar) {
+        strcpy(buffer,I->Line[curLine]);
           
-          if(PComplete(G,buffer+I->PromptChar,
-                       sizeof(OrthoLineType)-I->PromptChar))
-            {
-              OrthoRestorePrompt(G);
-              curLine=I->CurLine&OrthoSaveLines;
-              strcpy(I->Line[curLine],buffer);
-              I->CurChar = strlen(I->Line[curLine]);
-            }
-        }
+        if(PComplete(G,buffer+I->PromptChar,
+                     sizeof(OrthoLineType)-I->PromptChar))
+          {
+            OrthoRestorePrompt(G);
+            curLine=I->CurLine&OrthoSaveLines;
+            strcpy(I->Line[curLine],buffer);
+            I->CurChar = strlen(I->Line[curLine]);
+          }
       }
-      break;
-    case 27: /* ESCAPE */
+    }
+    break;
+  case 27: /* ESCAPE */
+    if(SettingGetGlobal_b(G,cSetting_presentation)&&!(mod&(cOrthoCTRL||cOrthoSHIFT))) {
+      PParse(G,"_quit");
+    } else {
       if(I->SplashFlag) {
         OrthoRemoveSplash(G);
       } else {
-        SettingSet(G,cSetting_text,(float)(!((int)SettingGet(G,cSetting_text))));
         if(mod&cOrthoSHIFT) 
           SettingSet(G,cSetting_overlay,(float)(!((int)SettingGet(G,cSetting_overlay))));
+        else
+          SettingSet(G,cSetting_text,(float)(!((int)SettingGet(G,cSetting_text))));
       }
-		break;
-	 case 13: /* CTRL M -- carriage return */
-      OrthoParseCurrentLine(G);
-		break;
-	 case 11: /* CTRL K -- truncate */
-      if(OrthoArrowsGrabbed(G)) {
-        if(I->CursorChar>=0) { 
-          I->Line[I->CurLine&OrthoSaveLines][I->CursorChar]=0;
-          I->CurChar=I->CursorChar;
-          I->CursorChar=-1;
-        }
-      } else {
-        if(mod&cOrthoCTRL) {
-          OrthoKeyControl(G,(unsigned char)(k+64));
-        }
+    }
+    break;
+  case 13: /* CTRL M -- carriage return */
+    OrthoParseCurrentLine(G);
+    break;
+  case 11: /* CTRL K -- truncate */
+    if(OrthoArrowsGrabbed(G)) {
+      if(I->CursorChar>=0) { 
+        I->Line[I->CurLine&OrthoSaveLines][I->CursorChar]=0;
+        I->CurChar=I->CursorChar;
+        I->CursorChar=-1;
       }
-      break;
-    case 22: /* CTRL V -- paste */
+    } else {
+      if(mod&cOrthoCTRL) {
+        OrthoKeyControl(G,(unsigned char)(k+64));
+      }
+    }
+    break;
+  case 22: /* CTRL V -- paste */
 #ifndef _PYMOL_NOPY
-      PBlockAndUnlockAPI(G);
-      PRunStringInstance(G,"cmd.paste()");
-      PLockAPIAndUnblock(G);
+    PBlockAndUnlockAPI(G);
+    PRunStringInstance(G,"cmd.paste()");
+    PLockAPIAndUnblock(G);
 #endif
-      break;
-	 default:
-      OrthoKeyControl(G,(unsigned char)(k+64));
-		break;
-	 }
+    break;
+  default:
+    OrthoKeyControl(G,(unsigned char)(k+64));
+    break;
+  }
   PyMOL_NeedRedisplay(G->PyMOL);
 }
 /*========================================================================*/
@@ -852,19 +878,18 @@ void OrthoParseCurrentLine(PyMOLGlobals *G)
   I->Line[curLine][I->CurChar]=0;
   strcpy(buffer,I->Line[curLine]+I->PromptChar);
 #ifndef _PYMOL_NOPY
-  if(buffer[0])
-    {
-      strcpy(I->History[I->HistoryLine],buffer);
-      I->HistoryLine = (I->HistoryLine+1)&OrthoHistoryLines;
-      I->History[I->HistoryLine][0]=0;
-      I->HistoryView=I->HistoryLine;
-      if(WordMatch(G,buffer,"quit",true)==0) /* don't log quit */
-        PLog(G,buffer,cPLog_pml);
-      OrthoNewLine(G,NULL,true);
-      OrthoDirty(G); /* this will force a redraw, if necessary */
-      PParse(G,buffer);
-      OrthoRestorePrompt(G);
-    }
+  if(buffer[0]) {
+    strcpy(I->History[I->HistoryLine],buffer);
+    I->HistoryLine = (I->HistoryLine+1)&OrthoHistoryLines;
+    I->History[I->HistoryLine][0]=0;
+    I->HistoryView=I->HistoryLine;
+    OrthoNewLine(G,NULL,true);
+    if(WordMatch(G,buffer,"quit",true)==0) /* don't log quit */
+      PLog(G,buffer,cPLog_pml);
+    OrthoDirty(G); /* this will force a redraw, if necessary */
+    PParse(G,buffer);
+    OrthoRestorePrompt(G);
+  }
 #endif
   I->CursorChar=-1;
 }
@@ -1029,6 +1054,9 @@ void OrthoDetach(PyMOLGlobals *G,Block *block)
 #ifdef PYMOL_EVAL
 #include "OrthoEvalMessage.h"
 #endif
+#ifdef PYMOL_BETA
+#include "OrthoBetaMessage.h"
+#endif
 #ifdef JYMOL_EVAL
 #include "OrthoJyMolEvalMessage.h"
 #endif
@@ -1148,7 +1176,7 @@ void OrthoDoDraw(PyMOLGlobals *G,int render_mode)
     ButModeSetRate(G,(float)I->DrawTime); 
     
     if(render&&(render_mode<2))
-      SceneRender(G,NULL,0,0,NULL,0,0);
+      SceneRender(G,NULL,0,0,NULL,0,0,0);
 
     glClearColor(0.0,0.0,0.0,1.0);
     
@@ -1279,6 +1307,9 @@ void OrthoDoDraw(PyMOLGlobals *G,int render_mode)
 #ifdef PYMOL_EVAL
       OrthoDrawEvalMessage(G);
 #endif
+#ifdef PYMOL_BETA
+      OrthoDrawBetaMessage(G);
+#endif
 #ifdef JYMOL_EVAL
       OrthoDrawEvalMessage(G);
 #endif
@@ -1297,6 +1328,7 @@ void OrthoDoDraw(PyMOLGlobals *G,int render_mode)
         PyMOLCheckOpenGLErr("OrthoDoDraw final checkpoint");
 
     } /* while */
+
   }
 
   I->DirtyFlag =false;
@@ -1509,49 +1541,55 @@ void OrthoReshape(PyMOLGlobals *G,int width, int height,int force)
     }
   }
 
-  if(SettingGet(G,cSetting_internal_gui)) {
-
+  {
+    int WizardMargin = WizardMargin1;
+    
+    if(!SettingGet(G,cSetting_mouse_grid)) {
+      WizardMargin = WizardMargin2;
+    }
+    if(SettingGet(G,cSetting_internal_gui)) {
 
 #ifndef _PYMOL_NOPY
-    block=ExecutiveGetBlock(G);
-    block->active=true;
-    BlockSetMargin(block,0,width-internal_gui_width,WizardMargin,0);
-    block=WizardGetBlock(G);
-    BlockSetMargin(block,height-WizardMargin+1,width-internal_gui_width,WizardMargin,0);
-    block->active=false;
-    block=ButModeGetBlock(G);
-    BlockSetMargin(block,height-WizardMargin+1,width-internal_gui_width,ButModeMargin,0);
-    block->active=true;
+      block=ExecutiveGetBlock(G);
+      block->active=true;
+      BlockSetMargin(block,0,width-internal_gui_width,WizardMargin,0);
+      block=WizardGetBlock(G);
+      BlockSetMargin(block,height-WizardMargin+1,width-internal_gui_width,WizardMargin,0);
+      block->active=false;
+      block=ButModeGetBlock(G);
+      BlockSetMargin(block,height-WizardMargin+1,width-internal_gui_width,ButModeMargin,0);
+      block->active=true;
 #else
-    block=ExecutiveGetBlock(G);
-    block->active=true;
-    BlockSetMargin(block,0,width-internal_gui_width,ButModeMargin,0);
-    block=WizardGetBlock(G);
-    BlockSetMargin(block,height-WizardMargin+1,width-internal_gui_width,ButModeMargin,0);
-    block->active=false;
-    block=ButModeGetBlock(G);
-    BlockSetMargin(block,height-WizardMargin+1,width-internal_gui_width,ButModeMargin,0);
-    block->active=false;
+      block=ExecutiveGetBlock(G);
+      block->active=true;
+      BlockSetMargin(block,0,width-internal_gui_width,ButModeMargin,0);
+      block=WizardGetBlock(G);
+      BlockSetMargin(block,height-WizardMargin+1,width-internal_gui_width,ButModeMargin,0);
+      block->active=false;
+      block=ButModeGetBlock(G);
+      BlockSetMargin(block,height-WizardMargin+1,width-internal_gui_width,ButModeMargin,0);
+      block->active=false;
 #endif
 
-    block=ControlGetBlock(G);
-    BlockSetMargin(block,height-ButModeMargin+1,width-internal_gui_width,ControlMargin,0);
-    block->active=true;
-  } else {
-    block=ExecutiveGetBlock(G);
-    block->active=false;
-    BlockSetMargin(block,0,width-internal_gui_width,WizardMargin,0);
-    block=WizardGetBlock(G);
-    BlockSetMargin(block,height-WizardMargin+1,width-internal_gui_width,WizardMargin,0);
-    block->active=false;
-    block=ButModeGetBlock(G);
-    BlockSetMargin(block,height-WizardMargin+1,width-internal_gui_width,ButModeMargin,0);
-    block->active=false;
-    block=ControlGetBlock(G);
-    BlockSetMargin(block,height-ButModeMargin+1,width-internal_gui_width,ControlMargin,0);
-    block->active=false;
-  }
+      block=ControlGetBlock(G);
+      BlockSetMargin(block,height-ButModeMargin+1,width-internal_gui_width,ControlMargin,0);
+      block->active=true;
+    } else {
+      block=ExecutiveGetBlock(G);
+      block->active=false;
+      BlockSetMargin(block,0,width-internal_gui_width,WizardMargin,0);
+      block=WizardGetBlock(G);
+      BlockSetMargin(block,height-WizardMargin+1,width-internal_gui_width,WizardMargin,0);
+      block->active=false;
+      block=ButModeGetBlock(G);
+      BlockSetMargin(block,height-WizardMargin+1,width-internal_gui_width,ButModeMargin,0);
+      block->active=false;
+      block=ControlGetBlock(G);
+      BlockSetMargin(block,height-ButModeMargin+1,width-internal_gui_width,ControlMargin,0);
+      block->active=false;
+    }
 
+  }
   block=SceneGetBlock(G);
   BlockSetMargin(block,sceneTop,0,sceneBottom,sceneRight);
 
@@ -1566,7 +1604,7 @@ void OrthoReshape(PyMOLGlobals *G,int width, int height,int force)
 }
 
 /*========================================================================*/
-void OrthoReshapeWizard(PyMOLGlobals *G,int wizHeight)
+void OrthoReshapeWizard(PyMOLGlobals *G,ov_size wizHeight)
 {
   Block *block;
   register COrtho *I=G->Ortho;
@@ -1577,12 +1615,17 @@ void OrthoReshapeWizard(PyMOLGlobals *G,int wizHeight)
   width=I->Width;
 
   if(SettingGet(G,cSetting_internal_gui)>0.0) {
+    int WizardMargin = WizardMargin1;
     internal_gui_width = (int)SettingGet(G,cSetting_internal_gui_width);
     block=ExecutiveGetBlock(G);
+
+    if(!SettingGet(G,cSetting_mouse_grid)) {
+      WizardMargin = WizardMargin2;
+    }
+
     if(height) {
       int wh=wizHeight;
       if(wh) wh++;
-
       BlockSetMargin(block,0,width-internal_gui_width,WizardMargin+wh,0);
     } else {
       BlockSetMargin(block,0,width-internal_gui_width,WizardMargin,0);
@@ -1609,7 +1652,11 @@ Block *OrthoFindBlock(PyMOLGlobals *G,int x,int y)
 
   return(BlockRecursiveFind(I->Blocks,x,y));
 }
-
+/*========================================================================*/
+int OrthoGetWrapClickSide(PyMOLGlobals *G)
+{
+  return G->Ortho->WrapClickSide;
+}
 /*========================================================================*/
 int OrthoButton(PyMOLGlobals *G,int button,int state,int x,int y,int mod)
 {
@@ -1625,13 +1672,15 @@ int OrthoButton(PyMOLGlobals *G,int button,int state,int x,int y,int mod)
     block = SceneGetBlock(G);
     break;
   }
-  
+
   if(I->WrapXFlag) {
     if(state==P_GLUT_DOWN) {
-      x = get_wrap_x(x,NULL,G->Option->winX);
+      x = get_wrap_x(x,NULL,G->Option->winX,&I->WrapClickSide);
     } else {
-      x = get_wrap_x(x,&I->LastX,G->Option->winX);
+      x = get_wrap_x(x,&I->LastX,G->Option->winX,&I->WrapClickSide);
     }
+  } else {
+    I->WrapClickSide = 0;
   }
 
   OrthoRemoveSplash(G);
@@ -1697,7 +1746,7 @@ int OrthoDrag(PyMOLGlobals *G,int x, int y,int mod)
   int handled = 0;
 
  if(I->WrapXFlag) {
-   x = get_wrap_x(x,&I->LastX,G->Option->winX);
+   x = get_wrap_x(x,&I->LastX,G->Option->winX, NULL);
  }
 
   I->LastX = x;
@@ -1729,7 +1778,7 @@ void OrthoSplash(PyMOLGlobals *G)
 #include"OrthoIPSplash.h"
 #else
   if(G->Option->incentive_product) {
-    PRINTF " PyMOL(TM) Incentive Product - Copyright (C) 2007 DeLano Scientific LLC.\n \n" ENDF(G);
+    PRINTF " PyMOL(TM) Incentive Product - Copyright (C) 2008 DeLano Scientific LLC.\n \n" ENDF(G);
     PRINTF " This Executable Build integrates and extends Open-Source PyMOL " ENDF(G);
     PRINTF _PyMOL_VERSION ENDF(G);
     PRINTF ".\n" ENDF(G);
@@ -1740,12 +1789,12 @@ void OrthoSplash(PyMOLGlobals *G)
       PRINTF " PyMOL(TM) Molecular Graphics System, Version " ENDF(G);
       PRINTF _PyMOL_VERSION ENDF(G);
       PRINTF ".\n" ENDF(G);
-      PRINTF " Copyright (C) 2007 by DeLano Scientific LLC.\n All Rights Reserved.\n \n" ENDF(G);
+      PRINTF " Copyright (C) 2008 by DeLano Scientific LLC.\n All Rights Reserved.\n \n" ENDF(G);
       
       PRINTF "    Created by Warren L. DeLano, Ph.D. \n \n" ENDF(G);
       
       PRINTF "    Other Major Authors and Contributors:\n\n" ENDF(G);
-      PRINTF "       Ralf W. Grosse-Kunstleve, Ph.D.\n \n" ENDF(G);
+      PRINTF "       Ralf W. Grosse-Kunstleve, Ph.D.\n \n" ENDF(G); /* note: sglite no longer used */
       
       PRINTF "    PyMOL is user-supported open-source software.  Although some versions\n" ENDF(G);
       PRINTF "    are freely available, PyMOL is not in the public domain.\n \n" ENDF(G);
@@ -1888,7 +1937,11 @@ void OrthoPushMatrix(PyMOLGlobals *G)
     glTranslatef(0.33F,0.33F,0.0F); /* this generates better 
                                        rasterization on macs */
 
-    glDisable(GL_ALPHA_TEST);
+    if(!SettingGetGlobal_b(G,cSetting_texture_fonts)){
+      glDisable(GL_ALPHA_TEST);
+    } else {
+      glEnable(GL_ALPHA_TEST);
+    }
     glDisable(GL_LIGHTING);
     glDisable(GL_FOG);
     glDisable(GL_NORMALIZE);
