@@ -47,15 +47,19 @@ Z* -------------------------------------------------------------------
 #define PUnlockAPIAsGlut(G)
 #define PUnlockAPIAsGlutNoFlush(G)
 
+#define PLockAPI(G)
+#define PUnlockAPI(G)
+
 #define PLockStatus(G)
 #define PLockStatusAttempt()G 1
 #define PUnlockStatusG()
 
+#define PBlockAndUnlockAPI(G)
 #define PBlockAndUnlockAPI(G)
 #define PLockAPIAndUnblock(G)
-
-#define PFlush(G)
-#define PFlushFast(G)
+#define PTryLockAPIAndUnblock(G)
+#define PFlush(G) 
+#define PFlushFast(G) 
 #define PParse(G,s)
 #define PDo(G,s)
 
@@ -77,6 +81,7 @@ Z* -------------------------------------------------------------------
 #define PFree()
 #define PInit(G,a)
 #define PSetupEmbedded(G,a,b)
+#define PConvertOptions(a,b)
 #define PGetOptions(a)
 
 #define PAlterAtom(G,a,b,c,d,e,f) 0
@@ -85,11 +90,17 @@ Z* -------------------------------------------------------------------
 
 #else
 
+ov_status PCacheSet(PyMOLGlobals *G, PyObject *entry, PyObject *output);
+ov_status PCacheGet(PyMOLGlobals *G, 
+                    PyObject **result_output, PyObject **result_entry,
+                    PyObject *input);
+
 void PInit(PyMOLGlobals *G,int global_instance);
 void PSetupEmbedded(PyMOLGlobals *G,int argc,char **argv);
 
   struct PyMOLOptionRec;
 
+void PConvertOptions(CPyMOLOptions *rec,PyObject *options);
 void PGetOptions(CPyMOLOptions *rec);
 
 void PFree(void);
@@ -112,6 +123,9 @@ void PSleep(PyMOLGlobals *G,int usec);
 void PSleepWhileBusy(PyMOLGlobals *G,int usec);
 void PSleepUnlocked(PyMOLGlobals *G,int usec);
 
+int PLockAPI(PyMOLGlobals *G,int block_if_busy);
+void PUnlockAPI(PyMOLGlobals *G);
+
 int PLockAPIAsGlut(PyMOLGlobals *G,int block_if_busy);
 void PUnlockAPIAsGlut(PyMOLGlobals *G);
 void PUnlockAPIAsGlutNoFlush(PyMOLGlobals *G);
@@ -131,11 +145,12 @@ void PAutoUnblock(PyMOLGlobals *G,int flag);
 
 void PBlockAndUnlockAPI(PyMOLGlobals *G);
 void PLockAPIAndUnblock(PyMOLGlobals *G);
+int PTryLockAPIAndUnblock(PyMOLGlobals *G);
 
-void PFlush(PyMOLGlobals *G);
-void PFlushFast(PyMOLGlobals *G);
+int PFlush(PyMOLGlobals *G);
+int PFlushFast(PyMOLGlobals *G);
 void PXDecRef(PyObject *obj);
-
+PyObject *PXIncRef(PyObject *obj);
 void PSGIStereo(PyMOLGlobals *G,int flag);
 void PDefineFloat(PyMOLGlobals *G,char *name,float value);
 
@@ -150,6 +165,7 @@ int PComplete(PyMOLGlobals *G,char *str,int buf_size);
 int PTruthCallStr(PyObject *object,char *method,char *argument);
 int PTruthCallStr0(PyObject *object,char *method);
 int PTruthCallStr1i(PyObject *object,char *method,int argument);
+int PTruthCallStr1s(PyObject *object,char *method,char *argument);
 int PTruthCallStr4i(PyObject *object,char *method,int a1,int a2,int a3,int a4);
 int PPovrayRender(PyMOLGlobals *G,char *header,char *inp,char *file,int width,int height,int antialias);
 int PIsGlutThread(void);
@@ -176,6 +192,8 @@ struct _CP_inst {
   PyObject *complete; /* complete partial command / TAB action */
   PyObject *cmd_do;
 
+  PyObject *cache;
+
   /* locks and threads */
 
   PyObject *lock; /* API locks */
@@ -207,10 +225,6 @@ extern PyObject *P_chempy; /* used by CoordSet and Selector for construction of
 extern PyObject *P_models; /* used by Selector for construction of models */
 extern PyObject *P_setting; /* used by Setting.c */
 
-/* unused? */
-extern PyObject *P_embed; /* not set by PyMOL -- must be set by host context */
-
-
 extern unsigned int P_glut_thread_id;
 
 #endif
