@@ -89,7 +89,7 @@ int PConvPyListToStrVLAList(PyObject *obj,char **vla, int *n_str)
   return(ok);
 }
 
-int PConvAttrToIntArrayInPlace(PyObject *obj,char *attr,int *f,int ll)
+int PConvAttrToIntArrayInPlace(PyObject *obj,char *attr,int *f,ov_size ll)
 {
   int ok=true;
   PyObject *tmp;
@@ -105,7 +105,7 @@ int PConvAttrToIntArrayInPlace(PyObject *obj,char *attr,int *f,int ll)
   return(ok);
 }
 
-int PConvAttrToFloatArrayInPlace(PyObject *obj,char *attr,float *f,int ll)
+int PConvAttrToFloatArrayInPlace(PyObject *obj,char *attr,float *f,ov_size ll)
 {
   int ok=true;
   PyObject *tmp;
@@ -121,7 +121,7 @@ int PConvAttrToFloatArrayInPlace(PyObject *obj,char *attr,float *f,int ll)
   return(ok);
 }
 
-int PConvAttrToStrMaxLen(PyObject *obj,char *attr,char *str,int ll)
+int PConvAttrToStrMaxLen(PyObject *obj,char *attr,char *str,ov_size ll)
 {
   int ok=true;
   PyObject *tmp;
@@ -662,10 +662,52 @@ int PConvPyListToIntVLA(PyObject *obj,int **f)
   return(ok);
 }
 
-int PConvPyListToDoubleArrayInPlace(PyObject *obj,double *ff,int ll)
+ov_status PConvPyTupleToIntVLA(int **result, PyObject *tuple)
+{
+  ov_status status = OV_STATUS_FAILURE;
+  if(!(tuple && PyTuple_Check(tuple))) {
+    *result = NULL;
+  } else {
+    int *vla = NULL;
+    ov_size size = PyTuple_Size(tuple);
+    vla = VLAlloc(int,size);
+    if(vla) {
+      ov_size i;
+      int *ptr = vla;
+      status = OV_STATUS_SUCCESS;
+      for(i=0;i<size;i++)
+        *(ptr++) = PyInt_AsLong(PyTuple_GetItem(tuple,i));
+    }
+    *result = vla;
+  }
+  return status;
+}
+
+ov_status PConvPyTupleToFloatVLA(float **result, PyObject *tuple)
+{
+  ov_status status = OV_STATUS_FAILURE;
+  if(!(tuple && PyTuple_Check(tuple))) {
+    *result = NULL;
+  } else {
+    float *vla = NULL;
+    ov_size size = PyTuple_Size(tuple);
+    vla = VLAlloc(float,size);
+    if(vla) {
+      ov_size i;
+      float *ptr = vla;
+      status = OV_STATUS_SUCCESS;
+      for(i=0;i<size;i++)
+        *(ptr++) = (float)PyFloat_AsDouble(PyTuple_GetItem(tuple,i));
+    }
+    *result = vla;
+  }
+  return status;
+}
+
+int PConvPyListToDoubleArrayInPlace(PyObject *obj,double *ff,ov_size ll)
 {
   int ok = true;
-  int a,l;
+  ov_size a,l;
   if(!obj) { 
     ok=false;
   } else if(!PyList_Check(obj)) {
@@ -687,10 +729,10 @@ int PConvPyListToDoubleArrayInPlace(PyObject *obj,double *ff,int ll)
   return(ok);
 }
 
-int PConvPyListToFloatArrayInPlace(PyObject *obj,float *ff,int ll)
+int PConvPyListToFloatArrayInPlace(PyObject *obj,float *ff,ov_size ll)
 {
   int ok = true;
-  int a,l;
+  ov_size a,l;
   if(!obj) { 
     ok=false;
   } else if(!PyList_Check(obj)) {
@@ -712,10 +754,10 @@ int PConvPyListToFloatArrayInPlace(PyObject *obj,float *ff,int ll)
   return(ok);
 }
 
-int PConvPyListToIntArrayInPlace(PyObject *obj,int *ii,int ll)
+int PConvPyListToIntArrayInPlace(PyObject *obj,int *ii,ov_size ll)
 {
   int ok = true;
-  int a,l;
+  ov_size a,l;
   if(!obj) 
     ok=false;
   else if(!PyList_Check(obj)) 
@@ -736,10 +778,10 @@ int PConvPyListToIntArrayInPlace(PyObject *obj,int *ii,int ll)
   return(ok);
 }
 
-int PConvPyListToIntArrayInPlaceAutoZero(PyObject *obj,int *ii,int ll)
+int PConvPyListToIntArrayInPlaceAutoZero(PyObject *obj,int *ii,ov_size ll)
 {
   int ok = true;
-  int a,l;
+  ov_size a,l;
   if(!obj) 
     ok=false;
   else if(!PyList_Check(obj)) 
@@ -760,10 +802,10 @@ int PConvPyListToIntArrayInPlaceAutoZero(PyObject *obj,int *ii,int ll)
   return(ok);
 }
 
-int PConvPyListToSIntArrayInPlaceAutoZero(PyObject *obj,short int *ii,int ll)
+int PConvPyListToSIntArrayInPlaceAutoZero(PyObject *obj,short int *ii,ov_size ll)
 {
   int ok = true;
-  int a,l;
+  ov_size a,l;
   if(!obj) 
     ok=false;
   else if(!PyList_Check(obj)) 
@@ -784,10 +826,10 @@ int PConvPyListToSIntArrayInPlaceAutoZero(PyObject *obj,short int *ii,int ll)
   return(ok);
 }
 
-int PConvPyListToSCharArrayInPlaceAutoZero(PyObject *obj,signed char *ii,int ll)
+int PConvPyListToSCharArrayInPlaceAutoZero(PyObject *obj,signed char *ii,ov_size ll)
 {
   int ok = true;
-  int a,l;
+  ov_size a,l;
   if(!obj) 
     ok=false;
   else if(!PyList_Check(obj)) 
@@ -808,10 +850,10 @@ int PConvPyListToSCharArrayInPlaceAutoZero(PyObject *obj,signed char *ii,int ll)
   return(ok);
 }
 
-int PConvPyListToFloatArrayInPlaceAutoZero(PyObject *obj,float *ii,int ll)
+int PConvPyListToFloatArrayInPlaceAutoZero(PyObject *obj,float *ii,ov_size ll)
 {
   int ok = true;
-  int a,l;
+  ov_size a,l;
   if(!obj) 
     ok=false;
   else if(!PyList_Check(obj)) 
@@ -836,88 +878,113 @@ int PConvPyListToFloatArrayInPlaceAutoZero(PyObject *obj,float *ii,int ll)
 PyObject *PConvFloatArrayToPyList(float *f,int l)
 {
   int a;
-  PyObject *result = Py_None;
-  result=PyList_New(l);
+  PyObject *result = PyList_New(l);
   for(a=0;a<l;a++) 
     PyList_SetItem(result,a,PyFloat_FromDouble((double)*(f++)));
-  return(result);
+  return(PConvAutoNone(result));
 }
 
 PyObject *PConvFloatArrayToPyListNullOkay(float *f,int l)
 {
   int a;
-  PyObject *result = Py_None;
-  if(!f) {
-    result = PConvAutoNone(NULL);
-  } else {
+  PyObject *result = NULL;
+  if(f) {
     result=PyList_New(l);
     for(a=0;a<l;a++) 
       PyList_SetItem(result,a,PyFloat_FromDouble((double)*(f++)));
   }
-  return(result);
+  return(PConvAutoNone(result));
 }
 
 PyObject *PConvDoubleArrayToPyList(double *f,int l)
 {
   int a;
-  PyObject *result = Py_None;
-  result=PyList_New(l);
+  PyObject *result = PyList_New(l);
   for(a=0;a<l;a++) 
     PyList_SetItem(result,a,PyFloat_FromDouble(*(f++)));
-  return(result);
+  return(PConvAutoNone(result));
 }
 
 PyObject *PConvFloatVLAToPyList(float *f)
 {
   int a,l;
-  PyObject *result = Py_None;
+  PyObject *result = NULL;
   l=VLAGetSize(f);
   result=PyList_New(l);
   for(a=0;a<l;a++) {
     PyList_SetItem(result,a,PyFloat_FromDouble((double)*(f++))); /* set item steals ref */
   }
-  return(result);
+  return(PConvAutoNone(result));
+}
+
+PyObject *PConvFloatVLAToPyTuple(float *vla)
+{
+  PyObject *result = NULL;
+  if(vla) {
+    ov_size size = VLAGetSize(vla);
+    result = PyTuple_New(size);
+    if(result) {
+      ov_size i;
+      for(i=0;i<size;i++) {
+        PyTuple_SetItem(result,i,PyFloat_FromDouble((double)*(vla++))); /* set item steals ref */
+      }
+    }
+  }
+  return(PConvAutoNone(result));
 }
 
 PyObject *PConvIntVLAToPyList(int *f)
 {
   int a,l;
-  PyObject *result = Py_None;
+  PyObject *result = NULL;
   l=VLAGetSize(f);
   result=PyList_New(l);
   for(a=0;a<l;a++) 
     PyList_SetItem(result,a,PyInt_FromLong(*(f++)));
-  return(result);
+  return(PConvAutoNone(result));
+}
+
+PyObject *PConvIntVLAToPyTuple(int *vla)
+{
+  PyObject *result = NULL;
+  if(vla) {
+    ov_size size = VLAGetSize(vla);
+    result = PyTuple_New(size);
+    if(result) {
+      ov_size i;
+      for(i=0;i<size;i++) {
+        PyTuple_SetItem(result,i,PyInt_FromLong(*(vla++))); /* set item steals ref */
+      }
+    }
+  }
+  return(PConvAutoNone(result));
 }
 
 PyObject *PConvIntArrayToPyList(int *f,int l)
 {
   int a;
-  PyObject *result = Py_None;
-  result=PyList_New(l);
+  PyObject *result = PyList_New(l);
   for(a=0;a<l;a++) 
     PyList_SetItem(result,a,PyInt_FromLong(*(f++)));
-  return(result);
+  return(PConvAutoNone(result));
 }
 
 PyObject *PConvSIntArrayToPyList(short int *f,int l)
 {
   int a;
-  PyObject *result = Py_None;
-  result=PyList_New(l);
+  PyObject *result = PyList_New(l);
   for(a=0;a<l;a++) 
     PyList_SetItem(result,a,PyInt_FromLong(*(f++)));
-  return(result);
+  return(PConvAutoNone(result));
 }
 
 PyObject *PConvSCharArrayToPyList(signed char *f,int l)
 {
   int a;
-  PyObject *result = Py_None;
-  result=PyList_New(l);
+  PyObject *result = PyList_New(l);
   for(a=0;a<l;a++) 
     PyList_SetItem(result,a,PyInt_FromLong(*(f++)));
-  return(result);
+  return(PConvAutoNone(result));
 }
 
 PyObject *PConv3DIntArrayTo3DPyList(int ***array,int *dim)
@@ -936,25 +1003,24 @@ PyObject *PConv3DIntArrayTo3DPyList(int ***array,int *dim)
       }
     }
   }
-  return(result);
+  return(PConvAutoNone(result));
 }
 
 PyObject *PConvStringListToPyList(int l,char **str)
 {
   int a;
-  PyObject *result = Py_None;
-  result=PyList_New(l);
+  PyObject *result = PyList_New(l);
   for(a=0;a<l;a++) {
     PyList_SetItem(result,a,PyString_FromString(str[a]));
   }
-  return(result);
+  return(PConvAutoNone(result));
 }
 
 PyObject *PConvStringVLAToPyList(char *vla)
 {
   int a,c,n=0;
   char *p;
-  PyObject *result = Py_None;
+  PyObject *result = NULL;
   p=vla;
   c = VLAGetSize(vla);
   while(c--) { /* count strings */
@@ -1043,7 +1109,7 @@ PyObject *PConvLabPosVLAToPyList(LabPosType *vla,int l)
 { /* TO DO error handling */
   int a;
   LabPosType *p = vla;
-  PyObject *result = Py_None;
+  PyObject *result = NULL;
   if(p) {
     PyObject *item;
     result=PyList_New(l); 
