@@ -48,7 +48,8 @@ void SceneDone(PyMOLGlobals *G);
 void SceneUpdate(PyMOLGlobals *G);
 int SceneRenderCached(PyMOLGlobals *G);
 void SceneRender(PyMOLGlobals *G,Picking *pick,int x,int y,
-                 Multipick *smp,int oversize_width, int oversize_height);
+                 Multipick *smp,int oversize_width, int oversize_height, 
+                 int click_side);
 void SceneSetFrame(PyMOLGlobals *G,int mode,int frame);
 int SceneSetNames(PyMOLGlobals *G,PyObject *list);
 int SceneGetFrame(PyMOLGlobals *G);
@@ -86,7 +87,7 @@ int SceneDeferRay(PyMOLGlobals *G,
                    int quiet,
                    int show_timing,
                    int antialias);
-void SceneMakeMovieImage(PyMOLGlobals *G,int show_timing);
+int SceneMakeMovieImage(PyMOLGlobals *G,int show_timing,int validate);
 
 void ScenePNG(PyMOLGlobals *G,char *png,float dpi,int quiet);
 int SceneCopyExternal(PyMOLGlobals *G,int width, int height,int rowbytes,
@@ -101,6 +102,10 @@ void SceneGetEyeNormal(PyMOLGlobals *G,float *v1,float *normal);
 
 void SceneRotate(PyMOLGlobals *G,float angle,float x,float y,float z);
 void SceneTranslate(PyMOLGlobals *G,float x,float y, float z);
+
+void SceneTranslateScaled(PyMOLGlobals *G,float x,float y, float z);
+void SceneRotateScaled(PyMOLGlobals *G,float rx,float ry, float rz);
+
 void SceneClip(PyMOLGlobals *G,int plane,float movement,char *sele,int state);
 void SceneGetImageSize(PyMOLGlobals *G,int *width,int *height);
 
@@ -125,9 +130,10 @@ void SceneClipSet(PyMOLGlobals *G,float front,float back);
 void SceneGetView(PyMOLGlobals *G,SceneViewType view);
 void SceneSetView(PyMOLGlobals *G,SceneViewType view,
                   int quiet,float animate,int hand);
+void SceneRestartSweepTimer(PyMOLGlobals *G);
 
-void SceneToViewElem(PyMOLGlobals *G,CViewElem *elem);
-void SceneFromViewElem(PyMOLGlobals *G,CViewElem *elem);
+void SceneToViewElem(PyMOLGlobals *G,CViewElem *elem,char *scene_name);
+void SceneFromViewElem(PyMOLGlobals *G,CViewElem *elem,int dirty);
 void SceneGetPos(PyMOLGlobals *G,float *pos);
 void SceneGetWidthHeight(PyMOLGlobals *G,int *width,int *height);
 int SceneMultipick(PyMOLGlobals *G,Multipick *smp);
@@ -151,7 +157,8 @@ void SceneSuppressMovieFrame(PyMOLGlobals *G);
 int SceneDeferClick(Block *block,int button,int x,int y,int mod);
 int SceneDeferRelease(Block *block,int button,int x,int y,int mod);
 int SceneDeferDrag(Block *block,int x,int y,int mod);
-int SceneDeferImage(PyMOLGlobals *G,int width, int height, char *filename,int antialias, float dpi,int quiet);
+int SceneDeferImage(PyMOLGlobals *G,int width, int height, char *filename,
+                    int antialias, float dpi, int quiet);
 char *SceneGetSeleModeKeyword(PyMOLGlobals *G);
 void SceneUpdateStereo(PyMOLGlobals *G);
 void ScenePushRasterMatrix(PyMOLGlobals *G,float *v);
@@ -163,6 +170,7 @@ float SceneGetReflectScaleValue(PyMOLGlobals *G,int limit);
 float SceneGetSpecularValue(PyMOLGlobals *G,float spec,int limit);
 void SceneAbortAnimation(PyMOLGlobals *G);
 void SceneObjectUpdateThread(CObjectUpdateThreadInfo *T);
+int SceneCaptureWindow(PyMOLGlobals *G);
 
 #endif
 
