@@ -42,13 +42,13 @@ typedef struct {
   int defined;
   int changed;
   int type;
-  unsigned int offset;
-  unsigned int max_size;
+  ov_diff offset;
+  ov_size max_size;
 } SettingRec;
 
 struct _CSetting {
   PyMOLGlobals *G;
-  unsigned int size;
+  ov_size size;
   char *data;
   SettingRec *info;
 };
@@ -87,7 +87,10 @@ int SettingUniqueFromPyList(PyMOLGlobals *G,PyObject *list,int partial_restore);
 int SettingUniqueConvertOldSessionID(PyMOLGlobals *G,int old_unique_id);
 
 int SettingUniqueCopyAll(PyMOLGlobals *G, int src_unique_id, int dst_unique_id);
-void SettingInitGlobal(PyMOLGlobals *G,int alloc,int reset_gui);
+void SettingInitGlobal(PyMOLGlobals *G,int alloc,int reset_gui,int use_default);
+void SettingStoreDefault(PyMOLGlobals *G);
+void SettingPurgeDefault(PyMOLGlobals *G);
+
 void SettingFreeGlobal(PyMOLGlobals *G);
 
 
@@ -173,8 +176,15 @@ int SettingGetName(PyMOLGlobals *G,int index,SettingName name);
 
 PyObject *SettingAsPyList(CSetting *I);
 int SettingFromPyList(CSetting *I,PyObject *list);
+
 int SettingSetGlobalsFromPyList(PyMOLGlobals *G,PyObject *list);
 PyObject *SettingGetGlobalsAsPyList(PyMOLGlobals *G);
+
+/* proposed...
+PyObject *SettingGetDefaultsAsPyList(PyMOLGlobals *G);
+int SettingSetDefaultsFromPyList(PyMOLGlobals *G,PyObject *list);
+*/
+
 CSetting *SettingNewFromPyList(PyMOLGlobals *G,PyObject *list);
 
 /* WARNING: do not delete or change indices
@@ -752,6 +762,42 @@ CSetting *SettingNewFromPyList(PyMOLGlobals *G,PyObject *list);
 #define cSetting_moe_separate_chains        558
 #define cSetting_transparency_global_sort   559
 #define cSetting_hide_long_bonds            560
+#define cSetting_auto_rename_duplicate_objects 561
+#define cSetting_pdb_hetatm_guess_valences  562
+#define cSetting_ellipsoid_quality          563
+#define cSetting_cgo_ellipsoid_quality      564
+#define cSetting_movie_animate_by_frame     565
+#define cSetting_ramp_blend_nearby_colors   566
+#define cSetting_auto_defer_builds          567
+#define cSetting_ellipsoid_probability      568
+#define cSetting_ellipsoid_scale            569
+#define cSetting_ellipsoid_color            570
+#define cSetting_ellipsoid_transparency     571
+#define cSetting_movie_rock                 572
+#define cSetting_cache_mode                 573
+#define cSetting_dash_color                 574
+#define cSetting_angle_color                575
+#define cSetting_dihedral_color             576
+#define cSetting_grid_mode                  577
+#define cSetting_cache_max                  578
+#define cSetting_grid_slot                  579
+#define cSetting_grid_max                   580
+#define cSetting_cartoon_putty_transform    581
+#define cSetting_rock                       582
+#define cSetting_cone_quality               583
+#define cSetting_pdb_formal_charges         584
+#define cSetting_ati_bugs                   585
+#define cSetting_geometry_export_mode       586
+#define cSetting_mouse_grid                 587
+#define cSetting_mesh_cutoff                588
+#define cSetting_mesh_carve_selection       589
+#define cSetting_mesh_carve_state           590
+#define cSetting_mesh_carve_cutoff          591
+#define cSetting_mesh_clear_selection       592
+#define cSetting_mesh_clear_state           593
+#define cSetting_mesh_clear_cutoff          594
+#define cSetting_mesh_grid_max              595
+#define cSetting_session_cache_optimize     596
 
 /* when you add a new setting also remember:
    layer1/Setting.c
@@ -761,8 +807,7 @@ CSetting *SettingNewFromPyList(PyMOLGlobals *G,PyObject *list);
 
 /* cSetting_ss_INIT must always be last setting_index +1 */
 
-#define cSetting_INIT                       561
-
+#define cSetting_INIT                       597
 #endif
 
 
