@@ -19,11 +19,13 @@ Z* -------------------------------------------------------------------
 #define cShakerDistBond 0
 #define cShakerDistAngle 1
 #define cShakerDistLimit 2
+#define cShakerDistMinim 3
+#define cShakerDistMaxim 4
 
 typedef struct {
   int at0,at1;
   int type;
-  float targ,targ2;
+  float targ,targ2,weight;
 } ShakerDistCon;
 
 #define cShakerTorsAlkane 1
@@ -68,7 +70,7 @@ typedef struct {
 
 CShaker *ShakerNew(PyMOLGlobals *G);
 void ShakerReset(CShaker *I);
-void ShakerAddDistCon(CShaker *I,int atom0,int atom1,float dist,int type);
+void ShakerAddDistCon(CShaker *I,int atom0,int atom1,float dist,int type,float weight);
 void ShakerAddTorsCon(CShaker *I,int atom0,int atom1,int atom2,int atom3,int type);
 void ShakerAddPyraCon(CShaker *I,int atom0,int atom1,int atom2,int atom3,float target);
 void ShakerAddPlanCon(CShaker *I,int atom0,int atom1,int atom2,int atom3,float target, int fixed);
@@ -78,17 +80,19 @@ void ShakerAddLineCon(CShaker *I,int atom0,int atom1,int atom2);
 float ShakerGetPyra(float *v0,float *v1,float *v2,float *v3);
 
 /* the following fn's have been inlined in Sculpt.c  
+
 float ShakerDoDist(float target,float *v0,float *v1,float *d0to1,float *d1to0,float wt);
 
 float ShakerDoTors(int type, float *v0,float *v1,float *v2,float *v3,
                    float *p0,float *p1,float *p2,float *p3,float wt);
+float ShakerDoDistLimit(float target,float *v0,float *v1,float *d0to1,float *d1to0,float wt);
+
 
 */
 
 float ShakerDoPyra(float target,float *v0,float *v1,float *v2,float *v3,
                    float *p0,float *p1,float *p2,float *p3,float wt);
 
-float ShakerDoDistLimit(float target,float *v0,float *v1,float *d0to1,float *d1to0,float wt);
 
 float ShakerDoLine(float *v0,float *v1,float *v2,
                    float *p0,float *p1,float *p2,float wt);
