@@ -57,7 +57,7 @@ int SymmetryFromPyList(CSymmetry *I,PyObject *list)
   return 0;
 #else
   int ok=true;
-  int ll;
+  ov_size ll;
 
   if(ok) ok = (I!=NULL);
   if(ok) SymmetryReset(I);
@@ -67,7 +67,7 @@ int SymmetryFromPyList(CSymmetry *I,PyObject *list)
   if(ok) ok = CrystalFromPyList(I->Crystal,PyList_GetItem(list,0));
   if(ok) ok = PConvPyStrToStr(PyList_GetItem(list,1),I->SpaceGroup,sizeof(WordType));
    if(ok) {
-    ok = SymmetryAttemptGeneration(I,true,true);
+    ok = SymmetryAttemptGeneration(I,true);
   }
   /* TO SUPPORT BACKWARDS COMPATIBILITY...
    Always check ll when adding new PyList_GetItem's */
@@ -88,6 +88,8 @@ CSymmetry *SymmetryNewFromPyList(PyMOLGlobals *G,PyObject *list)
   return(I);
 }
 
+#ifndef _PYMOL_NOPY
+#ifdef _PYMOL_XRAY
 static void SymmetryDump44f(PyMOLGlobals *G,float *m,char *prefix)
 {
   if(prefix) {
@@ -102,39 +104,41 @@ static void SymmetryDump44f(PyMOLGlobals *G,float *m,char *prefix)
     PRINTF "%12.5f %12.5f %12.5f %12.5f\n",m[12],m[13],m[14],m[15] ENDF(G);
   }
 }
+#endif
+#endif
 
-int SymmetryAttemptGeneration(CSymmetry *I,int blocked,int quiet)
+int SymmetryAttemptGeneration(CSymmetry *I,int quiet)
 {
   int ok = false;
 #ifndef _PYMOL_NOPY
 #ifdef _PYMOL_XRAY
+  PyMOLGlobals *G = I->G;
   PyObject *mats;
-  int a,l;
+  ov_size a,l;
   CrystalUpdate(I->Crystal);
   if(!quiet) {
-    if(Feedback(I->G,FB_Symmetry,FB_Blather)) {
+    if(Feedback(G,FB_Symmetry,FB_Blather)) {
       CrystalDump(I->Crystal);
     }
   }
   if(!I->SpaceGroup[0]) {
-    ErrMessage(I->G,"Symmetry","Missing space group symbol");
-  } else {
-    if(!blocked) 
-      PBlock();
-    mats = PyObject_CallMethod(P_xray,"sg_sym_to_mat_list","s",I->SpaceGroup);
+    ErrMessage(G,"Symmetry","Missing space group symbol");
+  } else if(P_xray) {
+	int blocked = PAutoBlock(G);
+	mats = PyObject_CallMethod(P_xray,"sg_sym_to_mat_list","s",I->SpaceGroup);
     if(mats&&(mats!=Py_None)) {
       l = PyList_Size(mats);
       VLACheck(I->SymMatVLA,float,16*l);
       if(!quiet) {
-        PRINTFB(I->G,FB_Symmetry,FB_Details)
-          " Symmetry: Found %d symmetry operators.\n",l
-          ENDFB(I->G);
+        PRINTFB(G,FB_Symmetry,FB_Details)
+          " Symmetry: Found %d symmetry operators.\n",(int)l
+          ENDFB(G);
       }
       for(a=0;a<l;a++) {
         PConv44PyListTo44f(PyList_GetItem(mats,a),I->SymMatVLA+(a*16));
         if(!quiet) {
-          if(Feedback(I->G,FB_Symmetry,FB_Blather)) {
-            SymmetryDump44f(I->G,I->SymMatVLA+(a*16)," Symmetry:");
+          if(Feedback(G,FB_Symmetry,FB_Blather)) {
+            SymmetryDump44f(G,I->SymMatVLA+(a*16)," Symmetry:");
           }
         }
       }
@@ -142,10 +146,9 @@ int SymmetryAttemptGeneration(CSymmetry *I,int blocked,int quiet)
       ok = true;
       Py_DECREF(mats);
     } else {
-      ErrMessage(I->G,"Symmetry","Unable to get matrices from sglite.");
+      ErrMessage(G,"Symmetry","Unable to get matrices.");
     }
-    if(!blocked) 
-      PUnblock();
+    PAutoUnblock(G,blocked);
   }
 #endif
 #endif
