@@ -47,13 +47,19 @@ typedef struct CViewElem {
   int timing_flag;
   double timing;
 
+  int scene_flag; /* only applies to main movie view */
+  int scene_name; /* lexicon key */
+
 } CViewElem;
 
-PyObject *ViewElemAsPyList(CViewElem *view);
-int ViewElemFromPyList(PyObject *list, CViewElem *view);
+PyObject *ViewElemAsPyList(PyMOLGlobals *G, CViewElem *view);
+int ViewElemFromPyList(PyMOLGlobals *G, PyObject *list, CViewElem *view);
 
-int ViewElemVLAFromPyList(PyObject *list, CViewElem **vla, int nFrame);
-PyObject *ViewElemVLAAsPyList(CViewElem *vla, int nFrame);
+int ViewElemVLAFromPyList(PyMOLGlobals *G, PyObject *list, CViewElem **vla, int nFrame);
+PyObject *ViewElemVLAAsPyList(PyMOLGlobals *G, CViewElem *vla, int nFrame);
+
+void ViewElemArrayPurge(PyMOLGlobals *G,CViewElem *view,int nFrame);
+void ViewElemCopy(PyMOLGlobals *G,CViewElem *src,CViewElem *dst);
 
 typedef struct CView {
   PyMOLGlobals *G;
@@ -69,8 +75,11 @@ void ViewFree(CView *I);
 
 CViewIterator ViewGetIterator(CView *I);
 int ViewIterate(CView *I,CViewIterator *iter,CRay *ray,int at_least_once);
+int ViewElemSmooth(CViewElem *first,CViewElem *last,int window,int loop);
 
-int ViewElemInterpolate(CViewElem *first,CViewElem *last,float power,float bias);
+int ViewElemInterpolate(PyMOLGlobals *G,CViewElem *first,CViewElem *last,
+                        float power,float bias,
+                        int simple, float linearity,int hand,float cut);
 
 #endif
 
