@@ -28,6 +28,7 @@ Z* -------------------------------------------------------------------
 #include"Ortho.h"
 #include"OVOneToAny.h"
 #include"OVContext.h"
+#include"PyMOLObject.h"
 
 struct _CAtomInfo {
   int NColor,CColor,DColor,HColor,OColor,SColor;
@@ -40,6 +41,30 @@ struct _CAtomInfo {
   OVOneToAny *ActiveIDs;
 };
 
+void AtomInfoCleanAtomName(char *name)
+{
+  char *p = name, *q = name;
+  int c = 0;
+  while(*p) {
+    if(c+1==sizeof(AtomName)) {
+      break;
+    }
+    if( ( ((*p)>='0')&&((*p)<='9')) ||
+        ( ((*p)>='a')&&((*p)<='z')) ||
+        ( ((*p)>='A')&&((*p)<='Z')) ||
+        ((*p)=='.') || 
+        ((*p)=='_' ) || 
+        ((*p)=='+' ) || 
+        ((*p)=='\'') || 
+        ((*p)=='*' )) {
+      *q++ = *p;
+      c++;
+    }
+    p++;
+  }
+  *q = 0;
+}
+
 int AtomInfoCheckSetting(PyMOLGlobals *G, AtomInfoType *ai, int setting_id)
 {  
   if(!ai->has_setting) {
@@ -837,7 +862,7 @@ PyObject *AtomInfoAsPyList(PyMOLGlobals *G,AtomInfoType *I)
 #else
   PyObject *result = NULL;
 
-  result = PyList_New(41);
+  result = PyList_New(47);
   PyList_SetItem(result, 0,PyInt_FromLong(I->resv));
   PyList_SetItem(result, 1,PyString_FromString(I->chain));
   PyList_SetItem(result, 2,PyString_FromString(I->alt));
@@ -890,6 +915,13 @@ PyObject *AtomInfoAsPyList(PyMOLGlobals *G,AtomInfoType *I)
   PyList_SetItem(result,38,PyInt_FromLong((int)I->hb_acceptor));
   PyList_SetItem(result,39,PyInt_FromLong((int)I->atomic_color));
   PyList_SetItem(result,40,PyInt_FromLong((int)I->has_setting));
+  PyList_SetItem(result,41,PyFloat_FromDouble(I->U11));
+  PyList_SetItem(result,42,PyFloat_FromDouble(I->U22));
+  PyList_SetItem(result,43,PyFloat_FromDouble(I->U33));
+  PyList_SetItem(result,44,PyFloat_FromDouble(I->U12));
+  PyList_SetItem(result,45,PyFloat_FromDouble(I->U13));
+  PyList_SetItem(result,46,PyFloat_FromDouble(I->U23));
+  
   return(PConvAutoNone(result));
 #endif
 }
@@ -901,7 +933,7 @@ int AtomInfoFromPyList(PyMOLGlobals *G,AtomInfoType *I,PyObject *list)
 #else
   int ok=true;
   int hetatm;
-  int ll = 0;
+  ov_size ll = 0;
   if(ok) ok = PyList_Check(list);  
   if(ok) ll = PyList_Size(list);  
   if(ok) ok = PConvPyIntToInt(PyList_GetItem(list, 0),&I->resv);   
@@ -911,7 +943,7 @@ int AtomInfoFromPyList(PyMOLGlobals *G,AtomInfoType *I,PyObject *list)
   if(ok) ok = PConvPyStrToStr(PyList_GetItem(list, 4),I->segi,sizeof(SegIdent));  
   if(ok) ok = PConvPyStrToStr(PyList_GetItem(list, 5),I->resn,sizeof(ResName));  
   if(ok) ok = PConvPyStrToStr(PyList_GetItem(list, 6),I->name,sizeof(AtomName));  
-  if(ok) ok = PConvPyStrToStr(PyList_GetItem(list, 7),I->elem,sizeof(AtomName));  
+  if(ok) ok = PConvPyStrToStr(PyList_GetItem(list, 7),I->elem,sizeof(ElemName));  
   if(ok) {
     OrthoLineType temp;
     PConvPyStrToStr(PyList_GetItem(list, 8),temp,sizeof(OrthoLineType));
@@ -979,7 +1011,14 @@ int AtomInfoFromPyList(PyMOLGlobals *G,AtomInfoType *I,PyObject *list)
     I->atomic_color = AtomInfoGetColor(G,I);
   }
   if(ok&&(ll>40)) ok = PConvPyIntToChar(PyList_GetItem(list,40),(char*)&I->has_setting);
-
+  if(ok&&(ll>46)) {
+    if(ok) ok = PConvPyFloatToFloat(PyList_GetItem(list,41),&I->U11);
+    if(ok) ok = PConvPyFloatToFloat(PyList_GetItem(list,42),&I->U22);
+    if(ok) ok = PConvPyFloatToFloat(PyList_GetItem(list,43),&I->U33);
+    if(ok) ok = PConvPyFloatToFloat(PyList_GetItem(list,44),&I->U12);
+    if(ok) ok = PConvPyFloatToFloat(PyList_GetItem(list,45),&I->U13);
+    if(ok) ok = PConvPyFloatToFloat(PyList_GetItem(list,46),&I->U23);
+  }
   return(ok);
 #endif
 }
@@ -1683,19 +1722,21 @@ int AtomInfoGetColor(PyMOLGlobals *G,AtomInfoType *at1)
   return(color);
 }
 
-
-int *AtomInfoGetSortedIndex(PyMOLGlobals *G,AtomInfoType *rec,int n,int **outdex)
+int *AtomInfoGetSortedIndex(PyMOLGlobals *G,CObject *obj,AtomInfoType *rec,int n,int **outdex)
 {
   int *index;
   int a;
+  CSetting *setting = NULL;
   index = Alloc(int,n+1);
   ErrChkPtr(G,index);
   (*outdex)=Alloc(int,n+1);
   ErrChkPtr(G,*outdex);
+  if(obj)
+    setting=obj->Setting;
 
-  if((int)SettingGet(G,cSetting_retain_order)) {
+  if(SettingGet_b(G,setting,NULL,cSetting_retain_order)) {
     UtilSortIndexGlobals(G,n,rec,index,(UtilOrderFnGlobals*)AtomInfoInOrigOrder);
-  } else if((int)SettingGet(G,cSetting_pdb_hetatm_sort)) {
+  } else if(SettingGet_b(G,setting,NULL,cSetting_pdb_hetatm_sort)) {
     UtilSortIndexGlobals(G,n,rec,index,(UtilOrderFnGlobals*)AtomInfoInOrder);    
   } else {
     UtilSortIndexGlobals(G,n,rec,index,(UtilOrderFnGlobals*)AtomInfoInOrderIgnoreHet);    
@@ -1786,7 +1827,7 @@ int AtomInfoCompare(PyMOLGlobals *G,AtomInfoType *at1,AtomInfoType *at2)
           } else {
             /* NOTE: don't forget to synchronize with below */
             if(SettingGetGlobal_b(G,cSetting_pdb_insertions_go_first)) {
-              int sl1,sl2;
+              ov_size sl1,sl2;
               sl1 = strlen(at1->resi);
               sl2 = strlen(at2->resi);
               if(sl1==sl2)
@@ -1881,7 +1922,7 @@ int AtomInfoCompareIgnoreRankHet(PyMOLGlobals *G,AtomInfoType *at1,AtomInfoType
          } else {
            /* NOTE: don't forget to synchronize with below */
            if(SettingGetGlobal_b(G,cSetting_pdb_insertions_go_first)) {
-             int sl1,sl2;
+             ov_size sl1,sl2;
              sl1 = strlen(at1->resi);
              sl2 = strlen(at2->resi);
              if(sl1==sl2)
@@ -1973,7 +2014,7 @@ int AtomInfoCompareIgnoreRank(PyMOLGlobals *G,AtomInfoType *at1,AtomInfoType *at
            } else {
              /* NOTE: don't forget to synchronize with below */
              if(SettingGetGlobal_b(G,cSetting_pdb_insertions_go_first)) {
-               int sl1,sl2;
+               ov_size sl1,sl2;
                sl1 = strlen(at1->resi);
                sl2 = strlen(at2->resi);
                if(sl1==sl2)
@@ -2069,7 +2110,7 @@ int AtomInfoCompareIgnoreHet(PyMOLGlobals *G,AtomInfoType *at1,AtomInfoType *at2
           /* NOTE: don't forget to synchronize with above */
 
             if(SettingGetGlobal_b(G,cSetting_pdb_insertions_go_first)) {
-              int sl1,sl2;
+              ov_size sl1,sl2;
               sl1 = strlen(at1->resi);
               sl2 = strlen(at2->resi);
               if(sl1==sl2)
@@ -2310,7 +2351,7 @@ static void set_protons(AtomInfoType *I,char *elem)
     case 'H': I->protons=cAN_H; break;
     case 'D': I->protons=cAN_H; break;
     case 'Q': I->protons=cAN_H; break; /* for NMR structures */
-    case 'C': I->protons=cAN_C; break;
+    case 'C': I->protons=cAN_C; break;    
     case 'N': I->protons=cAN_N; break;
     case 'O': I->protons=cAN_O; break;
     case 'F': I->protons=cAN_F; break;
@@ -2318,6 +2359,7 @@ static void set_protons(AtomInfoType *I,char *elem)
     case 'P': I->protons=cAN_P; break;
     case 'K': I->protons=cAN_K; break;
     case 'I': I->protons=cAN_I; break;
+    case 'U': I->protons=cAN_U; break;
     default: /* unrecognized element (possible garbage in this column?) */
       if(!elem)
         set_protons(I,I->name);
@@ -2325,22 +2367,51 @@ static void set_protons(AtomInfoType *I,char *elem)
     }
   } else {
     switch(e[0]) {
-    case 'C':
-      switch(e[1]) {
+    case 'A':
+     switch(e[1]) {
+      case 'G':
+      case 'g': I->protons=cAN_Ag; break;
       case 'L':
-      case 'l': I->protons=cAN_Cl; break;
-      case 'A':
-      case 'a': I->protons=cAN_Ca; break;
+      case 'l': I->protons=cAN_Al; break;
+      case 'R':
+      case 'r': I->protons=cAN_Ar; break;
+      case 'S':
+      case 's': I->protons=cAN_As; break;
       case 'U':
-      case 'u': I->protons=cAN_Cu; break;
-      }
-      break;
+      case 'u': I->protons=cAN_Au; break;
+     }
+     break;
     case 'B':
       switch(e[1]) {
-      case 'R':
-      case 'r': I->protons=cAN_Br; break;
       case 'A':
       case 'a': I->protons=cAN_Ba; break;
+      case 'E':
+      case 'e': I->protons=cAN_Be; break;
+      case 'R':
+      case 'r': I->protons=cAN_Br; break;
+      }
+      break;
+    case 'C':
+      switch(e[1]) {
+      case 'A':
+      case 'a': I->protons=cAN_Ca; break;
+      case 'D':
+      case 'd': I->protons=cAN_Cd; break;
+      case 'E':
+      case 'e': I->protons=cAN_Ce; break;
+      case 'L':
+      case 'l': I->protons=cAN_Cl; break;
+      case 'O':
+      case 'o': I->protons=cAN_Co; break;
+      case 'R':
+      case 'r': I->protons=cAN_Cr; break;
+      case 'S':
+      case 's': I->protons=cAN_Cs; break;
+      case 'U':
+      case 'u': I->protons=cAN_Cu; break;
+      default:
+        I->protons=cAN_C;  /* failsafe for wacky carbons */
+        break;
       }
       break;
     case 'F':
@@ -2349,6 +2420,14 @@ static void set_protons(AtomInfoType *I,char *elem)
       case 'e': I->protons=cAN_Fe; break;
       }
       break;
+    case 'G':
+      switch(e[1]) {
+      case 'A':
+      case 'a': I->protons=cAN_Ga; break;
+      case 'E':
+      case 'e': I->protons=cAN_Ge; break;
+      }
+      break;
     case 'H':
       switch(e[1]) {
       case 'G':
@@ -2360,8 +2439,26 @@ static void set_protons(AtomInfoType *I,char *elem)
         break;
       }
       break;
+    case 'I':
+      switch(e[1]) {
+      case 'N':
+      case 'n': I->protons=cAN_In; break;
+      }
+      break;
+    case 'K': 
+      switch(e[1]) {
+      case 'R':
+      case 'r':
+        I->protons=cAN_Kr; break;
+        break;
+      }
+      break;
     case 'L': 
       switch(e[1]) {
+      case 'I':
+      case 'i':
+        I->protons=cAN_LP; break;
+        break;
       case 'P':
       case 'p':
         I->protons=cAN_LP; break;
@@ -2372,30 +2469,61 @@ static void set_protons(AtomInfoType *I,char *elem)
       switch(e[1]) {
       case 'G':
       case 'g': I->protons=cAN_Mg; break;
+      case 'N':
+      case 'n': I->protons=cAN_Mn; break;
       }
       break;
     case 'N':
       switch(e[1]) {
       case 'A':
       case 'a': I->protons=cAN_Na; break;
+      case 'E':
+      case 'e': I->protons=cAN_Ne; break;
+      case 'I':
+      case 'i': I->protons=cAN_Ni; break;
       }
       break;
-    case 'Z':
+    case 'P':
       switch(e[1]) {
-      case 'N':
-      case 'n': I->protons=cAN_Zn; break;
+      case 'B':
+      case 'b': I->protons=cAN_Pb; break;
+      case 'D':
+      case 'd': I->protons=cAN_Pd; break;
+      case 'T':
+      case 't': I->protons=cAN_Pt; break;
       }
       break;
     case 'S':
       switch(e[1]) {
-      case 'I':
-      case 'i': I->protons=cAN_Si; break;
+      case 'B':
+      case 'b': I->protons=cAN_Sb; break;
       case 'E':
       case 'e': I->protons=cAN_Se; break;
+      case 'I':
+      case 'i': I->protons=cAN_Si; break;
+      case 'N':
+      case 'n': I->protons=cAN_Sn; break;
       case 'R':
       case 'r': I->protons=cAN_Sr; break;
       }
       break;
+    case 'T':
+      switch(e[1]) {
+      case 'I':
+      case 'i': I->protons=cAN_Ti; break;
+      case 'E':
+      case 'e': I->protons=cAN_Te; break;
+      case 'L':
+      case 'l': I->protons=cAN_Tl; break;
+      }
+      break;
+
+    case 'Z':
+      switch(e[1]) {
+      case 'N':
+      case 'n': I->protons=cAN_Zn; break;
+      }
+      break;
     default: /* unrecognized element (possible garbage?) */
       if(!elem)
         set_protons(I,I->name);
@@ -2685,26 +2813,60 @@ void AtomInfoAssignParameters(PyMOLGlobals *G,AtomInfoType *I)
 
   switch(I->protons) {
   case cAN_H:  vdw=1.20F; break;
-  case cAN_N:  vdw=1.55F; break;
-  case cAN_Na: vdw=2.27F; break;
-  case cAN_Cu: vdw=1.40F; break; 
-  case cAN_Cl: vdw=1.75F; break;
+  case cAN_He: vdw=1.40F; break;
+
+  case cAN_Li: vdw=1.82F; break;
+
+  case cAN_B:  vdw=1.85F; break; 
   case cAN_C:  vdw=1.70F; break; 
+  case cAN_N:  vdw=1.55F; break;
   case cAN_O:  vdw=1.52F; break;
-  case cAN_I:	vdw=1.98F; break;
-  case cAN_P:	vdw=1.80F; break;
-  case cAN_B:	vdw=1.85F; break; 
-  case cAN_Br:	vdw=1.85F; break; 
-  case cAN_S:  vdw=1.80F; break;
-  case cAN_Se: vdw=1.90F; break;
   case cAN_F:  vdw=1.47F; break;
-  case cAN_Fe: vdw=1.80F; break; 
-  case cAN_K:  vdw=2.75F; break;
-  case cAN_Mn: vdw=1.73F; break;
+  case cAN_Ne: vdw=1.54F; break;
+
+  case cAN_Na: vdw=2.27F; break;
   case cAN_Mg: vdw=1.73F; break;
+  case cAN_Al: vdw=2.00F; break; 
+  case cAN_Si: vdw=2.10F; break;
+  case cAN_P:  vdw=1.80F; break;
+  case cAN_S:  vdw=1.80F; break;
+  case cAN_Cl: vdw=1.75F; break;
+  case cAN_Ar: vdw=1.88F; break;
+
+  case cAN_K:  vdw=2.75F; break;
+
+  case cAN_Mn: vdw=1.73F; break;
+  case cAN_Ni: vdw=1.63F; break;
+  case cAN_Cu: vdw=1.40F; break; 
   case cAN_Zn: vdw=1.39F; break;
+  case cAN_Ga: vdw=1.87F; break;
+
+  case cAN_As: vdw=1.85F; break;
+  case cAN_Se: vdw=1.90F; break;
+  case cAN_Br: vdw=1.85F; break;
+  case cAN_Kr: vdw=2.02F; break;
+ 
+  case cAN_Pd: vdw=1.63F; break;
+  case cAN_Ag: vdw=1.72F; break;
+  case cAN_Cd: vdw=1.58F; break;
+  case cAN_In: vdw=1.93F; break;
+  case cAN_Sn: vdw=2.17F; break;
+
+  case cAN_Te: vdw=2.06F; break;
+  case cAN_I:  vdw=1.98F; break;
+  case cAN_Xe: vdw=2.16F; break;
+
+  case cAN_Pt: vdw=1.75F; break;
+  case cAN_Au: vdw=1.66F; break;
+  case cAN_Hg: vdw=1.55F; break;
+  case cAN_Tl: vdw=1.96F; break;
+  case cAN_Pb: vdw=2.02F; break;
+
+  case cAN_U:  vdw=1.86F; break;
+
   case cAN_LP: vdw=0.5F; break; /* lone pairs @ 0.5 same as MOE? */
-  default: vdw=1.80F; break;
+
+  default: vdw=1.80F; break; /* default radius for known atoms with unknown radii */
   }
   
   if(SettingGet(G,cSetting_legacy_vdw_radii)) { /* ver<0.75, old, incorrect VDW */
@@ -2722,9 +2884,13 @@ void AtomInfoAssignParameters(PyMOLGlobals *G,AtomInfoType *I)
 
   if(I->vdw==0.0) /* only assigned if not yet assigned */
     I->vdw = vdw;
+
+#if 0
   if(!I->protons)
     I->protons = cAN_C; /* default assumption */
-  else if(I->protons==cAN_H) 
+#endif
+  
+  if(I->protons==cAN_H) 
     I->hydrogen = true;
   /*  printf("I->name %s I->priority %d\n",I->name,I->priority);*/
 }
