@@ -31,7 +31,8 @@ Z* -------------------------------------------------------------------
 #define cAtomFlag_fix           0x00000008
 /* FLAG 4 - Exclude these atoms when performing simulation, minimization */
 #define cAtomFlag_exclude       0x00000010
-
+/* FLAG 5 - Study atoms  */
+#define cAtomFlag_study         0x00000020
 
 /* FLAGS 4-7 are reserved for additional molecular modeling tasks */
 
@@ -71,6 +72,7 @@ Z* -------------------------------------------------------------------
 #define cResnLen 5
 #define cResiLen 5
 #define cAtomNameLen 4
+#define cElemNameLen 4
 #define cSegiLen 4
 #define cTextTypeLen 20
 #define cLabelTypeLen 20
@@ -84,29 +86,65 @@ Z* -------------------------------------------------------------------
 #define cAN_LP  0
 #define cAN_H   1
 #define cAN_He  2
+#define cAN_Li  3
+#define cAN_Be  4
 #define cAN_B   5
 #define cAN_C   6
 #define cAN_N   7
 #define cAN_O   8
 #define cAN_F   9
+#define cAN_Ne 10
 #define cAN_Na 11
 #define cAN_Mg 12
+#define cAN_Al 13
 #define cAN_Si 14
 #define cAN_P  15
 #define cAN_S  16
 #define cAN_Cl 17
+#define cAN_Ar 18
 #define cAN_K  19
 #define cAN_Ca 20
+
+#define cAN_Ti 22
+
+#define cAN_Cr 24
 #define cAN_Mn 25
 #define cAN_Fe 26
+#define cAN_Co 27
+#define cAN_Ni 28
 #define cAN_Cu 29
 #define cAN_Zn 30
+#define cAN_Ga 31
+#define cAN_Ge 32
+#define cAN_As 33
 #define cAN_Se 34
 #define cAN_Br 35
+#define cAN_Kr 36
+
+#define cAN_Rb 37
 #define cAN_Sr 38
+
+#define cAN_Pd 46
+#define cAN_Ag 47
+#define cAN_Cd 48
+#define cAN_In 49
+#define cAN_Sn 50
+#define cAN_Sb 51
+#define cAN_Te 52
 #define cAN_I  53
+#define cAN_Xe 54
+#define cAN_Cs 55
 #define cAN_Ba 56
+
+#define cAN_Ce 58
+
+#define cAN_Pt 78
+#define cAN_Au 79
 #define cAN_Hg 80
+#define cAN_Tl 81
+#define cAN_Pb 82
+
+#define cAN_U  92
 
 typedef char Chain[2];
 typedef char SSType[2];
@@ -114,6 +152,8 @@ typedef char SegIdent[cSegiLen+1];
 typedef char ResIdent[cResiLen+1];
 typedef char ResName[cResnLen+1];
 typedef char AtomName[cAtomNameLen+1];
+
+typedef char ElemName[cElemNameLen+1];
 #if 0
 typedef char TextType[cTextTypeLen+1];
 typedef char LabelType[cLabelTypeLen+1];
@@ -126,6 +166,7 @@ typedef struct {
   int order;
   int id;
   int unique_id; 
+  int temp1; 
   short int stereo; /* to preserve 2D rep */
   short int has_setting; /* setting based on unique_id */
 } BondType;
@@ -177,8 +218,9 @@ typedef struct AtomInfoType {
   SegIdent segi;
   ResName resn;
   AtomName name;
-  AtomName elem;
+  ElemName elem;
   SSType ssType; /* blank or 'L' = turn/loop, 'H' = helix, 'S' = beta-strand/sheet */
+  float U11, U22, U33, U12, U13, U23;
 } AtomInfoType;
 
 void AtomInfoFree(PyMOLGlobals *G);
@@ -188,6 +230,7 @@ void AtomInfoCopy(PyMOLGlobals *G,AtomInfoType *src,AtomInfoType *dst);
 int AtomInfoReserveUniqueID(PyMOLGlobals *G,int unique_id);
 int AtomInfoIsUniqueIDActive(PyMOLGlobals *G,int unique_id);
 int AtomInfoGetNewUniqueID(PyMOLGlobals *G);
+void AtomInfoCleanAtomName(char *name);
 
 int AtomInfoCheckSetting(PyMOLGlobals *G, AtomInfoType *ai, int setting_id);
 int AtomInfoGetSetting_b(PyMOLGlobals *G, AtomInfoType *ai, int setting_id, int current, int *effective);
@@ -204,7 +247,7 @@ int AtomInfoGetBondSetting_f(PyMOLGlobals *G, BondType *ai, int setting_id, floa
 int AtomInfoGetBondSetting_color(PyMOLGlobals *G, BondType *ai, int setting_id, int current, int *effective);
 
 int AtomInfoCheckUniqueID(PyMOLGlobals *G, AtomInfoType *ai);
-int *AtomInfoGetSortedIndex(PyMOLGlobals *G,AtomInfoType *rec,int n,int **outdex);
+int *AtomInfoGetSortedIndex(PyMOLGlobals *G,CObject *obj,AtomInfoType *rec,int n,int **outdex);
 void AtomInfoAssignParameters(PyMOLGlobals *G,AtomInfoType *I);
 void AtomInfoFreeSortedIndexes(PyMOLGlobals *G,int *index,int *outdex);
 void AtomInfoPrimeColors(PyMOLGlobals *G);
