@@ -25,7 +25,6 @@ Z* -------------------------------------------------------------------
 #include"Color.h"
 #include"PConv.h"
 #include"P.h"
-#include"ButMode.h"
 #include"Matrix.h"
 #include"Sphere.h"
 #include"Util.h"
@@ -41,8 +40,10 @@ Z* -------------------------------------------------------------------
 #include"RepLabel.h"
 #include"RepNonbonded.h"
 #include"RepNonbondedSphere.h"
+#include"RepEllipsoid.h"
 
 #include"PyMOLGlobals.h"
+#include"PyMOLObject.h"
 
 static void CoordSetUpdate(CoordSet *I,int state);
 
@@ -559,7 +560,8 @@ void CoordSetFracToReal(CoordSet *I,CCrystal *cryst)
 }
 
 /*========================================================================*/
-void CoordSetAtomToPDBStrVLA(PyMOLGlobals *G,char **charVLA,int *c,AtomInfoType *ai,
+void CoordSetAtomToPDBStrVLA(PyMOLGlobals *G,char **charVLA,int *c,
+                             AtomInfoType *ai,
                              float *v,int cnt,PDBInfoRec *pdb_info)
 {
   char *aType;
@@ -567,16 +569,26 @@ void CoordSetAtomToPDBStrVLA(PyMOLGlobals *G,char **charVLA,int *c,AtomInfoType
   ResIdent resi; 
   ResName resn;
   Chain chain;
+  char formalCharge[4];
   int rl;
   int literal = (int)SettingGet(G,cSetting_pdb_literal_names);
   int reformat = (int)SettingGet(G,cSetting_pdb_reformat_names_mode);
   WordType x,y,z;
 
+  formalCharge[0]=0;
   strcpy(resn,ai->resn); 
   if(SettingGetGlobal_b(G,cSetting_pdb_truncate_residue_name)) {
     resn[3]=0; /* enforce 3-letter residue name in PDB files */
   }
 
+  if(SettingGetGlobal_b(G,cSetting_pdb_formal_charges)) {
+    if((ai->formalCharge>0)&&(ai->formalCharge<10)) {
+      sprintf(formalCharge,"%d+",ai->formalCharge);
+    } else if((ai->formalCharge<0)&&(ai->formalCharge>-10)) {
+      sprintf(formalCharge,"%d-",-ai->formalCharge);
+    }
+  }
+
   if(ai->hetatm)
 	aType=sHETATM;
   else
@@ -732,13 +744,15 @@ void CoordSetAtomToPDBStrVLA(PyMOLGlobals *G,char **charVLA,int *c,AtomInfoType
   if(cnt>99998)
     cnt=99998;
 
+  name[4] = 0;
+
   if((!pdb_info)||(!pdb_info->is_pqr_file)) { /* relying upon short-circuit */
     sprintf(x,"%8.3f",v[0]); x[8]=0;
     sprintf(y,"%8.3f",v[1]); y[8]=0;
     sprintf(z,"%8.3f",v[2]); z[8]=0;
-    (*c)+=sprintf((*charVLA)+(*c),"%6s%5i %-4s%1s%-4s%1s%5s   %s%s%s%6.2f%6.2f      %-4s%2s\n",
+    (*c)+=sprintf((*charVLA)+(*c),"%6s%5i %-4s%1s%-4s%1s%5s   %s%s%s%6.2f%6.2f      %-4s%2s%2s\n",
                   aType,cnt+1,name,ai->alt,resn,
-                  ai->chain,resi,x,y,z,ai->q,ai->b,ai->segi,ai->elem);
+                  ai->chain,resi,x,y,z,ai->q,ai->b,ai->segi,ai->elem,formalCharge);
   } else {
     if(pdb_info->is_pqr_file && pdb_info->pqr_workarounds) {
       int non_num = false;
@@ -765,9 +779,15 @@ void CoordSetAtomToPDBStrVLA(PyMOLGlobals *G,char **charVLA,int *c,AtomInfoType
       chain[0] = ai->chain[0];
       chain[1] = 0;
     }
-    sprintf(x,"%8.3f",v[0]); x[8]=0;
+    sprintf(x,"%8.3f",v[0]); 
+    if(x[0]!=32) sprintf(x," %7.2f",v[0]); 
+    x[8]=0;
     sprintf(y,"%8.3f",v[1]); y[8]=0;
-    sprintf(z,"%8.3f",v[2]); z[8]=0;
+    if(y[0]!=32) sprintf(y," %7.2f",v[1]); 
+    y[8]=0;
+    sprintf(z,"%8.3f",v[2]); 
+    if(z[0]!=32) sprintf(z," %7.2f",v[2]); 
+    z[8]=0;
       
     (*c)+=sprintf((*charVLA)+(*c),"%6s%5i %-4s%1s%-4s%1s%5s   %s%s%s %11.8f %7.3f\n",
                   aType,cnt+1,name,ai->alt,resn,
@@ -802,6 +822,22 @@ PyObject *CoordSetAtomToChemPyAtom(PyMOLGlobals *G,AtomInfoType *ai,float *v,int
     PConvStringToPyObjAttr(atom,"segi",ai->segi);
     PConvFloatToPyObjAttr(atom,"q",ai->q);
     PConvFloatToPyObjAttr(atom,"b",ai->b);
+    {
+      float tmp_array[6];
+      tmp_array[0] = ai->U11;
+      tmp_array[1] = ai->U22;
+      tmp_array[2] = ai->U33;
+      tmp_array[3] = ai->U12;
+      tmp_array[4] = ai->U13;
+      tmp_array[5] = ai->U23;
+      {
+		  PyObject *tmp_obj = PConvFloatArrayToPyList(tmp_array,6);
+      if(tmp_obj) {
+        PyObject_SetAttrString(atom,"u_aniso",tmp_obj);
+        Py_XDECREF(tmp_obj);
+      }
+	  }
+    }
     PConvFloatToPyObjAttr(atom,"vdw",ai->vdw);
     PConvFloatToPyObjAttr(atom,"elec_radius",ai->elec_radius);
     PConvFloatToPyObjAttr(atom,"partial_charge",ai->partialCharge);
@@ -864,8 +900,10 @@ void CoordSetInvalidateRep(CoordSet *I,int type,int level)
 {
   int a;
 
-  /*  printf("inv %d %d \n",type,level);fflush(stdout);*/
 
+  if(level>=cRepInvVisib) {
+    I->Obj->RepVisCacheValid = false;
+  }
   if(level==cRepInvVisib) {
     if(SettingGet_b(I->State.G,I->Setting,I->Obj->Obj.Setting,
                     cSetting_cartoon_side_chain_helper)) {
@@ -902,34 +940,64 @@ void CoordSetInvalidateRep(CoordSet *I,int type,int level)
       FreeP(I->Spheroid);
       FreeP(I->SpheroidNormal);
     }
+
   if(level>=cRepInvColor) 
 	 VLAFreeP(I->Color);
+
   if(type>=0) { /* representation specific */
 	 if(type<I->NRep)	{
-      a=type;
-      if(I->Rep[a]) {
-        if(I->Rep[a]->fInvalidate && (level<cRepInvPurge))
-          I->Rep[a]->fInvalidate(I->Rep[a],I,level);
-        else {
-          I->Rep[a]->fFree(I->Rep[a]);
-          I->Rep[a] = NULL;
-        }
-      }
-      if(level>=cRepInvVisib) /* make active if visibility has changed */
-        I->Active[type]=true;
+       int eff_level = level;
+       a=type;
+       if(level==cRepInvPick) {
+         switch(a) {
+         case cRepSurface:
+         case cRepMesh:
+         case cRepDot:
+           /* skip the expensive to recompute, non-pickable
+              representations */
+           break;
+         default: /* default behavior is to blow away the representation */
+           eff_level = cRepInvRep;
+           break;
+         }
+       }
+       if(I->Rep[a]) {
+         if(I->Rep[a]->fInvalidate && (eff_level<cRepInvPurge))
+           I->Rep[a]->fInvalidate(I->Rep[a],I,eff_level);
+         else if(eff_level>=cRepInvExtColor) {
+           I->Rep[a]->fFree(I->Rep[a]);
+           I->Rep[a] = NULL;
+         }
+       }
+       if(eff_level>=cRepInvVisib) /* make active if visibility has changed */
+         I->Active[type]=true;
 	 }
   } else { /* all representations are affected */
 	 for(a=0;a<I->NRep;a++)	{
-      if(level>=cRepInvVisib) /* make active if visibility has changed */
-        I->Active[a]=true;
-		if(I->Rep[a]) {
-          if(I->Rep[a]->fInvalidate && (level<cRepInvPurge))
-            I->Rep[a]->fInvalidate(I->Rep[a],I,level);
-          else {
-            I->Rep[a]->fFree(I->Rep[a]);
-            I->Rep[a] = NULL;
-          }
-		}
+       int eff_level = level;
+       if(level==cRepInvPick) {
+         switch(a) {
+         case cRepSurface:
+         case cRepMesh:
+         case cRepDot:
+           /* skip the expensive to recompute, non-pickable
+              representations */
+           break;
+         default: /* default behavior is to blow away the representation */
+           eff_level = cRepInvRep;
+           break;
+         }
+       }
+       if(eff_level>=cRepInvVisib) /* make active if visibility has changed */
+         I->Active[a]=true;
+       if(I->Rep[a]) {
+         if(I->Rep[a]->fInvalidate && (eff_level<cRepInvPurge))
+           I->Rep[a]->fInvalidate(I->Rep[a],I,eff_level);
+         else if(eff_level>=cRepInvExtColor) {
+           I->Rep[a]->fFree(I->Rep[a]);
+           I->Rep[a] = NULL;
+         }
+       }
 	 }
   }
   if(level>=cRepInvCoord) { /* if coordinates change, then this map becomes invalid */
@@ -963,30 +1031,28 @@ static void CoordSetUpdate(CoordSet *I,int state)
   
   if(Feedback(I->Obj->Obj.G,FB_CoordSet,FB_Blather)) {
     printf(" CoordSetUpdate-Entered: object %s state %d cset %p\n",
-           I->Obj->Obj.Name, state, I);
+           I->Obj->Obj.Name, state, (void*)I);
   }
 
-  if(!I->Color) /* colors invalidated */
-	 {
-		I->Color=VLAlloc(int,I->NIndex);
-		if(I->Color) {
-        if(obj->DiscreteFlag)
-          for(a=0;a<I->Obj->NAtom;a++) {
-            if(obj->DiscreteCSet[a]==I) {
-              i = obj->DiscreteAtmToIdx[a];
-              if(i>=0) 
-                I->Color[i]=obj->AtomInfo[a].color;
-            }
+  if(!I->Color) /* colors invalidated */ {
+    I->Color=VLAlloc(int,I->NIndex);
+    if(I->Color) {
+      if(obj->DiscreteFlag)
+        for(a=0;a<I->Obj->NAtom;a++) {
+          if(obj->DiscreteCSet[a]==I) {
+            i = obj->DiscreteAtmToIdx[a];
+            if(i>=0) 
+              I->Color[i]=obj->AtomInfo[a].color;
           }
-        else 
-          for(a=0;a<I->Obj->NAtom;a++)
-            {
-              i=I->AtmToIdx[a];
-              if(i>=0) 
-                I->Color[i]=obj->AtomInfo[a].color;
-            }
-		}
-	 }
+        }
+      else 
+        for(a=0;a<I->Obj->NAtom;a++) {
+          i=I->AtmToIdx[a];
+          if(i>=0) 
+            I->Color[i]=obj->AtomInfo[a].color;
+        }
+    }
+  }
   OrthoBusyFast(I->State.G,0,I->NRep);
   RepUpdateMacro(I, cRepLine,            RepWireBondNew        , state );
   RepUpdateMacro(I, cRepCyl,             RepCylBondNew         , state );
@@ -999,6 +1065,7 @@ static void CoordSetUpdate(CoordSet *I,int state)
   RepUpdateMacro(I, cRepLabel,           RepLabelNew           , state );
   RepUpdateMacro(I, cRepNonbonded,       RepNonbondedNew       , state );
   RepUpdateMacro(I, cRepNonbondedSphere, RepNonbondedSphereNew , state );
+  RepUpdateMacro(I, cRepEllipsoid,       RepEllipsoidNew       , state );
 
   for(a=0;a<I->NRep;a++) 
     if(!I->Rep[a])
@@ -1008,7 +1075,7 @@ static void CoordSetUpdate(CoordSet *I,int state)
   OrthoBusyFast(I->State.G,1,1);
   if(Feedback(I->Obj->Obj.G,FB_CoordSet,FB_Blather)) {
     printf(" CoordSetUpdate-Leaving: object %s state %d cset %p\n",
-           I->Obj->Obj.Name, state, I);
+           I->Obj->Obj.Name, state, (void*)I);
   }
 
 }
@@ -1051,8 +1118,6 @@ void CoordSetRender(CoordSet *I,RenderInfo *info)
     " CoordSetRender: entered (%p).\n",(void*)I
     ENDFD;
 
-  if((!pass)&&I->Name[0])
-    ButModeCaption(G,I->Name);
   if((!pass)&&I->SculptCGO&&(I->Obj->Obj.RepVis[cRepCGO])) {
     if(ray) {
       CGORenderRay(I->SculptCGO,ray,
@@ -1163,6 +1228,15 @@ void CoordSetRender(CoordSet *I,RenderInfo *info)
                 } else if(pass==1)
                   r->fRender(r,info);
                 break;
+              case cRepEllipsoid: /* render spheres differently depending on transparency */
+                if(SettingGet_f(G,r->cs->Setting,
+                                r->obj->Setting,
+                                cSetting_sphere_transparency)>0.0001) {
+                  if(pass==-1)
+                    r->fRender(r,info);                                
+                } else if(pass==1)
+                  r->fRender(r,info);
+                break;
               case cRepCartoon:
                 if(info->alpha_cgo) {
                   if(pass==1)
@@ -1324,23 +1398,22 @@ void CoordSetExtendIndices(CoordSet *I,int nAtom)
       }
     }
   }
-  if(I->NAtIndex<nAtom)
-	 {
-		if(I->AtmToIdx) {
-        I->AtmToIdx = Realloc(I->AtmToIdx,int,nAtom);
-        if(nAtom){
-          ErrChkPtr(I->State.G,I->AtmToIdx);
-          for(a=I->NAtIndex;a<nAtom;a++)
-            I->AtmToIdx[a]=-1;
-        }
-        I->NAtIndex = nAtom;
-      } else if(!obj->DiscreteFlag) {
-        I->AtmToIdx = Alloc(int,nAtom);
-        for(a=0;a<nAtom;a++)
+  if(I->NAtIndex<nAtom) {
+    if(I->AtmToIdx) {
+      I->AtmToIdx = Realloc(I->AtmToIdx,int,nAtom);
+      if(nAtom) {
+        ErrChkPtr(I->State.G,I->AtmToIdx);
+        for(a=I->NAtIndex;a<nAtom;a++)
           I->AtmToIdx[a]=-1;
-        I->NAtIndex = nAtom;
-		}
-	 }
+      }
+      I->NAtIndex = nAtom;
+    } else if(!obj->DiscreteFlag) {
+      I->AtmToIdx = Alloc(int,nAtom);
+      for(a=0;a<nAtom;a++)
+        I->AtmToIdx[a]=-1;
+      I->NAtIndex = nAtom;
+    }
+  }
 }
 /*========================================================================*/
 void CoordSetAppendIndices(CoordSet *I,int offset) 
