@@ -127,7 +127,7 @@ static int AlignmentFindTag(PyMOLGlobals *G,AtomInfoType *ai,int sele,int n_more
 int ObjectAlignmentAsStrVLA(PyMOLGlobals *G,ObjectAlignment *I, int state,int format, char **str_vla)
 {
   int ok=true;
-  int len = 0;
+  ov_size len = 0;
   char *vla = VLAlloc(char, 1000);
   int force_update = false;
   int active_only = false;
@@ -156,7 +156,7 @@ int ObjectAlignmentAsStrVLA(PyMOLGlobals *G,ObjectAlignment *I, int state,int fo
         int align_sele = SelectorIndexByName(G,I->Obj.Name);
         if(align_sele>=0) {
           int nRow = 0;
-          int nCol = 0;
+          ov_size nCol = 0;
           CSeqRow *row_vla = NULL,*row;
           char *cons_str = NULL;
           void *hidden = NULL;
@@ -384,7 +384,7 @@ int ObjectAlignmentAsStrVLA(PyMOLGlobals *G,ObjectAlignment *I, int state,int fo
             { 
               int block_width = 76 - (max_name_len +1);
               int done = false;
-              int seq_len = 0;
+              ov_size seq_len = 0;
               int a;
               while(!done) {
                 done = true;
@@ -556,7 +556,7 @@ static int *AlignmentMerge(PyMOLGlobals *G, int *curVLA, int *newVLA, ObjectMole
           
           while( (cur_start<n_cur) && !curVLA[cur_start]) 
             cur_start++;
-          while( (new_start<n_cur) && !newVLA[new_start]) 
+          while( (new_start<n_new) && !newVLA[new_start]) 
             new_start++;
           
           if(newVLA[new_start]) { /* default is to insert new first...*/
@@ -1158,11 +1158,11 @@ static ObjectAlignment *ObjectAlignmentNew(PyMOLGlobals *G)
   I->SelectionState=-1;
 
   I->Obj.type = cObjectAlignment;
-  I->Obj.fFree = (void (*)(struct CObject *))ObjectAlignmentFree;
-  I->Obj.fUpdate =(void (*)(struct CObject *)) ObjectAlignmentUpdate;
-  I->Obj.fRender =(void (*)(struct CObject *, RenderInfo *))ObjectAlignmentRender;
-  I->Obj.fGetNFrame = (int (*)(struct CObject *)) ObjectAlignmentGetNState;
-  I->Obj.fInvalidate = (void (*)(struct CObject *,int rep, int level, int state))
+  I->Obj.fFree = (void (*)(CObject *))ObjectAlignmentFree;
+  I->Obj.fUpdate =(void (*)(CObject *)) ObjectAlignmentUpdate;
+  I->Obj.fRender =(void (*)(CObject *, RenderInfo *))ObjectAlignmentRender;
+  I->Obj.fGetNFrame = (int (*)(CObject *)) ObjectAlignmentGetNState;
+  I->Obj.fInvalidate = (void (*)(CObject *,int rep, int level, int state))
     ObjectAlignmentInvalidate;
 
   return(I);
