@@ -21,6 +21,8 @@ Z* -------------------------------------------------------------------
 #include"Vector.h"
 #include"Color.h"
 
+/* NOTE: "Dist" names & symbols should be updated to "Measurement" */
+
 typedef struct ObjectDist {
   CObject Obj;
   struct DistSet **DSet;
@@ -30,15 +32,19 @@ typedef struct ObjectDist {
 
 ObjectDist *ObjectDistNewFromSele(PyMOLGlobals *G,ObjectDist *oldObj,
                                   int sele1,int sele2,int mode,float cutoff,
-                                  int labels,int reset,float *result);
+                                  int labels,int reset,float *result,int state);
 
 ObjectDist *ObjectDistNewFromAngleSele(PyMOLGlobals *G,ObjectDist *oldObj,
                                        int sele1,int sele2,int sele3, int mode,
-                                       int labels,float *result, int reset);
+                                       int labels,float *result, int reset,int state);
 
 ObjectDist *ObjectDistNewFromDihedralSele(PyMOLGlobals *G,ObjectDist *oldObj,
-                                        int sele1, int sele2, int sele3, int sele4,
-                                          int mode, int labels, float *result, int reset);
+                                          int sele1, int sele2, int sele3, int sele4,
+                                          int mode, int labels, float *result,
+                                          int reset, int state);
+
+int ObjectDistGetLabelTxfVertex(ObjectDist *I,int state,int index,float *v);
+int ObjectDistMoveLabel(ObjectDist *I,int state,int index,float *v,int mode,int log);
 
 ObjectDist *ObjectDistNew(PyMOLGlobals *G);
 void ObjectDistInvalidateRep(ObjectDist *I,int rep);
