@@ -435,7 +435,8 @@ static int ObjectGadgetRampInterpolateWithSpecial(ObjectGadgetRamp *I,
 
 int ObjectGadgetRampInterpolate(ObjectGadgetRamp *I,float level,float *color)
 {
-  return _ObjectGadgetRampInterpolate(I,level,color,I->Color,I->Extreme);
+  int result = _ObjectGadgetRampInterpolate(I,level,color,I->Color,I->Extreme);
+  return result;
 }
 
 PyObject *ObjectGadgetRampAsPyList(ObjectGadgetRamp *I)
@@ -579,26 +580,45 @@ int ObjectGadgetRampInterVertex(ObjectGadgetRamp *I,float *pos,float *color,int
       }
       if(ok) ok = (I->Mol!=NULL);      
       if(ok) {
-        int index = ObjectMoleculeGetNearestAtomIndex(I->Mol, pos, cutoff, state, &dist);
-        if(index>=0) {
-          float *atomic =  ColorGet(I->Gadget.Obj.G,I->Mol->AtomInfo[index].color);
-          float *object =  ColorGet(I->Gadget.Obj.G,I->Mol->Obj.Color);
-          
-          if(sub_vdw) {
-            dist-=I->Mol->AtomInfo[index].vdw;
-            if(dist<0.0F)
-              dist = 0.0F;
-          }
-          
-          if(!ObjectGadgetRampInterpolateWithSpecial(I,dist,color,atomic,
-                                                     object,pos,state,false)) {
-            copy3f(I->Color,color);
+        if(SettingGet_b(I->Gadget.Obj.G,I->Gadget.Obj.Setting,NULL,cSetting_ramp_blend_nearby_colors)) {
+          float atomic[3];
+          int index = ObjectMoleculeGetNearestBlendedColor(I->Mol, pos, cutoff, state, &dist, atomic, sub_vdw);
+          if(index>=0) {
+            float *object =  ColorGetRaw(I->Gadget.Obj.G,I->Mol->Obj.Color);
+            
+            if(!ObjectGadgetRampInterpolateWithSpecial(I,dist,color,atomic,
+                                                       object,pos,state,false)) {
+              copy3f(I->Color,color);
+            }
+          } else {
+            float white[3] = {1.0F, 1.0F, 1.0F};
+            if(!ObjectGadgetRampInterpolateWithSpecial(I,cutoff+1.0F,color,white,
+                                                       white,pos,state,false)) {
+              copy3f(I->Color,color);
+            }
           }
         } else {
-          float white[3] = {1.0F, 1.0F, 1.0F};
-          if(!ObjectGadgetRampInterpolateWithSpecial(I,cutoff+1.0F,color,white,
-                                                     white,pos,state,false)) {
-            copy3f(I->Color,color);
+          int index = ObjectMoleculeGetNearestAtomIndex(I->Mol, pos, cutoff, state, &dist);
+          if(index>=0) {
+            float *atomic =  ColorGetRaw(I->Gadget.Obj.G,I->Mol->AtomInfo[index].color);
+            float *object =  ColorGetRaw(I->Gadget.Obj.G,I->Mol->Obj.Color);
+            
+            if(sub_vdw) {
+              dist-=I->Mol->AtomInfo[index].vdw;
+              if(dist<0.0F)
+                dist = 0.0F;
+            }
+            
+            if(!ObjectGadgetRampInterpolateWithSpecial(I,dist,color,atomic,
+                                                       object,pos,state,false)) {
+              copy3f(I->Color,color);
+            }
+          } else {
+            float white[3] = {1.0F, 1.0F, 1.0F};
+            if(!ObjectGadgetRampInterpolateWithSpecial(I,cutoff+1.0F,color,white,
+                                                       white,pos,state,false)) {
+              copy3f(I->Color,color);
+            }
           }
         }
       }
@@ -620,8 +640,6 @@ int ObjectGadgetRampInterVertex(ObjectGadgetRamp *I,float *pos,float *color,int
   return(ok);
 }
 
-
-
 static void ObjectGadgetRampUpdateCGO(ObjectGadgetRamp *I,GadgetSet *gs)
 {
   CGO *cgo;
@@ -645,8 +663,9 @@ static void ObjectGadgetRampUpdateCGO(ObjectGadgetRamp *I,GadgetSet *gs)
   CGOEnd(cgo);
 
   CGOColor(cgo,1.0F,1.0F,1.0F);
-  CGOFontScale(cgo,I->text_scale_h,I->text_scale_v);
 
+#ifndef _PYMOL_NOPY
+  CGOFontScale(cgo,I->text_scale_h,I->text_scale_v);
 
   if(I->Level&&I->NLevel) {
     /*
@@ -663,6 +682,7 @@ static void ObjectGadgetRampUpdateCGO(ObjectGadgetRamp *I,GadgetSet *gs)
     ShapeFVertex(cgo,REL,12);
     CGOWriteLeft(cgo,buffer);
   }
+#endif
 
   CGOBegin(cgo,GL_TRIANGLE_STRIP);
   ShapeNormal(cgo,LKP,2);
@@ -683,7 +703,10 @@ static void ObjectGadgetRampUpdateCGO(ObjectGadgetRamp *I,GadgetSet *gs)
           if(I->Special&&(I->Special[a]<0)) {
             CGOColorv(cgo,white);
           } else {
-            CGOColorv(cgo,I->Color+3*a);
+            float tmp[3],*src = I->Color+3*a;
+            copy3f(src,tmp);
+            ColorClampColor(I->Gadget.Obj.G,tmp);
+            CGOColorv(cgo,tmp);
           }
           
           *(p++) = I->border + (I->width * a)/(I->NLevel-1);
@@ -708,7 +731,10 @@ static void ObjectGadgetRampUpdateCGO(ObjectGadgetRamp *I,GadgetSet *gs)
           if(I->Special&&(I->Special[0]<0)) {
             CGOColorv(cgo,white);
           } else {
-            CGOColorv(cgo,I->Color);
+            float tmp[3],*src = I->Color;
+            copy3f(src,tmp);
+            ColorClampColor(I->Gadget.Obj.G,tmp);
+            CGOColorv(cgo,tmp);
           }
           
           *(p++) = I->border + (I->width * a);
@@ -820,8 +846,10 @@ static void ObjectGadgetRampUpdateCGO(ObjectGadgetRamp *I,GadgetSet *gs)
   CGOFree(gs->ShapeCGO);
   gs->ShapeCGO = cgo;
 
+#ifndef _PYMOL_NOPY
   CGOPreloadFonts(gs->ShapeCGO);
-  
+#endif
+
   cgo = CGONewSized(I->Gadget.Obj.G,100);
   CGODotwidth(cgo,5);
   CGOPickColor(cgo,0,cPickableGadget);
@@ -877,7 +905,6 @@ static void ObjectGadgetRampUpdateCGO(ObjectGadgetRamp *I,GadgetSet *gs)
   gs->PickShapeCGO = cgo;
 }
 
-#ifndef _PYMOL_NOPY
 static void ObjectGadgetRampBuild(ObjectGadgetRamp *I)
 {
   GadgetSet *gs = NULL;
@@ -945,11 +972,11 @@ VV(    I->width+I->border,I->text_border-(I->border+I->height), I->border+I->tex
   gs->Obj = (ObjectGadget*)I;
   gs->State = 0;
 
+  
   ObjectGadgetRampUpdateCGO(I,gs);
   gs->fUpdate(gs);
-  
+
 }
-#endif
 
 /*========================================================================*/
 void ObjectGadgetRampUpdate(ObjectGadgetRamp *I)
@@ -1061,28 +1088,21 @@ static int ObjectGadgetRampHandleInputColors(ObjectGadgetRamp *I)
 /*========================================================================*/
 ObjectGadgetRamp *ObjectGadgetRampMapNewAsDefined(PyMOLGlobals *G,
                                                   ObjectMap *map,
-                                                  PyObject *level,
-                                                  PyObject *color,int map_state,
+                                                  float *level_vla,
+                                                  float *color_vla,int map_state,
                                                   float *vert_vla,float beyond,float within,
-                                                  float sigma,int zero)
+                                                  float sigma,int zero,int calc_mode)
 {
-#ifdef _PYMOL_NOPY
-  return NULL;
-#else
+
 
   ObjectGadgetRamp *I;
   int ok = true;
   I = ObjectGadgetRampNew(G);
   I->RampType = cRampMap;
 
-  PBlock(G);
-  if(ok) {
-    if(PyList_Check(color))
-      ok = PConvPyList3ToFloatVLA(color,&I->Color);
-    else if(PyInt_Check(color)) {
-      ok = PConvPyIntToInt(color,&I->CalcMode);      
-    }
-  }
+  if(ok) I->Color = color_vla;
+  if(ok) I->CalcMode = calc_mode;
+
   if(ok) {     
     ObjectMapState *ms;
     float tmp_level[3];
@@ -1105,13 +1125,13 @@ ObjectGadgetRamp *ObjectGadgetRampMapNewAsDefined(PyMOLGlobals *G,
       }
       I->Level = VLAlloc(float,3);
       copy3f(tmp_level,I->Level);
+      VLAFreeP(level_vla);
     } else  {
-      ok = PConvPyListToFloatVLA(level,&I->Level);
+      I->Level = level_vla;
     }
   }
   if(ok) I->NLevel=VLAGetSize(I->Level);
   if(ok) ok = ObjectGadgetRampHandleInputColors(I);
-
   ObjectGadgetRampBuild(I);
   UtilNCopy(I->SrcName,map->Obj.Name,WordLength);
   I->SrcState=map_state;
@@ -1138,20 +1158,16 @@ ObjectGadgetRamp *ObjectGadgetRampMapNewAsDefined(PyMOLGlobals *G,
     dump3f(test,"test color");
   }
   */
-  PUnblock(G);
   return(I);
-#endif
+
 }
 
 /*========================================================================*/
 ObjectGadgetRamp *ObjectGadgetRampMolNewAsDefined(PyMOLGlobals *G,ObjectMolecule *mol,
-                                                  PyObject *level,
-                                                  PyObject *color,
-                                                  int mol_state)
+                                                  float *level_vla,
+                                                  float *color_vla,
+                                                  int mol_state, int calc_mode)
 {
-#ifdef _PYMOL_NOPY
-  return NULL;
-#else
 
   ObjectGadgetRamp *I;
   int ok = true;
@@ -1161,20 +1177,22 @@ ObjectGadgetRamp *ObjectGadgetRampMolNewAsDefined(PyMOLGlobals *G,ObjectMolecule
     I->RampType = cRampMol;
   else
     I->RampType = cRampNone;
-  PBlock(G);
-  if(ok) {
-    if(PyList_Check(color))
-      ok = PConvPyList3ToFloatVLA(color,&I->Color);
-    else if(PyInt_Check(color)) {
-      ok = PConvPyIntToInt(color,&I->CalcMode);      
-    }
-  }
-  if(ok) {     
-    ok = PConvPyListToFloatVLA(level,&I->Level);
-  }
+  if(ok) I->Color = color_vla;
+  if(ok) I->CalcMode = calc_mode;
+  if(ok) I->Level = level_vla;
   if(ok) I->NLevel=VLAGetSize(I->Level);
   if(ok) ok = ObjectGadgetRampHandleInputColors(I);
-
+  
+  if(ok && I->Level && I->NLevel) {
+    int a;
+    float last = I->Level[0];
+    for(a=1;a<I->NLevel;a++) {
+      if(I->Level[a]<last)
+        I->Level[a] = last;
+      last = I->Level[a];
+    }
+  }
+  
   ObjectGadgetRampBuild(I);
   if(mol) {
     UtilNCopy(I->SrcName,mol->Obj.Name,WordLength);
@@ -1182,9 +1200,7 @@ ObjectGadgetRamp *ObjectGadgetRampMolNewAsDefined(PyMOLGlobals *G,ObjectMolecule
     UtilNCopy(I->SrcName,"none",WordLength);
   }
   I->SrcState=mol_state;
-  PUnblock(G);
   return(I);
-#endif
 }
 
 
@@ -1208,9 +1224,9 @@ ObjectGadgetRamp *ObjectGadgetRampNew(PyMOLGlobals *G)
   I->Extreme = NULL;
   I->SrcName[0] = 0;
 
-  I->Gadget.Obj.fUpdate =(void (*)(struct CObject *)) ObjectGadgetRampUpdate;
-  I->Gadget.Obj.fFree =(void (*)(struct CObject *)) ObjectGadgetRampFree;
-  I->Gadget.Obj.fInvalidate = (void (*)(struct CObject *,int,int,int)) ObjectGadgetRampInvalidate;
+  I->Gadget.Obj.fUpdate =(void (*)(CObject *)) ObjectGadgetRampUpdate;
+  I->Gadget.Obj.fFree =(void (*)(CObject *)) ObjectGadgetRampFree;
+  I->Gadget.Obj.fInvalidate = (void (*)(CObject *,int,int,int)) ObjectGadgetRampInvalidate;
 
   I->Mol = NULL;
   I->Map = NULL;
