@@ -64,23 +64,24 @@ typedef struct ObjectMolecule {
   CGO *UnitCellCGO;
   int BondCounter;
   int AtomCounter;
+  /* not stored */
   struct CSculpt *Sculpt;
+  int RepVisCacheValid;
   signed char RepVisCache[cRepCnt]; /* for transient storage during updates */
 
-  /* not stored */
 } ObjectMolecule;
 
 typedef struct ObjectMoleculeOpRec {
   unsigned int code;
   Vector3f v1,v2;
   int cs1,cs2;
-  int i1,i2,i3,i4,*vc1,*i1VLA,*ii1,*vp1;
+  int i1,i2,i3,i4,i5,i6,*vc1,*i1VLA,*ii1,*vp1;
   float f1,f2,*f1VLA,*f2VLA,*ff1;
   double d[3][3],d1;
   float *vv1,*vv2;
   char *charVLA;
   char *s1;
-  ObjectMolecule **obj1VLA;
+  ObjectMolecule **obj1VLA,*obj3;
   AtomInfoType *ai,**ai1VLA;
   PyObject *py_ob1;
   float ttt[16],*mat1;
@@ -174,6 +175,8 @@ typedef struct {
 #define OMOP_Sort 57
 #define OMOP_SetAtomicSetting 58
 #define OMOP_CSetSumSqDistToPt 59
+#define OMOP_RevalenceFromSource 60
+#define OMOP_RevalenceByGuessing 61
 
 #include"CoordSet.h"
 
@@ -238,6 +241,8 @@ int ObjectMoleculeGetTopNeighbor(PyMOLGlobals *G,
                                  int start, int excluded);
 
 int ObjectMoleculeGetNearestAtomIndex(ObjectMolecule *I, float *point, float cutoff, int state, float *dist);
+int ObjectMoleculeGetNearestBlendedColor(ObjectMolecule *I, float *point, float cutoff, 
+                                         int state, float *dist, float *color, int sub_vdw);
 
 int *ObjectMoleculeGetPrioritizedOtherIndexList(ObjectMolecule *I,struct CoordSet *cs);
 int ObjectMoleculeGetPrioritizedOther(int *other, int a1, int a2, int *double_sided);
@@ -302,7 +307,7 @@ ObjectMolecule *ObjectMoleculeReadPDBStr(PyMOLGlobals *G,ObjectMolecule *obj,cha
 ObjectMolecule *ObjectMoleculeReadMMDStr(PyMOLGlobals *G,ObjectMolecule *I,char *MMDStr,int frame,int discrete);
 ObjectMolecule *ObjectMoleculeReadXYZStr(PyMOLGlobals *G,ObjectMolecule *I,char *PDBStr,int frame,int discrete);
 
-void ObjectMoleculeExtendIndices(ObjectMolecule *I);
+void ObjectMoleculeExtendIndices(ObjectMolecule *I,int state);
 
 void ObjectMoleculeInvalidate(ObjectMolecule *I,int rep,int level,int state);
 
@@ -332,6 +337,9 @@ void ObjectMoleculeInferChemForProtein(ObjectMolecule *I,int state);
 void ObjectMoleculeInferChemFromBonds(ObjectMolecule *I,int state);
 void ObjectMoleculePurge(ObjectMolecule *I);
 
+int ObjectMoleculeXferValences(ObjectMolecule *Ia, int sele1, int sele2, int target_state,
+                                ObjectMolecule *Ib, int sele3, int source_state, int quiet);
+void ObjectMoleculeGuessValences(ObjectMolecule *I,int state,int *flag1,int *flag2,int reset);
 int ObjectMoleculeAddBond(ObjectMolecule *I,int sele0,int sele1,int order);
 int ObjectMoleculeRemoveBonds(ObjectMolecule *I,int sele1,int sele2);
 
@@ -374,7 +382,8 @@ int ObjectMoleculePurgeBondPath(ObjectMolecule *I,ObjectMoleculeBPRec *bp);
 int ObjectMoleculeGetBondPath(ObjectMolecule *I,int atom,int max,ObjectMoleculeBPRec *bp);
 int ***ObjectMoleculeGetBondPrint(ObjectMolecule *I,int max_bond,int max_type,int *dim);
 
-int ObjectMoleculeConnect(ObjectMolecule *I,BondType **bond,AtomInfoType *ai,struct CoordSet *cs,int searchFlag);
+int ObjectMoleculeConnect(ObjectMolecule *I,BondType **bond,AtomInfoType *ai,
+                          struct CoordSet *cs,int searchFlag, int connectModeOverride);
 int ObjectMoleculeSetDiscrete(PyMOLGlobals *G,ObjectMolecule *I,int discrete);
 
 float ObjectMoleculeGetMaxVDW(ObjectMolecule *I);
