@@ -44,7 +44,7 @@ Z* -------------------------------------------------------------------
 #define STOP_STRIP -2
 
 typedef struct ObjRec {
-  struct CObject *obj;  
+  CObject *obj;  
   struct ObjRec *next;
 } ObjRec;
 
@@ -271,6 +271,7 @@ static void ObjectSliceStateAssignColors(ObjectSliceState *oss, ObjectGadgetRamp
       for(x=min[0];x<=max[0];x++) {
         if(*flag) {
           ObjectGadgetRampInterpolate(ogr, *value, color);
+          ColorClampColor(oss->G,color);
         }
         color +=3;
         value++;
@@ -1023,8 +1024,11 @@ static void ObjectSliceRender(ObjectSlice *I,RenderInfo *info)
           Picking p;
           
           p.context.object = (void*)I;
+          p.context.state = 0;
           p.src.index = state+1;
-          
+          p.src.bond = 0;
+
+
           if(I->Obj.RepVis[cRepSlice]) {
             int *strip = oss->strips;
             float *point = oss->points;
@@ -1222,11 +1226,11 @@ ObjectSlice *ObjectSliceNew(PyMOLGlobals *G)
 
   I->Obj.type = cObjectSlice;
   
-  I->Obj.fFree = (void (*)(struct CObject *))ObjectSliceFree;
-  I->Obj.fUpdate =  (void (*)(struct CObject *)) ObjectSliceUpdate;
-  I->Obj.fRender =(void (*)(struct CObject *, RenderInfo *))ObjectSliceRender;
-  I->Obj.fInvalidate =(void (*)(struct CObject *,int,int,int))ObjectSliceInvalidate;
-  I->Obj.fGetNFrame = (int (*)(struct CObject *)) ObjectSliceGetNStates;
+  I->Obj.fFree = (void (*)(CObject *))ObjectSliceFree;
+  I->Obj.fUpdate =  (void (*)(CObject *)) ObjectSliceUpdate;
+  I->Obj.fRender =(void (*)(CObject *, RenderInfo *))ObjectSliceRender;
+  I->Obj.fInvalidate =(void (*)(CObject *,int,int,int))ObjectSliceInvalidate;
+  I->Obj.fGetNFrame = (int (*)(CObject *)) ObjectSliceGetNStates;
   return(I);
 }
 
