@@ -20,7 +20,7 @@ Z* -------------------------------------------------------------------
 #include"CoordSet.h"
 
 
-Rep *RepCartoonNew(CoordSet *cset);
+Rep *RepCartoonNew(CoordSet *cset,int state);
 void RepCartoonInit(void);
 
 #endif
