@@ -39,7 +39,6 @@ typedef struct RepDistDash {
 
 #include"ObjectDist.h"
 
-void RepDistDashRender(RepDistDash *I,CRay *ray,Pickable **pick);
 void RepDistDashFree(RepDistDash *I);
 
 void RepDistDashFree(RepDistDash *I)
@@ -50,13 +49,16 @@ void RepDistDashFree(RepDistDash *I)
 }
 
 
-void RepDistDashRender(RepDistDash *I,CRay *ray,Pickable **pick)
+static void RepDistDashRender(RepDistDash *I,RenderInfo *info)
 {
+  CRay *ray = info->ray;
+  Picking **pick = info->pick;
   PyMOLGlobals *G=I->R.G;
   float *v=I->V;
   int c=I->N;
   float *vc;
   int round_ends;
+  int color = SettingGet_color(G,I->ds->Setting,I->ds->Obj->Obj.Setting,cSetting_dash_color);
   I->linewidth = SettingGet_f(G,I->ds->Setting,I->ds->Obj->Obj.Setting,cSetting_dash_width);
   I->radius = SettingGet_f(G,I->ds->Setting,I->ds->Obj->Obj.Setting,cSetting_dash_radius);
   round_ends = SettingGet_b(G,I->ds->Setting,I->ds->Obj->Obj.Setting,cSetting_dash_round_ends);
@@ -65,31 +67,43 @@ void RepDistDashRender(RepDistDash *I,CRay *ray,Pickable **pick)
 
     float radius;
 
-    if(I->radius==0.0F) {
+    if(I->radius<=0.0F) {
       radius = ray->PixelRadius*I->linewidth/2.0F;
     } else {
       radius = I->radius;
     }
-
-    vc = ColorGet(G,I->Obj->Color);
-	 v=I->V;
-	 c=I->N;
-	 
-	 while(c>0) {
+    
+    if(color<0)
+      color = I->Obj->Color;
+    vc = ColorGet(G,color);
+    v=I->V;
+    c=I->N;
+    
+    while(c>0) {
       /*      printf("%8.3f %8.3f %8.3f   %8.3f %8.3f %8.3f \n",v[3],v[4],v[5],v[6],v[7],v[8]);*/
       if(round_ends) {
         ray->fSausage3fv(ray,v,v+3,radius,vc,vc);
       } else {
         ray->fCustomCylinder3fv(ray,v,v+3,radius,vc,vc,cCylCapFlat,cCylCapFlat);
       }
-		v+=6;
+      v+=6;
       c-=2;
-	 }
+    }
 
   } else if(G->HaveGUI && G->ValidContext) {
     if(pick) {
     } else {
       int use_dlst;
+
+      if(info->width_scale_flag) {
+        glLineWidth(I->linewidth * info->width_scale);
+      } else {
+        glLineWidth(I->linewidth);
+      }
+
+      if(color>=0)
+        glColor3fv(ColorGet(G,color));
+
       use_dlst = (int)SettingGet(G,cSetting_use_display_lists);
       if(use_dlst&&I->R.displayList) {
         glCallList(I->R.displayList);
@@ -110,7 +124,6 @@ void RepDistDashRender(RepDistDash *I,CRay *ray,Pickable **pick)
         c=I->N;
       
         glDisable(GL_LIGHTING);
-        glLineWidth(I->linewidth);
         glBegin(GL_LINES);	 
         while(c>0) {
           glVertex3fv(v);
@@ -133,7 +146,7 @@ void RepDistDashRender(RepDistDash *I,CRay *ray,Pickable **pick)
 
 Rep *RepDistDashNew(DistSet *ds)
 {
-  PyMOLGlobals *G=ds->G;
+  PyMOLGlobals *G=ds->State.G;
   int a;
   int n;
   float *v,*v1,*v2,d[3],d1[3],d2[3];
@@ -150,7 +163,7 @@ Rep *RepDistDashNew(DistSet *ds)
   RepInit(G,&I->R);
   
   
-  I->R.fRender=(void (*)(struct Rep *, CRay *, Pickable **))RepDistDashRender;
+  I->R.fRender=(void (*)(struct Rep *, RenderInfo *))RepDistDashRender;
   I->R.fFree=(void (*)(struct Rep *))RepDistDashFree;
   I->R.fRecolor=NULL;
 
