@@ -36,7 +36,6 @@ typedef struct RepNonbonded {
 
 #include"ObjectMolecule.h"
 
-void RepNonbondedRender(RepNonbonded *I,CRay *ray,Pickable **pick);
 void RepNonbondedFree(RepNonbonded *I);
 
 void RepNonbondedFree(RepNonbonded *I)
@@ -47,17 +46,24 @@ void RepNonbondedFree(RepNonbonded *I)
   OOFreeP(I);
 }
 
-void RepNonbondedRender(RepNonbonded *I,CRay *ray,Pickable **pick)
+static void RepNonbondedRender(RepNonbonded *I,RenderInfo *info)
 {
+  CRay *ray = info->ray;
+  Picking **pick = info->pick;
   PyMOLGlobals *G=I->R.G;
   float *v=I->V;
   int c=I->N;
   unsigned int i,j;
   Pickable *p;
+  float alpha;
 
+  alpha = SettingGet_f(G,I->R.cs->Setting,I->R.obj->Setting,cSetting_nonbonded_transparency);
+  alpha=1.0F-alpha;
+  if(fabs(alpha-1.0)<R_SMALL4)
+    alpha=1.0F;
   if(ray) {
-
     float radius;
+    ray->fTransparentf(ray,1.0F-alpha);
     
     if(I->Radius==0.0F) {
       radius = ray->PixelRadius*I->Width/2.0F;
@@ -75,11 +81,11 @@ void RepNonbondedRender(RepNonbonded *I,CRay *ray,Pickable **pick)
       ray->fSausage3fv(ray,v+15,v+18,radius,v,v);
 		v+=21;
 	 }
-
+    ray->fTransparentf(ray,0.0);
   } else if(G->HaveGUI && G->ValidContext) {
     if(pick) {
 
-      i=(*pick)->index;
+      i=(*pick)->src.index;
 
       v=I->VP;
       c=I->NP;
@@ -91,13 +97,14 @@ void RepNonbondedRender(RepNonbonded *I,CRay *ray,Pickable **pick)
 
         i++;
 
-        if(!(*pick)[0].ptr) {
+        if(!(*pick)[0].src.bond) {
           /* pass 1 - low order bits */
 
           glColor3ub((uchar)((i&0xF)<<4),(uchar)((i&0xF0)|0x8),(uchar)((i&0xF00)>>4)); 
-          VLACheck((*pick),Pickable,i);
+          VLACheck((*pick),Picking,i);
           p++;
-          (*pick)[i] = *p; /* copy object and atom info */
+          (*pick)[i].src = *p; /* copy object and atom info */
+          (*pick)[i].context = I->R.context;
         } else { 
           /* pass 2 - high order bits */
 
@@ -123,18 +130,26 @@ void RepNonbondedRender(RepNonbonded *I,CRay *ray,Pickable **pick)
       }
       glEnd();
 
-      (*pick)[0].index = i;
+      (*pick)[0].src.index = i;
     } else {
 
       int use_dlst;
-
-      glLineWidth(I->Width);
+      
+      if(info->width_scale_flag) 
+        glLineWidth(I->Width*info->width_scale);
+      else
+        glLineWidth(I->Width);
 
       use_dlst = (int)SettingGet(G,cSetting_use_display_lists);
       if(use_dlst&&I->R.displayList) {
         glCallList(I->R.displayList);
       } else { 
+	   int nvidia_bugs = SettingGetGlobal_i(G,cSetting_nvidia_bugs);
 
+	if(SettingGetGlobal_i(G,cSetting_ati_bugs)) {
+	    glFlush(); /* eliminate ATI artifacts under VISTA */
+	  }
+	    
         if(use_dlst) {
           if(!I->R.displayList) {
             I->R.displayList = glGenLists(1);
@@ -150,10 +165,18 @@ void RepNonbondedRender(RepNonbonded *I,CRay *ray,Pickable **pick)
           glDisable(GL_LIGHTING);
           glBegin(GL_LINES);	 
           SceneResetNormal(G,true);
+
           while(c--) {
-        
-            glColor3fv(v);
+
+            if(alpha==1.0) {
+              glColor3fv(v);
+            } else {
+              glColor4f(v[0],v[1],v[2],alpha);
+            }
             v+=3;
+	    if(nvidia_bugs) {
+	      glFlush();
+	    }
         
             glVertex3fv(v);
             v+=3;
@@ -177,12 +200,13 @@ void RepNonbondedRender(RepNonbonded *I,CRay *ray,Pickable **pick)
         if(use_dlst&&I->R.displayList) {
           glEndList();
         }
+
       }
     }
   }
 }
 
-Rep *RepNonbondedNew(CoordSet *cs)
+Rep *RepNonbondedNew(CoordSet *cs,int state)
 {
   PyMOLGlobals *G=cs->State.G;
   ObjectMolecule *obj;
@@ -218,7 +242,7 @@ Rep *RepNonbondedNew(CoordSet *cs)
   nonbonded_size = SettingGet_f(G,cs->Setting,obj->Obj.Setting,cSetting_nonbonded_size);
   RepInit(G,&I->R);
 
-  I->R.fRender=(void (*)(struct Rep *, CRay *, Pickable **))RepNonbondedRender;
+  I->R.fRender=(void (*)(struct Rep *, RenderInfo *))RepNonbondedRender;
   I->R.fFree=(void (*)(struct Rep *))RepNonbondedFree;
 
   I->N=0;
@@ -227,6 +251,8 @@ Rep *RepNonbondedNew(CoordSet *cs)
   I->VP=NULL;
   I->R.P=NULL;
   I->R.fRecolor=NULL;
+  I->R.obj = (CObject*)(cs->Obj);
+  I->R.cs = cs;
 
   I->Width = SettingGet_f(G,cs->Setting,obj->Obj.Setting,cSetting_line_width);
   I->Radius = SettingGet_f(G,cs->Setting,obj->Obj.Setting,cSetting_line_radius);
@@ -240,7 +266,7 @@ Rep *RepNonbondedNew(CoordSet *cs)
       v1 = cs->Coord+3*a;
 
       if(ColorCheckRamped(G,c1)) {
-        ColorGetRamped(G,c1,v1,tmpColor);
+        ColorGetRamped(G,c1,v1,tmpColor,state);
         v0 = tmpColor;
       } else {
         v0 = ColorGet(G,c1);
@@ -291,40 +317,42 @@ Rep *RepNonbondedNew(CoordSet *cs)
     for(a=0;a<cs->NIndex;a++) 
       if(active[a]>0) {
         
-        I->NP++;
-
         a1=cs->IdxToAtm[a];
-        
-        I->R.P[I->NP].ptr = (void*)obj;
-        I->R.P[I->NP].index = a1;
-        I->R.P[I->NP].bond = -1;
-        v1 = cs->Coord+3*a;
-        
-        *(v++)=v1[0]-nonbonded_size;
-        *(v++)=v1[1];
-        *(v++)=v1[2];
 
-        *(v++)=v1[0]+nonbonded_size;
-        *(v++)=v1[1];
-        *(v++)=v1[2];
-
-        *(v++)=v1[0];
-        *(v++)=v1[1]-nonbonded_size;
-        *(v++)=v1[2];
-
-        *(v++)=v1[0];
-        *(v++)=v1[1]+nonbonded_size;
-        *(v++)=v1[2];
-
-        *(v++)=v1[0];
-        *(v++)=v1[1];
-        *(v++)=v1[2]-nonbonded_size;
-
-        *(v++)=v1[0];
-        *(v++)=v1[1];
-        *(v++)=v1[2]+nonbonded_size;
+        if(!obj->AtomInfo[a1].masked) {
+          I->NP++;
+          I->R.P[I->NP].index = a1;
+          I->R.P[I->NP].bond = -1;
+          v1 = cs->Coord+3*a;
+          
+          *(v++)=v1[0]-nonbonded_size;
+          *(v++)=v1[1];
+          *(v++)=v1[2];
+          
+          *(v++)=v1[0]+nonbonded_size;
+          *(v++)=v1[1];
+          *(v++)=v1[2];
+          
+          *(v++)=v1[0];
+          *(v++)=v1[1]-nonbonded_size;
+          *(v++)=v1[2];
+          
+          *(v++)=v1[0];
+          *(v++)=v1[1]+nonbonded_size;
+          *(v++)=v1[2];
+          
+          *(v++)=v1[0];
+          *(v++)=v1[1];
+          *(v++)=v1[2]-nonbonded_size;
+          
+          *(v++)=v1[0];
+          *(v++)=v1[1];
+          *(v++)=v1[2]+nonbonded_size;
+        }
       }
     I->R.P = Realloc(I->R.P,Pickable,I->NP+1);
+    I->R.context.object = (void*)obj;
+    I->R.context.state = state;
     I->R.P[0].index = I->NP;
     I->VP = ReallocForSure(I->VP,float,(v-I->VP));
   }
