@@ -40,7 +40,6 @@ typedef struct RepNonbondedSphere {
 
 #include"ObjectMolecule.h"
 
-void RepNonbondedSphereRender(RepNonbondedSphere *I,CRay *ray,Pickable **pick);
 void RepNonbondedSphereFree(RepNonbondedSphere *I);
 
 void RepNonbondedSphereInit(void)
@@ -56,8 +55,10 @@ void RepNonbondedSphereFree(RepNonbondedSphere *I)
   OOFreeP(I);
 }
 
-void RepNonbondedSphereRender(RepNonbondedSphere *I,CRay *ray,Pickable **pick)
+static void RepNonbondedSphereRender(RepNonbondedSphere *I,RenderInfo *info)
 {
+  CRay *ray = info->ray;
+  Picking **pick = info->pick;
   register PyMOLGlobals *G=I->R.G;
   float *v=I->V;
   int c=I->N;
@@ -67,7 +68,15 @@ void RepNonbondedSphereRender(RepNonbondedSphere *I,CRay *ray,Pickable **pick)
   int i,j;
   Pickable *p;
 
+  float alpha;
+
+  alpha = SettingGet_f(G,I->R.cs->Setting,I->R.obj->Setting,cSetting_nonbonded_transparency);
+  alpha=1.0F-alpha;
+  if(fabs(alpha-1.0)<R_SMALL4)
+    alpha=1.0F;
+  
   if(ray) {
+    ray->fTransparentf(ray,1.0F-alpha);
 	 v=I->VC;
 	 c=I->NC;
 	 while(c--) {
@@ -76,10 +85,11 @@ void RepNonbondedSphereRender(RepNonbondedSphere *I,CRay *ray,Pickable **pick)
 		ray->fSphere3fv(ray,v,*(v+3));
 		v+=4;
 	 }
+     ray->fTransparentf(ray,0.0);
   } else if(G->HaveGUI && G->ValidContext) {
     if(pick) {
 
-      i=(*pick)->index;
+      i=(*pick)->src.index;
 
       v=I->VP;
       c=I->NP;
@@ -91,13 +101,14 @@ void RepNonbondedSphereRender(RepNonbondedSphere *I,CRay *ray,Pickable **pick)
 
         i++;
 
-        if(!(*pick)[0].ptr) {
+        if(!(*pick)[0].src.bond) {
           /* pass 1 - low order bits */
 
           glColor3ub((uchar)((i&0xF)<<4),(uchar)((i&0xF0)|0x8),(uchar)((i&0xF00)>>4)); 
-          VLACheck((*pick),Pickable,i);
+          VLACheck((*pick),Picking,i);
           p++;
-          (*pick)[i] = *p; /* copy object and atom info */
+          (*pick)[i].src = *p; /* copy object and atom info */
+          (*pick)[i].context = I->R.context;
         } else { 
           /* pass 2 - high order bits */
 
@@ -123,14 +134,18 @@ void RepNonbondedSphereRender(RepNonbondedSphere *I,CRay *ray,Pickable **pick)
       }
       glEnd();
 
-      (*pick)[0].index = i;
+      (*pick)[0].src.index = i;
 
     } else {
 
       sp=I->SP;
       while(c--)
         {
-          glColor3fv(v);
+          if(alpha==1.0) {
+            glColor3fv(v);
+          } else {
+            glColor4f(v[0],v[1],v[2],alpha);
+          }
           v+=3;
           for(a=0;a<sp->NStrip;a++) {
             glBegin(GL_TRIANGLE_STRIP);
@@ -148,7 +163,7 @@ void RepNonbondedSphereRender(RepNonbondedSphere *I,CRay *ray,Pickable **pick)
   }
 }
 
-Rep *RepNonbondedSphereNew(CoordSet *cs)
+Rep *RepNonbondedSphereNew(CoordSet *cs,int state)
 {
   PyMOLGlobals *G=cs->State.G;
   ObjectMolecule *obj;
@@ -197,9 +212,11 @@ Rep *RepNonbondedSphereNew(CoordSet *cs)
   sp = G->Sphere->Sphere[ds];
 
   RepInit(G,&I->R);
-  I->R.fRender=(void (*)(struct Rep *, CRay *, Pickable **))RepNonbondedSphereRender;
+  I->R.fRender=(void (*)(struct Rep *, RenderInfo *))RepNonbondedSphereRender;
   I->R.fFree=(void (*)(struct Rep *))RepNonbondedSphereFree;
   I->R.fRecolor=NULL;
+  I->R.obj = (CObject*)(cs->Obj);
+  I->R.cs = cs;
   I->N=0;
   I->NC=0;
   I->V=NULL;
@@ -225,7 +242,7 @@ Rep *RepNonbondedSphereNew(CoordSet *cs)
 			 c1=*(cs->Color+a);
 			 v0 = cs->Coord+3*a;			 
           if(ColorCheckRamped(G,c1)) {
-            ColorGetRamped(G,c1,v0,tmpColor);
+            ColorGetRamped(G,c1,v0,tmpColor,state);
             vc = tmpColor;
           } else {
             vc = ColorGet(G,c1);
@@ -263,7 +280,7 @@ Rep *RepNonbondedSphereNew(CoordSet *cs)
 			 vc = ColorGet(G,c1);
 
           if(ColorCheckRamped(G,c1)) {
-            ColorGetRamped(G,c1,v0,tmpColor);
+            ColorGetRamped(G,c1,v0,tmpColor,state);
             vc = tmpColor;
           } else {
             vc = ColorGet(G,c1);
@@ -312,35 +329,39 @@ Rep *RepNonbondedSphereNew(CoordSet *cs)
     for(a=0;a<cs->NIndex;a++) 
       if(active[a]>0) {
         
-        I->NP++;
-
         a1=cs->IdxToAtm[a];
-        
-        I->R.P[I->NP].ptr = (void*)obj;
-        I->R.P[I->NP].index = a1;
-        I->R.P[I->NP].bond = -1;
-        v1 = cs->Coord+3*a;
-        
-        *(v++)=v1[0]-nonbonded_size;
-        *(v++)=v1[1];
-        *(v++)=v1[2];
-        *(v++)=v1[0]+nonbonded_size;
-        *(v++)=v1[1];
-        *(v++)=v1[2];
-        *(v++)=v1[0];
-        *(v++)=v1[1]-nonbonded_size;
-        *(v++)=v1[2];
-        *(v++)=v1[0];
-        *(v++)=v1[1]+nonbonded_size;
-        *(v++)=v1[2];
-        *(v++)=v1[0];
-        *(v++)=v1[1];
-        *(v++)=v1[2]-nonbonded_size;
-        *(v++)=v1[0];
-        *(v++)=v1[1];
-        *(v++)=v1[2]+nonbonded_size;
+          
+        if(!obj->AtomInfo[a1].masked) {
+          I->NP++;
+
+          I->R.P[I->NP].index = a1;
+          I->R.P[I->NP].bond = -1;
+          v1 = cs->Coord+3*a;
+          
+          *(v++)=v1[0]-nonbonded_size;
+          *(v++)=v1[1];
+          *(v++)=v1[2];
+          *(v++)=v1[0]+nonbonded_size;
+          *(v++)=v1[1];
+          *(v++)=v1[2];
+          *(v++)=v1[0];
+          *(v++)=v1[1]-nonbonded_size;
+          *(v++)=v1[2];
+          *(v++)=v1[0];
+          *(v++)=v1[1]+nonbonded_size;
+          *(v++)=v1[2];
+          *(v++)=v1[0];
+          *(v++)=v1[1];
+          *(v++)=v1[2]-nonbonded_size;
+          *(v++)=v1[0];
+          *(v++)=v1[1];
+          *(v++)=v1[2]+nonbonded_size;
+        }
       }
     I->R.P = Realloc(I->R.P,Pickable,I->NP+1);
+    I->R.context.object = (void*)obj;
+    I->R.context.state = state;
+
     I->R.P[0].index = I->NP;
     I->VP = Realloc(I->VP,float,I->NP*21);
   }
