@@ -40,7 +40,6 @@ typedef struct RepRibbon {
 
 #include"ObjectMolecule.h"
 
-void RepRibbonRender(RepRibbon *I,CRay *ray,Pickable **pick);
 void RepRibbonFree(RepRibbon *I);
 
 void RepRibbonInit(void)
@@ -54,8 +53,10 @@ void RepRibbonFree(RepRibbon *I)
   OOFreeP(I);
 }
 
-void RepRibbonRender(RepRibbon *I,CRay *ray,Pickable **pick)
+static void RepRibbonRender(RepRibbon *I,RenderInfo *info)
 {
+  CRay *ray = info->ray;
+  Picking **pick = info->pick;
   PyMOLGlobals *G=I->R.G;
   float *v=I->V;
   int c=I->N;
@@ -91,7 +92,7 @@ void RepRibbonRender(RepRibbon *I,CRay *ray,Pickable **pick)
 
     if(c>0) {
       while(c--) {
-		  ray->fSausage3fv(ray,v+4,v+11,radius,v+1,v+8);
+        ray->fSausage3fv(ray,v+4,v+11,radius,v+1,v+8);
         v+=18;
       }
     }
@@ -103,7 +104,7 @@ void RepRibbonRender(RepRibbon *I,CRay *ray,Pickable **pick)
         ENDFD;
 
       if(c) {
-        i=(*pick)->index;
+        i=(*pick)->src.index;
         p=I->R.P;
         last=-1;
         glBegin(GL_LINES);
@@ -113,12 +114,13 @@ void RepRibbonRender(RepRibbon *I,CRay *ray,Pickable **pick)
             if(ip!=last) {
               i++;
               last=ip;
-              if(!(*pick)[0].ptr) {
+              if(!(*pick)[0].src.bond) {
                 /* pass 1 - low order bits */
               
                 glColor3ub((uchar)((i&0xF)<<4),(uchar)((i&0xF0)|0x8),(uchar)((i&0xF00)>>4)); /* we're encoding the index into the color */
-                VLACheck((*pick),Pickable,i);
-                (*pick)[i] = p[ip]; /* copy object and atom info */
+                VLACheck((*pick),Picking,i);
+                (*pick)[i].src = p[ip]; /* copy object and atom info */
+                (*pick)[i].context = I->R.context;
               } else { 
                 /* pass 2 - high order bits */
                 j=i>>12;
@@ -132,12 +134,13 @@ void RepRibbonRender(RepRibbon *I,CRay *ray,Pickable **pick)
               glVertex3fv(v+15);
               i++;
               last=ip;
-              if(!(*pick)[0].ptr) {
+              if(!(*pick)[0].src.bond) {
                 /* pass 1 - low order bits */
               
                 glColor3ub((uchar)((i&0xF)<<4),(uchar)((i&0xF0)|0x8),(uchar)((i&0xF00)>>4)); /* we're encoding the index into the color */
-                VLACheck((*pick),Pickable,i);
-                (*pick)[i] = p[ip]; /* copy object and atom info */
+                VLACheck((*pick),Picking,i);
+                (*pick)[i].src = p[ip]; /* copy object and atom info */
+                (*pick)[i].context = I->R.context;
               } else { 
                 /* pass 2 - high order bits */
                 j=i>>12;
@@ -148,7 +151,7 @@ void RepRibbonRender(RepRibbon *I,CRay *ray,Pickable **pick)
             v+=18;
           }
         glEnd();
-        (*pick)[0].index = i; /* pass the count */
+        (*pick)[0].src.index = i; /* pass the count */
       }
     } else {
       int use_dlst;
@@ -157,6 +160,12 @@ void RepRibbonRender(RepRibbon *I,CRay *ray,Pickable **pick)
       ribbon_smooth=SettingGet_i(G,NULL,I->R.obj->Setting,cSetting_ribbon_smooth);
       if(!ribbon_smooth)
         glDisable(GL_LINE_SMOOTH);
+
+      if(info->width_scale_flag) 
+        glLineWidth(I->linewidth*info->width_scale);
+      else
+        glLineWidth(I->linewidth);
+
       use_dlst = (int)SettingGet(G,cSetting_use_display_lists);
       if(use_dlst&&I->R.displayList) {
         glCallList(I->R.displayList);
@@ -176,7 +185,6 @@ void RepRibbonRender(RepRibbon *I,CRay *ray,Pickable **pick)
           " RepRibbonRender: rendering GL...\n"
           ENDFD;
       
-        glLineWidth(I->linewidth);
       
         if(c) {
         
@@ -228,7 +236,7 @@ static float smooth(float x,float power)
   }
 }
 
-Rep *RepRibbonNew(CoordSet *cs)
+Rep *RepRibbonNew(CoordSet *cs,int state)
 {
   PyMOLGlobals *G=cs->State.G;
   ObjectMolecule *obj;
@@ -249,9 +257,12 @@ Rep *RepRibbonNew(CoordSet *cs)
   float throw;
   int visFlag;
   float dev;
-  int trace;
+  int trace,trace_mode;
   int ribbon_color;
+  int na_mode;
   AtomInfoType *ai,*last_ai=NULL;
+  AtomInfoType *trailing_O3p_ai=NULL, *leading_O5p_ai=NULL;
+  int trailing_O3p_a = 0, leading_O5p_a = 0, leading_O5p_a1 =0;
 
   Pickable *rp=NULL;
   OOAlloc(G,RepRibbon);
@@ -276,6 +287,8 @@ Rep *RepRibbonNew(CoordSet *cs)
   power_b=SettingGet_f(G,cs->Setting,obj->Obj.Setting,cSetting_ribbon_power_b);
   throw=SettingGet_f(G,cs->Setting,obj->Obj.Setting,cSetting_ribbon_throw);
   trace=SettingGet_i(G,cs->Setting,obj->Obj.Setting,cSetting_ribbon_trace_atoms);
+  trace_mode=SettingGet_i(G,cs->Setting,obj->Obj.Setting,cSetting_trace_atoms_mode);
+  na_mode = SettingGet_i(G,cs->Setting,obj->Obj.Setting,cSetting_ribbon_nucleic_acid_mode);
 
   ribbon_color=SettingGet_color(G,cs->Setting,obj->Obj.Setting,cSetting_ribbon_color);
 
@@ -283,13 +296,14 @@ Rep *RepRibbonNew(CoordSet *cs)
   if(sampling<1) sampling=1;
   I->radius=SettingGet_f(G,cs->Setting,obj->Obj.Setting,cSetting_ribbon_radius);
 
-  I->R.fRender=(void (*)(struct Rep *, CRay *, Pickable **))RepRibbonRender;
+  I->R.fRender=(void (*)(struct Rep *, RenderInfo *))RepRibbonRender;
   I->R.fFree=(void (*)(struct Rep *))RepRibbonFree;
   I->R.fRecolor=NULL;
   I->R.obj = (CObject*)obj;
   I->linewidth = SettingGet_f(G,cs->Setting,obj->Obj.Setting,cSetting_ribbon_width);
-
-
+  I->R.context.object = (void*)obj;
+  I->R.context.state = state;
+  
   /* find all of the CA points */
 
   at = Alloc(int,cs->NAtIndex*2);
@@ -304,7 +318,7 @@ Rep *RepRibbonNew(CoordSet *cs)
   nSeg = 0;
   a2=-1;
   for(a1=0;a1<cs->NAtIndex;a1++)
-	 {
+    {
       if(obj->DiscreteFlag) {
         if(cs==obj->DiscreteCSet[a1]) 
           a=obj->DiscreteAtmToIdx[a1];
@@ -312,22 +326,22 @@ Rep *RepRibbonNew(CoordSet *cs)
           a=-1;
       } else 
         a=cs->AtmToIdx[a1];
-		if(a>=0) {
+      if(a>=0) {
         ai = obj->AtomInfo+a1;
-		  if(obj->AtomInfo[a1].visRep[cRepRibbon]) {
+        if(obj->AtomInfo[a1].visRep[cRepRibbon]) {
           if(trace||((obj->AtomInfo[a1].protons==cAN_C)&&
                      (WordMatch(G,"CA",obj->AtomInfo[a1].name,1)<0)&&
                      !AtomInfoSameResidueP(G,last_ai,ai))) {
             PRINTFD(G,FB_RepRibbon)
               " RepRibbon: found atom in %s; a1 %d a2 %d\n",obj->AtomInfo[a1].resi,a1,a2
               ENDFD;
-            
+              
             if(a2>=0) {
               /*						if((abs(obj->AtomInfo[a1].resv-obj->AtomInfo[a2].resv)>1)||
-                (obj->AtomInfo[a1].chain[0]!=obj->AtomInfo[a2].chain[0])||
-                (!WordMatch(G,obj->AtomInfo[a1].segi,obj->AtomInfo[a2].segi,1)))*/
+                                        (obj->AtomInfo[a1].chain[0]!=obj->AtomInfo[a2].chain[0])||
+                                        (!WordMatch(G,obj->AtomInfo[a1].segi,obj->AtomInfo[a2].segi,1)))*/
               if(trace) {
-                if(!AtomInfoSequential(G,obj->AtomInfo+a2,obj->AtomInfo+a1))
+                if(!AtomInfoSequential(G,obj->AtomInfo+a2,obj->AtomInfo+a1,trace_mode))
                   a2=-1;
               } else {
                 if(!ObjectMoleculeCheckBondSep(obj,a1,a2,3)) /* CA->N->C->CA = 3 bonds */
@@ -348,14 +362,47 @@ Rep *RepRibbonNew(CoordSet *cs)
             *(v++)=*(v1++);
             
             a2=a1;
-          } else if(trace||(((ai->protons==cAN_P)&&
-                             (WordMatch(G,"P",ai->name,1)<0))&&
-                            !AtomInfoSameResidueP(G,last_ai,ai))) {
-            if(!trace) 
-              if(a2>=0) {
-                if(!ObjectMoleculeCheckBondSep(obj,a1,a2,6)) /* six bonds between phosphates */
-                  a2=-1;
+          } else if(
+                    (((na_mode!=1)&&(ai->protons==cAN_P) &&
+                      (WordMatch(G,"P",ai->name,1)<0) ) ||
+                     ((na_mode==1)&&(ai->protons==cAN_C) &&
+                      (WordMatchExact(G,"C4*",ai->name,1) ||
+                       WordMatchExact(G,"C4'",ai->name,1))))&&
+                    !AtomInfoSameResidueP(G,last_ai,ai)) {
+            if(a2>=0) {
+              if(!ObjectMoleculeCheckBondSep(obj,a1,a2,6)) { /* six bonds between phosphates */
+                if(trailing_O3p_ai&&((na_mode==2)||(na_mode==4))) {
+                  /* 3' end of nucleic acid */
+                  *(s++) = nSeg;
+                  nAt++;
+                  *(i++)=trailing_O3p_a;
+                  v1 = cs->Coord+3*trailing_O3p_a;		
+                  *(v++)=*(v1++);
+                  *(v++)=*(v1++);
+                  *(v++)=*(v1++);
+                }
+                a2=-1;
               }
+            }
+
+            trailing_O3p_ai = NULL;
+
+            if(leading_O5p_ai&&(a2<0)&&
+               ((na_mode==3)||(na_mode==4))) {
+              if((!AtomInfoSameResidueP(G,ai,leading_O5p_ai))&&
+                 ObjectMoleculeCheckBondSep(obj,a1,leading_O5p_a1,5)) {
+                nSeg++;
+                *(s++) = nSeg;
+                nAt++;
+                *(i++)= leading_O5p_a;
+                v1 = cs->Coord+3*leading_O5p_a;		
+                *(v++)=*(v1++);
+                *(v++)=*(v1++);
+                *(v++)=*(v1++);
+                a2 = leading_O5p_a1;
+              }
+            }
+            leading_O5p_ai = NULL;
             last_ai = ai;
             if(a2<0) nSeg++;
             *(s++) = nSeg;
@@ -367,94 +414,123 @@ Rep *RepRibbonNew(CoordSet *cs)
             *(v++)=*(v1++);
             
             a2=a1;
+          } else if((a2>=0)&&
+                    last_ai&&
+                    (ai->protons==cAN_O)&&
+                    (last_ai->protons==cAN_P)&&
+                    ((na_mode==2)||(na_mode==4))&&
+                    (WordMatchExact(G,"O3'",ai->name,1)||
+                     WordMatchExact(G,"O3*",ai->name,1))&&
+                    AtomInfoSameResidueP(G,last_ai,ai)&&
+                    ObjectMoleculeCheckBondSep(obj,a1,a2,5)) {
+            trailing_O3p_ai = ai;
+            trailing_O3p_a = a;
+          } else if((ai->protons==cAN_O)&&
+                    ((na_mode==3)||(na_mode==4))&&
+                    (WordMatchExact(G,"O5'",ai->name,1)||
+                     WordMatchExact(G,"O5*",ai->name,1))) {
+            leading_O5p_ai = ai;
+            leading_O5p_a = a;
+            leading_O5p_a1 = a1;
           }
         }
       }
+      
     }
+  if(trailing_O3p_ai&&((na_mode==2)||(na_mode==4))) {
+    /* 3' end of nucleic acid */
+    *(s++) = nSeg;
+    nAt++;
+    *(i++)=trailing_O3p_a;
+    v1 = cs->Coord+3*trailing_O3p_a;		
+    *(v++)=*(v1++);
+    *(v++)=*(v1++);
+    *(v++)=*(v1++);
+  }
   PRINTFD(G,FB_RepRibbon)
     " RepRibbon: nAt %d\n",nAt
     ENDFD;
-
+  
   if(nAt)
-	 {
-		/* compute differences and normals */
+    {
+      /* compute differences and normals */
 
-		s=seg;
-		v=pv;
+      s=seg;
+      v=pv;
 		
-		dv = Alloc(float,nAt*6);
-		nv = Alloc(float,nAt*6);
-		dl = Alloc(float,nAt*2);
-		v1=dv;
-		v2=nv;
-		d=dl;
+      dv = Alloc(float,nAt*6);
+      nv = Alloc(float,nAt*6);
+      dl = Alloc(float,nAt*2);
+      v1=dv;
+      v2=nv;
+      d=dl;
 		
-		for(a=0;a<(nAt-1);a++)
-		  {
-			 if(*s==*(s+1))
-				{
-				  float d_1;
-				  subtract3f(v+3,v,v1);
-				  *d = (float)length3f(v1);
-				  if(*d>R_SMALL4) {
-				    d_1 = 1.0F/(*d);
-				    scale3f(v1,d_1,v2);
-				  } else if(a)  {
-				    copy3f(v2-3,v2); 
-				  } else {
-				    zero3f(v2);
-				  }
-				}
-			 d++;
-			 v+=3;
-			 v1+=3;
-			 v2+=3;
-			 s++;
-		  }
+      for(a=0;a<(nAt-1);a++)
+        {
+          if(*s==*(s+1))
+            {
+              float d_1;
+              subtract3f(v+3,v,v1);
+              *d = (float)length3f(v1);
+              if(*d>R_SMALL4) {
+                d_1 = 1.0F/(*d);
+                scale3f(v1,d_1,v2);
+              } else if(a)  {
+                copy3f(v2-3,v2); 
+              } else {
+                zero3f(v2);
+              }
+            }
+          d++;
+          v+=3;
+          v1+=3;
+          v2+=3;
+          s++;
+        }
 		
-		/* compute tangents */
+      /* compute tangents */
 		
-		s=seg;
-		v=nv;
+      s=seg;
+      v=nv;
 		
-		tv = Alloc(float,nAt*6+6);
-		v1=tv;
+      tv = Alloc(float,nAt*6+6);
+      v1=tv;
 		
-		*(v1++)=*(v++); /* first segment */
-		*(v1++)=*(v++);
-		*(v1++)=*(v++);
-		s++;
+      *(v1++)=*(v++); /* first segment */
+      *(v1++)=*(v++);
+      *(v1++)=*(v++);
+      s++;
 		
-		for(a=1;a<(nAt-1);a++)
-		  {
-			 if((*s==*(s-1))&&(*s==*(s+1)))
-				{
-				  add3f(v,(v-3),v1);
-				  normalize3f(v1);			 
-				}
-			 else if(*s==*(s-1))
-				{
-				  *(v1)=*(v-3);  /* end a segment */
-				  *(v1+1)=*(v-2); 
-				  *(v1+2)=*(v-1); 
-				}
-			 else if(*s==*(s+1))
-				{
-				  *(v1)=*(v);   /* new segment */
-				  *(v1+1)=*(v+1); 
-				  *(v1+2)=*(v+2); 
-				}
-			 v+=3;
-			 v1+=3;
-			 s++;
-		  }
+      for(a=1;a<(nAt-1);a++)
+        {
+          if((*s==*(s-1))&&(*s==*(s+1)))
+            {
+              add3f(v,(v-3),v1);
+              normalize3f(v1);			 
+            }
+          else if(*s==*(s-1))
+            {
+              *(v1)=*(v-3);  /* end a segment */
+              *(v1+1)=*(v-2); 
+              *(v1+2)=*(v-1); 
+            }
+          else if(*s==*(s+1))
+            {
+              *(v1)=*(v);   /* new segment */
+              *(v1+1)=*(v+1); 
+              *(v1+2)=*(v+2); 
+            }
+          v+=3;
+          v1+=3;
+          s++;
+        }
 		
-		*(v1++)=*(v-3); /* last segment */
-		*(v1++)=*(v-2);
-		*(v1++)=*(v-1);
+      *(v1++)=*(v-3); /* last segment */
+      *(v1++)=*(v-2);
+      *(v1++)=*(v-1);
 
       
-	 }
+    }
 
   /* okay, we now have enough info to generate smooth interpolations */
 
@@ -472,144 +548,146 @@ Rep *RepRibbonNew(CoordSet *cs)
   I->NP=0;
   v=I->V;
   if(nAt) {
-	 v1=pv; /* points */
-	 v2=tv; /* tangents */
-	 v3=dv; /* direction vector */
+    v1=pv; /* points */
+    v2=tv; /* tangents */
+    v3=dv; /* direction vector */
     d = dl;
-	 s=seg;
-	 atp=at;
-    rp->ptr = (void*)obj;
+    s=seg;
+    atp=at;
     rp->index = cs->IdxToAtm[*atp];
     if(obj->AtomInfo[cs->IdxToAtm[*atp]].masked)
       rp->index = -1; 
     rp->bond = -1;
     I->NP++;
     rp++;
-	 for(a=0;a<(nAt-1);a++)
-		{
-        rp->ptr = (void*)obj;
-        rp->index = cs->IdxToAtm[*(atp+1)]; /* store pickable for n+2 */
-        if(obj->AtomInfo[cs->IdxToAtm[*atp]].masked)
-          rp->index = -1;
-          rp->bond = -1;
-        rp++;
-        I->NP++;
+    for(a=0;a<(nAt-1);a++) {
 
-        PRINTFD(G,FB_RepRibbon)
-          " RepRibbon: seg %d *s %d , *(s+1) %d\n",a,*s,*(s+1)
-          ENDFD;
+      rp->index = cs->IdxToAtm[*(atp+1)]; /* store pickable for n+2 */
+      if(obj->AtomInfo[cs->IdxToAtm[*atp]].masked)
+        rp->index = -1;
+      rp->bond = -1;
+      rp++;
+      I->NP++;
+         
+      PRINTFD(G,FB_RepRibbon)
+        " RepRibbon: seg %d *s %d , *(s+1) %d\n",a,*s,*(s+1)
+        ENDFD;
 
-		  if(*s==*(s+1))
-			 {
-				c1=*(cs->Color+*atp);
-				c2=*(cs->Color+*(atp+1));
+      if(*s==*(s+1)) {
+        int atom_index1 = cs->IdxToAtm[*atp];
+        int atom_index2 = cs->IdxToAtm[*(atp+1)];
+        
+        c1=*(cs->Color+*atp);
+        c2=*(cs->Color+*(atp+1));
+          
+        if(ribbon_color>=0) {
+          c1 = (c2 = ribbon_color);
+        }
+          
+        AtomInfoGetSetting_color(G,obj->AtomInfo + atom_index1, cSetting_ribbon_color, c1, &c1);
+        AtomInfoGetSetting_color(G,obj->AtomInfo + atom_index2, cSetting_ribbon_color, c2, &c2);
 
-            if(ribbon_color>=0) {
-              c1 = (c2 = ribbon_color);
-            }
-
-            dev = throw*(*d);
-
-				for(b=0;b<sampling;b++) /* needs optimization */
-				  {
-
-					 f0=((float)b)/sampling; /* fraction of completion */
-                f0 = smooth(f0,power_a);  /* bias sampling towards the center of the curve */
-
-					 if(f0<0.5) {
-						v0 = ColorGet(G,c1);
-					 } else {
-						v0 = ColorGet(G,c2);
-					 }
-
-                /* store index */
-                if(f0<0.5F)
-                  *(v++)=(float)I->NP-1;
-                else
-                  *(v++)=(float)I->NP;
-                
-                /* store colors */
-
-					 *(v++)=*(v0++);
-					 *(v++)=*(v0++);
-					 *(v++)=*(v0);
-
-                /* start of line/cylinder */
-
-					 f1=1.0F-f0;
-                f2=smooth(f0,power_b);
-                f3=smooth(f1,power_b);
-                f4 = dev*f2*f3; /* displacement magnitude */
-                
-                *(v++)=f1*v1[0]+f0*v1[3]+
-                  f4*( f3*v2[0]-f2*v2[3] );
-                
-                *(v++)=f1*v1[1]+f0*v1[4]+
-                  f4*( f3*v2[1]-f2*v2[4] );
-                
-                *(v++)=f1*v1[2]+f0*v1[5]+
-                  f4*( f3*v2[2]-f2*v2[5] );
-                
-					 f0=((float)b+1)/sampling;
-                f0 = smooth(f0,power_a);
-
-					 if(f0<0.5) {
-						v0 = ColorGet(G,c1);
-					 } else {
-						v0 = ColorGet(G,c2);
-					 }
-
-                /* store index */
-                if(f0<0.5)
-                  *(v++)=(float)I->NP-1;
-                else
-                  *(v++)=(float)I->NP;
-                
-                /* store colors */
-
-					 *(v++)=*(v0++);
-					 *(v++)=*(v0++);
-					 *(v++)=*(v0);
-
-                /* end of line/cylinder */
-
-					 f1=1.0F-f0;
-                f2=smooth(f0,power_b);
-                f3=smooth(f1,power_b);
-                f4 = dev*f2*f3; /* displacement magnitude */
-                
-                *(v++)=f1*v1[0]+f0*v1[3]+
-                  f4*( f3*v2[0]-f2*v2[3] );
-                
-                *(v++)=f1*v1[1]+f0*v1[4]+
-                  f4*( f3*v2[1]-f2*v2[4] );
-                
-                *(v++)=f1*v1[2]+f0*v1[5]+
-                  f4*( f3*v2[2]-f2*v2[5] );
-
-					 v++; /* radius no longer stored here... */
-
-                average3f(v-4,v-11,v);
-
-                v+=3;
-
-					 I->N++;
-				  }
-            
+        dev = throw*(*d);
+          
+        for(b=0;b<sampling;b++) { /* needs optimization */
+                  
+          f0=((float)b)/sampling; /* fraction of completion */
+          f0 = smooth(f0,power_a);  /* bias sampling towards the center of the curve */
+                  
+          if(f0<0.5) {
+            v0 = ColorGet(G,c1);
+          } else {
+            v0 = ColorGet(G,c2);
           }
-        v1+=3;
-		  v2+=3;
-		  v3+=3;
-        d++;
-		  atp+=1;
-		  s++;
-		}
+
+          /* store index */
+          if(f0<0.5F)
+            *(v++)=(float)I->NP-1;
+          else
+            *(v++)=(float)I->NP;
+                
+          /* store colors */
+
+          *(v++)=*(v0++);
+          *(v++)=*(v0++);
+          *(v++)=*(v0);
+
+          /* start of line/cylinder */
+
+          f1=1.0F-f0;
+          f2=smooth(f0,power_b);
+          f3=smooth(f1,power_b);
+          f4 = dev*f2*f3; /* displacement magnitude */
+                
+          *(v++)=f1*v1[0]+f0*v1[3]+
+            f4*( f3*v2[0]-f2*v2[3] );
+                
+          *(v++)=f1*v1[1]+f0*v1[4]+
+            f4*( f3*v2[1]-f2*v2[4] );
+                
+          *(v++)=f1*v1[2]+f0*v1[5]+
+            f4*( f3*v2[2]-f2*v2[5] );
+                
+          f0=((float)b+1)/sampling;
+          f0 = smooth(f0,power_a);
+
+          if(f0<0.5) {
+            v0 = ColorGet(G,c1);
+          } else {
+            v0 = ColorGet(G,c2);
+          }
+
+          /* store index */
+          if(f0<0.5)
+            *(v++)=(float)I->NP-1;
+          else
+            *(v++)=(float)I->NP;
+                
+          /* store colors */
+
+          *(v++)=*(v0++);
+          *(v++)=*(v0++);
+          *(v++)=*(v0);
+
+          /* end of line/cylinder */
+
+          f1=1.0F-f0;
+          f2=smooth(f0,power_b);
+          f3=smooth(f1,power_b);
+          f4 = dev*f2*f3; /* displacement magnitude */
+                
+          *(v++)=f1*v1[0]+f0*v1[3]+
+            f4*( f3*v2[0]-f2*v2[3] );
+                
+          *(v++)=f1*v1[1]+f0*v1[4]+
+            f4*( f3*v2[1]-f2*v2[4] );
+                
+          *(v++)=f1*v1[2]+f0*v1[5]+
+            f4*( f3*v2[2]-f2*v2[5] );
+
+          v++; /* radius no longer stored here... */
+
+          average3f(v-4,v-11,v);
+
+          v+=3;
+
+          I->N++;
+        }
+            
+      }
+      v1+=3;
+      v2+=3;
+      v3+=3;
+      d++;
+      atp+=1;
+      s++;
+    }
 
 
-	 FreeP(dv);
-	 FreeP(dl);
-	 FreeP(tv);
-	 FreeP(nv);
+    FreeP(dv);
+    FreeP(dl);
+    FreeP(tv);
+    FreeP(nv);
   }
 
   FreeP(at);
