@@ -25,6 +25,7 @@ Z* -------------------------------------------------------------------
 #include"Scene.h"
 #include"Vector.h"
 #include"Word.h"
+#include"Editor.h"
 
 #include"CGO.h"
 
@@ -1640,6 +1641,7 @@ float SculptIterateObject(CSculpt *I,ObjectMolecule *obj,
   int active_flag=false;
   float hb_overlap,hb_overlap_base;
   int *active,n_active;
+  register int *exclude;
   AtomInfoType *ai0,*ai1;
   double task_time;
   float vdw_magnify,vdw_magnified = 1.0F;
@@ -1671,6 +1673,7 @@ float SculptIterateObject(CSculpt *I,ObjectMolecule *obj,
     atm2idx = Alloc(int,obj->NAtom);
     cnt = Alloc(int,obj->NAtom);
     active = Alloc(int,obj->NAtom);
+    exclude = Calloc(int,obj->NAtom);
     shk=I->Shaker;
 
     PRINTFD(G,FB_Sculpt)
@@ -1724,10 +1727,10 @@ float SculptIterateObject(CSculpt *I,ObjectMolecule *obj,
         cs->SculptCGO = CGONew(G);
       else
         CGOReset(cs->SculptCGO);
-      cgo = cs->SculptCGO;
     } else if(cs->SculptCGO) {
       CGOReset(cs->SculptCGO);      
     }
+    cgo = cs->SculptCGO;
 
     nb_skip = SettingGet_i(G,cs->Setting,obj->Obj.Setting,cSetting_sculpt_nb_interval);
     if(nb_skip>n_cycle)
@@ -1738,6 +1741,7 @@ float SculptIterateObject(CSculpt *I,ObjectMolecule *obj,
     ai0=obj->AtomInfo;
     for(a=0;a<obj->NAtom;a++) {
       if(ai0->flags&cAtomFlag_exclude) {
+        exclude[a] = true;
         a1=-1;
       } else {
         if(obj->DiscreteFlag) {
@@ -1838,7 +1842,7 @@ float SculptIterateObject(CSculpt *I,ObjectMolecule *obj,
             if(eval_flag) {
               a1 = atm2idx[b1]; /* coordinate set indices */
               a2 = atm2idx[b2];
-              if((a1>=0)&&(a2>=0)) {
+              if((a1>=0)&&(a2>=0)&&!(exclude[b1]||exclude[b2])) {
                 v1 = cs_coord+3*a1;
                 v2 = cs_coord+3*a2;
                 switch(sdc->type) {
@@ -1893,7 +1897,7 @@ float SculptIterateObject(CSculpt *I,ObjectMolecule *obj,
             a1 = atm2idx[b1];
             a2 = atm2idx[b2];
                 
-            if((a0>=0)&&(a1>=0)&&(a2>=0))
+            if((a0>=0)&&(a1>=0)&&(a2>=0)&&!(exclude[b0]||exclude[b1]||exclude[b2]))
               {
                 cnt[b0]++;
                 cnt[b1]++;
@@ -1924,7 +1928,7 @@ float SculptIterateObject(CSculpt *I,ObjectMolecule *obj,
             a2 = atm2idx[b2];
             a3 = atm2idx[b3];
               
-            if((a0>=0)&&(a1>=0)&&(a2>=0)&&(a3>=0)) {
+            if((a0>=0)&&(a1>=0)&&(a2>=0)&&(a3>=0)&&!(exclude[b0]||exclude[b1]||exclude[b2]||exclude[b3])) {
               v0 = cs_coord+3*a0;
               v1 = cs_coord+3*a1;
               v2 = cs_coord+3*a2;
@@ -1964,7 +1968,7 @@ float SculptIterateObject(CSculpt *I,ObjectMolecule *obj,
             a2 = atm2idx[b2];
             a3 = atm2idx[b3];
               
-            if((a0>=0)&&(a1>=0)&&(a2>=0)&&(a3>=0)) {
+            if((a0>=0)&&(a1>=0)&&(a2>=0)&&(a3>=0)&&!(exclude[b0]||exclude[b1]||exclude[b2]||exclude[b3])) {
               v0 = cs_coord+3*a0;
               v1 = cs_coord+3*a1;
               v2 = cs_coord+3*a2;
@@ -2006,7 +2010,7 @@ float SculptIterateObject(CSculpt *I,ObjectMolecule *obj,
             a2 = atm2idx[b2];
             a3 = atm2idx[b3];
               
-            if((a0>=0)&&(a1>=0)&&(a2>=0)&&(a3>=0)) {
+            if((a0>=0)&&(a1>=0)&&(a2>=0)&&(a3>=0)&&!(exclude[b0]||exclude[b1]||exclude[b2]||exclude[b3])) {
               v0 = cs_coord+3*a0;
               v1 = cs_coord+3*a1;
               v2 = cs_coord+3*a2;
@@ -2148,7 +2152,9 @@ float SculptIterateObject(CSculpt *I,ObjectMolecule *obj,
                                 a1 = atm2idx[b1];
                                 v1 = cs_coord+3*a1;
                                 if(vdw_vis_mode && cgo && 
-                                   (n_cycle<1) && (!(ai0->protekted&&ai1->protekted))) {
+                                   (n_cycle<1) && ((!(ai0->protekted&&ai1->protekted))||
+                                                   (ai0->flags&cAtomFlag_study)||
+                                                   (ai1->flags&cAtomFlag_study))) {
                                   SculptCGOBump(v0,v1,ai0->vdw,ai1->vdw,
                                                 cutoff,vdw_vis_min,
                                                 vdw_vis_mid, vdw_vis_max, 
@@ -2312,6 +2318,7 @@ float SculptIterateObject(CSculpt *I,ObjectMolecule *obj,
       if(total_count) 
         total_strain = (1000*total_strain)/total_count;
     }
+    FreeP(exclude);
     FreeP(active);
     FreeP(cnt);
     FreeP(disp);
@@ -2326,6 +2333,8 @@ float SculptIterateObject(CSculpt *I,ObjectMolecule *obj,
         }
       }
     }
+
+    EditorDihedralInvalid(G,obj);
   }
 
   PRINTFD(G,FB_Sculpt)
