@@ -69,6 +69,9 @@ Z* -------------------------------------------------------------------
 #define cLoadTypeG96 46
 #define cLoadTypeDCD 47
 #define cLoadTypeCUBEMap 48
+#define cLoadTypeXYZStr 49
+/* 50 is CIFStr */
+#define cLoadTypePHIStr 51
 
 /* NOTE: if you add a type above, then be sure to add corresponding code in:
    CmdLoad
@@ -169,7 +172,9 @@ int  ExecutiveDist(PyMOLGlobals *G,float *result,
                    char *nam,char *s1,char *s2,int mode,
                    float cutoff,int labels,int quiet,
                    int reset,int state,int zoom);
-void ExecutiveBond(PyMOLGlobals *G,char *s1,char *s2,int order,int add);
+int ExecutiveBond(PyMOLGlobals *G,char *s1,char *s2,int order,int mode,int quiet);
+int ExecutiveRevalence(PyMOLGlobals *G,char *s1,char *s2,char *src,
+                       int target_state,int source_state, int reset, int quiet);
 int ExecutiveVdwFit(PyMOLGlobals *G,char *s1,int state1,char *s2,int state2,float buffer, int quiet);
 int ExecutiveIterate(PyMOLGlobals *G,char *s1,char *expr,int read_only,int quiet,PyObject *space);
 int ExecutiveIterateList(PyMOLGlobals *G,char *s1,PyObject *list,int read_only,int quiet,PyObject *space);
@@ -182,8 +187,8 @@ int ExecutiveColor(PyMOLGlobals *G,char *name,char *color,int flags,int quiet);
 int ExecutiveInit(PyMOLGlobals *G);
 void ExecutiveFree(PyMOLGlobals *G);
 int ExecutivePop(PyMOLGlobals *G,char *target,char *source,int quiet);
-void ExecutiveManageObject(PyMOLGlobals *G,struct CObject *obj,int allow_zoom,int quiet);
-void ExecutiveUpdateObjectSelection(PyMOLGlobals *G,struct CObject *obj);
+void ExecutiveManageObject(PyMOLGlobals *G,CObject *obj,int allow_zoom,int quiet);
+void ExecutiveUpdateObjectSelection(PyMOLGlobals *G,CObject *obj);
 void ExecutiveManageSelection(PyMOLGlobals *G,char *name);
 Block *ExecutiveGetBlock(PyMOLGlobals *G);
 CObject *ExecutiveFindObjectByName(PyMOLGlobals *G,char *name);
@@ -233,7 +238,7 @@ void ExecutiveResetMatrix(PyMOLGlobals *G,
                           int   log,  
                           int quiet);
 void ExecutiveDrawNow(PyMOLGlobals *G);
-int ExecutiveDrawCmd(PyMOLGlobals *G, int width, int height,int antialias, int quiet);
+int ExecutiveDrawCmd(PyMOLGlobals *G, int width, int height,int antialias, int entire_window, int quiet);
 int ExecutiveCartoon(PyMOLGlobals *G,int type,char *sele);
 void ExecutiveSetAllVisib(PyMOLGlobals *G,int state);
 void ExecutiveSetRepVisib(PyMOLGlobals *G,char *name,int rep,int state);
@@ -304,7 +309,9 @@ int ExecutivePhiPsi(PyMOLGlobals *G,char *s1,ObjectMolecule ***objVLA,int **iVLA
 float *ExecutiveGetVertexVLA(PyMOLGlobals *G,char *s1,int state);
 int ExecutiveValidName(PyMOLGlobals *G,char *name);
 int ExecutiveValidNamePattern(PyMOLGlobals *G,char *name);
-int ExecutiveIsolevel(PyMOLGlobals *G,char *name,float level,int state,int query,float *result);
+int ExecutiveProcessObjectName(PyMOLGlobals *G,char *proposed,char *actual);
+
+int ExecutiveIsolevel(PyMOLGlobals *G,char *name,float level,int state,int query,float *result,int quiet);
 int ExecutiveTransformObjectSelection(PyMOLGlobals *G,char *name,int state,
                                       char *s1,int log,float *matrix,
                                       int homogenous,int global);
@@ -352,9 +359,9 @@ int  ExecutiveUnsetSetting(PyMOLGlobals *G,int index,char *sele,
 
 int  ExecutiveAssignSS(PyMOLGlobals *G,char *target,int state,char *context,int preserve,int quiet);
 
-int ExecutiveRampNew(PyMOLGlobals *G,char *name,char *src_name,PyObject *range,
-                        PyObject *color,int src_state,char *sele,
-                        float beyond,float within,float sigma,int zero,int quiet);
+int ExecutiveRampNew(PyMOLGlobals *G,char *name,char *src_name,float *range,
+                        float *color,int src_state,char *sele,
+                        float beyond,float within,float sigma,int zero,int calc_mode,int quiet);
 
 int ExecutiveValidateObjectPtr(PyMOLGlobals *G,CObject *ptr,int object_type);
 
@@ -402,6 +409,18 @@ int ExecutiveMatrixCopy(PyMOLGlobals *G,
 void ExecutiveMemoryDump(PyMOLGlobals *G);
 void ExecutiveObjMolSeleOp(PyMOLGlobals *G,int sele,ObjectMoleculeOpRec *op);
 
+int ExecutiveIsomeshEtc(PyMOLGlobals *G, 
+                        char *mesh_name, char *map_name, float lvl, 
+                        char *sele, float fbuf, int state, 
+                        float carve, int map_state, int quiet,
+                        int mesh_mode, int box_mode, float alt_lvl);
+
+int ExecutiveIsosurfaceEtc(PyMOLGlobals *G, 
+                           char *surf_name, char *map_name, float lvl, 
+                           char *sele, float fbuf, int state, 
+                           float carve, int map_state, int side,
+                           int quiet, int surf_mode, int box_mode);
+
 #endif
 
 
