@@ -1,7 +1,7 @@
 /* 
 A* -------------------------------------------------------------------
 B* This file contains source code for the PyMOL computer program
-C* copyright 1998-2000 by Warrn Lyford Delano of DeLano Scientific. 
+C* copyright 1998-2000 by Warren Lyford Delano of DeLano Scientific. 
 D* -------------------------------------------------------------------
 E* It is unlawful to modify or remove this copyright notice.
 F* -------------------------------------------------------------------
@@ -17,21 +17,31 @@ Z* -------------------------------------------------------------------
 #ifndef _H_CPyMOL
 #define _H_CPyMOL
 
-/* WARNING: Do not write applications against this API.  It is a
- * *private* internal interface to PyMOL for the exclusive use of
- * DeLano Scientific LLC in development of wrapped PyMOL applications
- * and as an interface layer for supporting more stable public APIs.
+/* WARNING: DO NOT DEVELOP APPLICATIONS AGAINST THIS PyMOL_* API.  
+ * 
+ * This is a internal interface to PyMOL for the exclusive use of
+ * DeLano Scientific LLC in development of PyMOL itself, for
+ * development of "wrapped" PyMOL products, and for use as foundation
+ * layer for support of stable public APIs.
  *
- * DeLano Scientific LLC will change this interface regularly and
- * without notice.  It may even vanish altogether.  Code you develop
- * against this interface is guaranteed to be fragile, time-consuming,
- * and expensive to maintain. 
+ * DeLano Scientific LLC changes this interface regularly and without
+ * notice.  It may even vanish altogether.  Code you develop against
+ * this interface is likely to be fragile, time-consuming, and
+ * expensive to maintain.
  *
- * If you feel that you absolutely must rely upon this API, then
- * please be sure to create your own lightweight wrapper layer around
- * it so that the rest of your code will be relatively insensitive to
- * changes made here.  Failure to do so will almost certainly result
- * in code that is impossible to maintain over time.
+ * Our recommended public APIs for PyMOL development are Python-based:
+ * (#1) the old "from pymol import cmd" module-based interface, or
+ * (#2) the new "from pymol2 import PyMOL; cmd=PyMOL().cmd"
+ * instance-based interface.  If you need a C, C++, Java, or
+ * ActiveX/COM interface or widget for molecular visualization, then
+ * please contact sales@delsci.com about obtaining access to our
+ * independent developer and/or OEM product APIs (e.g. JyMOL).
+ * 
+ * If you feel that you absolutely must rely upon this PyMOL_* API,
+ * then please be sure to create your own lightweight wrapper layer
+ * around it so that the rest of your code will be relatively
+ * insensitive to changes made here.  Failure to do so will almost
+ * certainly result in code that is impossible to maintain over time.
  *
  * You have been warned!
  */
@@ -137,6 +147,8 @@ typedef struct {
   int *array;
 } PyMOLreturn_int_array;
 
+typedef void PyMOLModalDrawFn(void *G);
+
 /* creation */
 
 CPyMOL *PyMOL_New(void);
@@ -156,9 +168,9 @@ void PyMOL_Stop(CPyMOL *I);
 
 /* upstream invalidation and configuration events */
 
-void PyMOL_NeedFakeDrag(CPyMOL *I);
-void PyMOL_NeedRedisplay(CPyMOL *I);
-void PyMOL_NeedSwap(CPyMOL *I);
+void PyMOL_NeedFakeDrag(CPyMOL *I); 
+void PyMOL_NeedRedisplay(CPyMOL *I); 
+void PyMOL_NeedSwap(CPyMOL *I); 
 void PyMOL_SetClickReady(CPyMOL *I, char *name, int index, int button, int mod,int x,int y);
 void PyMOL_SetPassive(CPyMOL *I, int onOff);
 void PyMOL_NeedReshape(CPyMOL *I,int mode, int x, int y, int width, int height);
@@ -170,6 +182,7 @@ void PyMOL_PopValidContext(CPyMOL *I);
 
 /* methods requiring a valid OpenGL context*/
 
+void PyMOL_AdaptToHardware(CPyMOL *I);
 void PyMOL_Draw(CPyMOL *I);
 
 /* methods that do not require a valid OpenGL context */
@@ -230,6 +243,12 @@ int PyMOL_GetProgressChanged(CPyMOL *I,int reset);
 int PyMOL_GetInterrupt(CPyMOL *I, int reset);
 void PyMOL_SetInterrupt(CPyMOL *I, int value);
 
+/* modal updates -- PyMOL is busy with some complex task, but we have
+   to return control to the host in order to get a valid draw callback */
+
+int PyMOL_GetModalDraw(CPyMOL *I);
+void PyMOL_SetModalDraw(CPyMOL *I, PyMOLModalDrawFn *fn); /* for internal use only */
+
 /* developer/transient privates */
 
 struct _PyMOLGlobals *PyMOL_GetGlobals(CPyMOL *I);
@@ -237,6 +256,11 @@ struct _PyMOLGlobals **PyMOL_GetGlobalsHandle(CPyMOL *I);
 
 void PyMOL_RunTest(CPyMOL *I, int group, int test);
 
+/* for python integration */
+
+void PyMOL_LockAPIAndUnblock(CPyMOL *I);
+void PyMOL_BlockAndUnlockAPI(CPyMOL *I);
+
 /* for Jmol integration */
 
 int PyMOL_NewG3DStream(CPyMOL *I,int **array_ptr);
@@ -376,9 +400,31 @@ PyMOLreturn_float_array PyMOL_CmdGetView(CPyMOL *I,int quiet);
 PyMOLreturn_status PyMOL_CmdDraw(CPyMOL *I,int width, int height,
                                  int antialias, int quiet);
 
+PyMOLreturn_status PyMOL_CmdCapture(CPyMOL *I, int quiet);
+
 PyMOLreturn_status PyMOL_CmdRay(CPyMOL *I,int width, int height,int antialias,
                                 float angle, float shift,int renderer, int defer, int quiet);
 
+PyMOLreturn_status PyMOL_CmdIsodot(CPyMOL *I, char *name, char *map_name, float level, char *selection,
+                                   float buffer, int state, float carve, int source_state, int quiet);
+
+PyMOLreturn_status PyMOL_CmdIsomesh(CPyMOL *I, char *name, char *map_name, float level, char *selection,
+                                    float buffer, int state, float carve, int source_state, int quiet);
+
+PyMOLreturn_status PyMOL_CmdIsosurface(CPyMOL *I,char *name, char *map_name, float level, char *selection,
+                                       float buffer, int state, float carve, int source_state, int side, 
+                                       int mode, int quiet);
+
+PyMOLreturn_status PyMOL_CmdGradient(CPyMOL *I, char *name, char *map_name, float minimum, float maximum,
+                                     char *selection, float buffer, int state, float carve, int source_state, 
+                                     int quiet);
+
+PyMOLreturn_float PyMOL_CmdIsolevel(CPyMOL *I,char *name, float level, int state, int query, int quiet);
+
+PyMOLreturn_status PyMOL_CmdRampNew(CPyMOL *I,char *name, char *map, float *range, 
+                                    int n_range, char *color, int state, char *selection,
+                                    float beyond, float within, float sigma,
+                                    int zero, int calc_mode, int quiet);
 
 /* releasing returned values */
 
