@@ -72,7 +72,7 @@ static int TestPyMOL_00_00(PyMOLGlobals *G)
 static char *get_st(const char array[][STR_MAX])
 {
   char *result=NULL,*p;
-  int c=0,l=0;
+  size_t c=0,l=0;
   while(array[c][0]) {
     l+=strlen(array[c]);
     c++;
