@@ -46,7 +46,7 @@
 #include "Scene.h"
 #include "Seq.h"
 #include "Util.h"
-
+#include "Control.h"
 
 #ifdef _PYMOL_NO_MAIN
 
@@ -125,6 +125,7 @@ void MainRunString(char *str)
   PBlock(G);
   PLockStatus(G);
   PRunStringModule(G,str);
+  PUnlockStatus(G);
   PUnblock(G);
 }
 void MainMovieCopyPrepare(int *width,int *height,int *length)
@@ -132,6 +133,7 @@ void MainMovieCopyPrepare(int *width,int *height,int *length)
   PyMOLGlobals *G = SingletonPyMOLGlobals;
   if(PLockAPIAsGlut(G,true)) {
     MovieCopyPrepare(G,width,height,length);
+    MovieSetRealtime(G,false);
     PUnlockAPIAsGlut(G);
   }
 }
@@ -161,6 +163,7 @@ void MainMovieCopyFinish(void)
   PyMOLGlobals *G = SingletonPyMOLGlobals;
   if(PLockAPIAsGlut(G,true)) {
     MovieCopyFinish(G);
+    MovieSetRealtime(G,true);
     PUnlockAPIAsGlut(G);
   }
 }
@@ -489,6 +492,7 @@ void MainRunString(char *str)
   MainPushValidContext(G);
   PRunStringModule(G,str);
   MainPopValidContext(G);
+  PUnlockStatus(G);
   PUnblock(G);
 }
 
@@ -532,7 +536,7 @@ int MainSavingUnderWhileIdle(void)
 {
   PyMOLGlobals *G = SingletonPyMOLGlobals;
   CMain *I = G->Main;
-  return(I->IdleMode>3);
+  return(I && (I->IdleMode>3));
 }
 /*========================================================================*/
 void MainSetWindowVisibility(int mode)
@@ -666,6 +670,8 @@ static void MainDrawLocked(void)
 
     PBlock(G);
 
+    if(PyErr_Occurred()) PyErr_Print();
+
     /* next, we need to let PyMOL know we have a valid context,
       because some initializations, involve GL calls (such as going
       into full-screen or stereo mode) */
@@ -677,21 +683,33 @@ static void MainDrawLocked(void)
     /* restore working directory if asked to */
     PRunStringModule(G,"if os.environ.has_key('PYMOL_WD'): os.chdir(os.environ['PYMOL_WD'])");
 
+    if(PyErr_Occurred()) PyErr_Print();
+
 /* BEGIN PROPRIETARY CODE SEGMENT (see disclaimer in "os_proprietary.h") */ 
 #ifdef _PYMOL_OSX
     PRunStringModule(G,"if os.getcwd()[-23:]=='.app/Contents/Resources': os.chdir('../../..')");
 #endif
 /* END PROPRIETARY CODE SEGMENT */    
+
+    if(PyErr_Occurred()) PyErr_Print();
     
     PXDecRef(PyObject_CallMethod(G->P_inst->obj,"launch_gui","O",G->P_inst->obj));
-    
+
+    if(PyErr_Occurred()) PyErr_Print();
+
     PXDecRef(PyObject_CallMethod(G->P_inst->obj,"adapt_to_hardware","O",G->P_inst->obj));
+
+    if(PyErr_Occurred()) PyErr_Print();
     
     if(G->Option->incentive_product) { /* perform incentive product initialization (if any) */
       PyRun_SimpleString("try:\n   import ipymol\nexcept:\n   pass\n");
+      if(PyErr_Occurred()) PyErr_Print();
     }
     
     PXDecRef(PyObject_CallMethod(G->P_inst->obj,"exec_deferred","O",G->P_inst->obj));
+
+    if(PyErr_Occurred()) PyErr_Print();
+      
 #ifdef _PYMOL_SHARP3D
     /*PParse("load $TUT/1hpv.pdb;hide;show sticks;show surface;set surface_color,white;set transparency,0.5;stereo on");*/
     /*PParse("stereo on");
@@ -867,6 +885,7 @@ static void MainDrawProgress(PyMOLGlobals *G)
 /*========================================================================*/
 static void MainDraw(void)
 {
+  int usec_sleep_after_draw = 0;
   PyMOLGlobals *G = SingletonPyMOLGlobals;
 
   PRINTFD(G,FB_Main)
@@ -912,6 +931,9 @@ static void MainDraw(void)
     if(!skip) {
       MainDrawLocked();
       I->DrawnFlag = true;
+      if(PyMOL_GetModalDraw(PyMOLInstance)) {
+        usec_sleep_after_draw = 10000; /* give other threads a chance to run */
+      }
     } else {
       PyMOL_NeedRedisplay(PyMOLInstance);
     }
@@ -922,6 +944,9 @@ static void MainDraw(void)
   PRINTFD(G,FB_Main)
     " MainDraw: completed.\n"
     ENDFD;
+  if(usec_sleep_after_draw && G) {
+    PSleepUnlocked(G, usec_sleep_after_draw);
+  }
 }
 /*========================================================================*/
 static void MainKey(unsigned char k, int x, int y)
@@ -1062,21 +1087,21 @@ void MainDoReshape(int width, int height) /* called internally */
     
     /* if we have a GUI, for a reshape event */
     
-    if(G->HaveGUI) {
+    if(G->HaveGUI && G->ValidContext) {
       p_glutReshapeWindow(width,height);
       glViewport(0, 0, (GLint) width, (GLint) height);
     }
     
-    
-    PyMOL_Reshape(PyMOLInstance, width, height, force);
+    PyMOL_Reshape(G->PyMOL, width, height, force);
     
     if(G->Main) {
       G->Main->DeferReshapeDeferral = 1;
     }
     /* do we need to become full-screen? */
     
-    if(SettingGet(G,cSetting_full_screen))
+    if(SettingGet(G,cSetting_full_screen) && G->HaveGUI && G->ValidContext) {
       p_glutFullScreen();
+    }
   }
 
 }
@@ -1246,19 +1271,15 @@ static void MainBusyIdle(void)
       " MainBusyIdle: calling idle function.\n"
       ENDFD;
 
-
     if(PyMOL_Idle(PyMOLInstance)) {
-      if(I->IdleMode<2) {
-        I->IdleMode = 2;
-        I->IdleTime = UtilGetSeconds(G);
-      }
+      /* we did some work, so keep PyMOL responsive */
+      I->IdleMode = 1;
     } else if(!I->IdleMode) {
       I->IdleMode = 1;
     } else if(I->IdleMode == 1) {
       I->IdleMode = 2;
       I->IdleTime = UtilGetSeconds(G);
     }
-
     PRINTFD(G,FB_Main)
       " MainBusyIdle: swap check.\n"
       ENDFD;
@@ -1322,31 +1343,39 @@ static void MainBusyIdle(void)
       " MainBusyIdle: unlocking.\n"
       ENDFD;
 
-    PUnlockAPIAsGlut(G);
-    
-    switch(I->IdleMode) {
-    case 4:
-      PSleepUnlocked(G,SettingGetGlobal_i(G,cSetting_slow_idle)); /* slow idle - save CPU cycles */
-      break;
-    case 3:
-      PSleepUnlocked(G,SettingGetGlobal_i(G,cSetting_fast_idle)); /* fast idle - more responsive */
-      break;
-    case 2:
-      PSleepUnlocked(G,SettingGetGlobal_i(G,cSetting_no_idle)); /* give Tcl/Tk a chance to run */
-      break;
-    default:
-      break;
+    {
+      int control_idling = false;
+      if(I->IdleMode==1) {
+        control_idling = ControlIdling(G);
+      }
+      PUnlockAPIAsGlut(G);
+      
+      switch(I->IdleMode) {
+      case 4:
+        PSleepUnlocked(G,SettingGetGlobal_i(G,cSetting_slow_idle)); /* slow idle - save CPU cycles */
+        break;
+      case 3:
+        PSleepUnlocked(G,SettingGetGlobal_i(G,cSetting_fast_idle)); /* fast idle - more responsive */
+        break;
+      case 2:
+        PSleepUnlocked(G,SettingGetGlobal_i(G,cSetting_no_idle)); /* give Tcl/Tk a chance to run */
+        break;
+      case 1:
+        if(control_idling) {
+          PSleepUnlocked(G,SettingGetGlobal_i(G,cSetting_no_idle)); /* give Tcl/Tk a chance to run */
+        }
+        break;
+      default:
+        break;
+      }
     }
     
     /* run final initilization code for Python-based PyMOL implementations. */
     
 #define FINAL_INIT_AT 10
-    
-    if(I->FinalInitCounter<FINAL_INIT_AT)
-      {
+    if(I->FinalInitCounter<FINAL_INIT_AT) {
         I->FinalInitCounter=I->FinalInitCounter+1;
         if(I->FinalInitCounter==FINAL_INIT_AT) {
-          
           I->FinalInitTrigger=true;
           PyMOL_NeedRedisplay(PyMOLInstance);
         }
@@ -1396,13 +1425,23 @@ static void MainBusyIdle(void)
 }
 void MainRepositionWindowDefault(PyMOLGlobals *G)
 {
+#ifdef _PYMOL_FINK
+  p_glutPositionWindow(G->Option->winPX,G->Option->winPY-22);
+ /* something is wrong with FinkGlut's window positioning...*/
+#else
   p_glutPositionWindow(G->Option->winPX,G->Option->winPY);
+#endif
+
   p_glutReshapeWindow(G->Option->winX,G->Option->winY);
 }
 void MainSetWindowPosition(PyMOLGlobals *G,int x,int y)
 {
+#ifdef _PYMOL_FINK
+  y -= 22; /* something is wrong with FinkGlut's window positioning...*/
+#endif
   p_glutPositionWindow(x,y);
 }
+
 void MainSetWindowSize(PyMOLGlobals *G,int w,int h)
 {
   G->Main->DeferReshapeDeferral = 1;
@@ -1646,24 +1685,6 @@ SetConsoleCtrlHandler(
      PUnblock(G);
      
      if(G->HaveGUI) {
-       SceneSetCardInfo(G,(char*)glGetString(GL_VENDOR),
-                        (char*)glGetString(GL_RENDERER),
-                        (char*)glGetString(GL_VERSION));
-       if(G->Option->show_splash) {
-         
-         printf(" OpenGL graphics engine:\n");
-         printf("  GL_VENDOR: %s\n",(char*)glGetString(GL_VENDOR));
-         printf("  GL_RENDERER: %s\n",(char*)glGetString(GL_RENDERER));
-         printf("  GL_VERSION: %s\n",(char*)glGetString(GL_VERSION));
-         if(Feedback(G,FB_OpenGL,FB_Blather)) {
-           printf("  GL_EXTENSIONS: %s\n",(char*)glGetString(GL_EXTENSIONS));
-         }
-         if(G->StereoCapable) {
-           printf("  Hardware stereo capability detected.\n");
-         } else if((G->Option->force_stereo==1)&&(!G->StereoCapable)) {
-           printf("  Hardware stereo not present (unable to force).\n");
-         }
-       } 
        if(!I->WindowIsVisible)
          MainReshape(G->Option->winX,G->Option->winY);
        I->IdleMode=3;
