@@ -19,8 +19,17 @@ Z* -------------------------------------------------------------------
 
 int  MainSavingUnderWhileIdle(void);
 
+
 #ifdef _PYMOL_NO_MAIN
 
+/* BEGIN PROPRIETARY CODE SEGMENT (see disclaimer in "os_proprietary.h") */
+#ifdef _MACPYMOL_XCODE
+#include"os_python.h"
+#include"PyMOLGlobals.h"
+PyObject *MainAsPyList(void);
+#endif
+/* END PROPRIETARY CODE SEGMENT */
+
 #else
 
 #include"os_python.h"
@@ -39,9 +48,14 @@ PyObject *MainAsPyList(void);
 void MainRepositionWindowDefault(PyMOLGlobals *G);
 
 void MainSetWindowVisibility(int mode);
+void MainMaximizeWindow(PyMOLGlobals *G);
+void MainSetWindowSize(PyMOLGlobals *G,int w,int h);
+void MainSetWindowPosition(PyMOLGlobals *G,int x,int y);
+void MainCheckWindowFit(PyMOLGlobals *G);
 
-#ifdef _PYMOL_OSX
 
+/* BEGIN PROPRIETARY CODE SEGMENT (see disclaimer in "os_proprietary.h") */
+#ifdef _MACPYMOL_XCODE
 int MainCheckRedundantOpen(char *file);
 void MainRunString(char *str);
 PyObject *MainGetStringResult(char *str);
@@ -51,10 +65,12 @@ void MainMoviePrepareCopy(int *width,int *height,int *length);
 int MainMovieCopy(int frame,int width,int height,int rowbytes,void *ptr);
 void MainMovieCopyPrepare(int *width,int *height,int *length);
 int MainMovieCopyFrame(int frame,int width,int height,int rowbytes,void *ptr);
+int MainMoviePurgeFrame(int frame);
 void MainMovieCopyFinish(void);
 void MainSceneGetSize(int *width,int *height);
 int MainSceneCopy(int width,int height,int rowbytes,void *ptr);
 #endif
+/* END PROPRIETARY CODE SEGMENT */
 
 #define PYMOL_MAX_OPT_STR  1025
 
