@@ -21,6 +21,7 @@ import threading
 import traceback
 import Queue
 import __builtin__
+import types
 
 # ensure that PyMOL seach path is used...
 
@@ -46,8 +47,8 @@ class PMGApp(Pmw.MegaWidget):
          # try to get the windows properly aligned...
          
          osFrame = { 'win32' : (4,60), 'irix'   : (0,41),
-                         'darwin': (0,51), 'cygwin' : (0,60),
-                         'linux' : (0,31), 'linux2' : (0,31) }
+                     'darwin': (0,51), 'cygwin' : (0,60),
+                     'linux' : (0,31), 'linux2' : (0,31) }
 
          if sys.platform in osFrame.keys():
              (self.frameXAdjust,self.frameYAdjust) = osFrame[sys.platform]
@@ -65,6 +66,69 @@ class PMGApp(Pmw.MegaWidget):
     def initializeTk_unix(self):
         pass
 
+    def getLoadableFileTypes(self):
+        return [("All Readable","*.pdb"),
+                ("All Readable","*.pdb1"),                
+                ("All Readable","*.ccp4"),
+                ("All Readable","*.xplor"),
+                ("All Readable","*.mol"),
+                ("All Readable","*.mol2"),
+                ("All Readable","*.sdf"),
+                ("All Readable","*.xyz"),
+                ("All Readable","*.r3d"),
+                ("All Readable","*.cc1"),
+                ("All Readable","*.cc2"), 
+                ("All Readable","*.ent"),
+                ("All Readable","*.dat"),
+                ("All Readable","*.out"),
+                ("All Readable","*.mmd"),
+                ("All Readable","*.mmod"),
+                ("All Readable","*.pse"),
+                ("All Readable","*.phi"),
+                ("All Readable","*.fld"),
+                ("All Readable","*.grd"),
+                ("All Readable","*.o"),
+                ("All Readable","*.omap"), 
+                ("All Readable","*.brix"),
+                ("All Readable","*.dx"),
+                ("All Readable","*.pqr"),
+                ("All Readable","*.p5m"),
+                ("All Readable","*.p1m"),
+                ("All Readable","*.cube"),
+                ("All Readable","*.cif"),
+                ("All Readable","*.moe"), # proprietary format
+                ("All Readable","*.mae"), # proprietary format
+                ("PDB File","*.pdb"),
+                ("PDB1 File","*.pdb1"),                
+                ("All Files","*.*"),
+                ("All Files","*"),  
+                ("PDB File","*.ent"),
+                ("PyMOL Session","*.pse"),
+                ("CCP4 Map","*.ccp4"), 
+                ("XPLOR Map","*.xplor"),
+                ("MOL2/Multi-MOL2","*.mol2"),
+                ("Macromodel File","*.dat"),
+                ("Macromodel File","*.out"),
+                ("Macromodel File","*.mmd"),
+                ("Macromodel File","*.mmod"),
+                ("BRIX/O Map","*.o"),
+                ("BRIX/O Map","*.omap"),
+                ("BRIX/O Map","*.brix"),
+                ("CIF","*.cif"),
+                ("Gaussian Cube Map","*.cube"),
+                ("DX Map","*.dx"),     
+                ("AVS (MEAD) Field","*.fld"),    
+                ("MOL File","*.mol"),
+                ("MOE File","*.moe"), # proprietary format
+                ("MAE File","*.mae"), # proprietary format  
+                ("ChemPy Model","*.pkl"),
+                ("Raster3D Scene","*.r3d"),
+                ("SDF File","*.sdf"),
+                ("ChemDraw3D File","*.cc1"),
+                ("ChemDraw3D File","*.cc2"),
+                ("Tinker XYZ File","*.xyz")
+                ]
+
     def initializeTk_colors_common(self):
         #self.root.option_add('*background', 'grey')   #let system decide
         self.root.option_add('*foreground', 'black')
@@ -76,7 +140,6 @@ class PMGApp(Pmw.MegaWidget):
         self.root.option_add('*Listbox*selectForeground', 'white')
         
     def quit_app(self):
-        print "here"
         self.pymol.cmd.log_close()
         self.pymol.cmd.quit()  # avoid logging this - it's inconvenient...
 
@@ -111,7 +174,7 @@ class PMGApp(Pmw.MegaWidget):
     def execute(self,cmmd):  
         self.fifo.put(cmmd)
 
-    def install_plugin(self):
+    def installPlugin(self):
         plugdir = os.path.split(__file__)[0]
         path = os.path.join(plugdir, "startup", "check_writable")
         ok = 1
@@ -144,7 +207,7 @@ class PMGApp(Pmw.MegaWidget):
                     traceback.print_exc()
                     tkMessageBox.showinfo("Error", "unable to install plugin '%s'" % plugname)
 
-    def initialize_plugins(self):
+    def initializePlugins(self):
         startup_pattern = re.sub(r"[\/\\][^\/\\]*$","/startup/*.py*",__file__)
         # startup_pattern = os.environ['PYMOL_PATH']+"/modules/pmg_tk/startup/*.py*"
         raw_list = glob(startup_pattern)
@@ -172,11 +235,47 @@ class PMGApp(Pmw.MegaWidget):
                     print "Exception in plugin '%s' -- Traceback follows..."%name
                     traceback.print_exc()
                     print "Error: unable to initialize plugin '%s'."%name
-                    
-    def set_skin(self,skin):
-        self.skin = skin
+
+    def addSkinMenuItems(self,menuBar,menuName):
+        if not hasattr(self,'skinNameList'):
+            # find installed skins
+            skin_pattern = re.sub(r"[\/\\][^\/\\]*$","/skins/*/__init__.py*",__file__)
+            raw_list = glob(skin_pattern)
+            unique = {}
+            for a in raw_list:
+                key = re.sub(r"[\/\\]__init__\.py.*$","",a)
+                unique[re.sub(r".*[\/\\]","",key)] = 1
+            name_list = unique.keys()
+            name_list.sort()
+            self.skinNameList = name_list
+        if hasattr(self,'skinNameList'):
+            for name in self.skinNameList:
+                caps_name = string.upper(name)[0:1]+string.lower(name)[1:]
+                menuBar.addmenuitem(menuName, 'command', name,
+                                    label=caps_name,
+                                    command=lambda s=self,n=name:s.setSkin(n))
+
+        
+    def setSkin(self,skin,run=1):
+        if isinstance(skin,types.StringType):
+            inv = sys.modules.get("pymol.invocation",None)
+            if inv!=None:
+                module_path = inv.options.gui +".skins."+ skin
+                __import__(inv.options.gui +".skins."+ skin)
+                skin = sys.modules[module_path].__init__(self)
+        if skin != self.skin:
+            if self.skin != None:
+                self.skin.takedown()
+            self.skin = skin
+
+        if run:
+            self.runSkin()
+            
+    def runSkin(self):
+        if self.skin != None:
+            self.skin.setup()
     
-    def __init__(self, pymol_instance):
+    def __init__(self, pymol_instance, skin):
 
         self.allow_after = 1 # easy switch for troubleshooting threads
 
@@ -221,23 +320,22 @@ class PMGApp(Pmw.MegaWidget):
             # read the command line arguments regarding:
             # - the size of the root window
             # - the skin to use
-            
+
             inv = sys.modules.get("pymol.invocation",None)
-            if inv!=None:
+            if inv != None:
+                if skin == None:
+                    skin = inv.options.skin
                 self.frameWidth = inv.options.win_x + 220
                 self.frameXPos = inv.options.win_px - self.frameXAdjust
                 self.frameHeight = inv.options.ext_y
                 self.frameYPos = inv.options.win_py - (
                          self.frameHeight + self.frameYAdjust)
-                module_path = inv.options.gui +".skins."+ inv.options.skin
-                __import__(inv.options.gui +".skins."+ inv.options.skin)
-                sys.modules[module_path].__init__(self)
+                self.setSkin(skin,run=0)
                 
             # define the size of the root window
             
             self.root.geometry('%dx%d+%d+%d' % (
                 self.frameWidth, self.frameHeight, self.frameXPos, self.frameYPos))
-
             
             # activate polling on the fifo
 
@@ -246,7 +344,6 @@ class PMGApp(Pmw.MegaWidget):
 
             # and let 'er rip
 
-            if self.skin != None:
-                self.skin.setup()
+            self.runSkin()
 
 
