@@ -29,6 +29,7 @@
 # message.  This is not a bug in PyMOL, as it can be produced with a
 # trivial tcl/tk program.  (Tentatively WORKED AROUND in 0.99beta18!)
 
+from copy import deepcopy
 import __main__
 if __name__!='__main__':
     import invocation
@@ -73,6 +74,13 @@ def _init_internals(_pymol):
     _pymol._session_save_tasks = [ None ]
     _pymol._session_restore_tasks = [ None ]
 
+    # cached results (as a list):
+    # [ [size, (hash1, hash2, ... ), (inp1, inp2, ...), output],
+    #   [size, (hash1, hash2, ... ), (inp1, inp2, ...), output],
+    #   ... ]
+    
+    _pymol._cache = []
+
     # standard input reading thread
 
     _pymol._stdin_reader_thread = None
@@ -90,14 +98,22 @@ def _init_internals(_pymol):
     _pymol._scene_counter = 1
     _pymol._scene_quit_on_action = ''
 
+    # get us a private invocation pseudo-module
+    
+    _pymol._invocation = Scratch_Storage()
+    _pymol._invocation.options = deepcopy(invocation.options)
+    _pymol._invocation.get_user_config = invocation.get_user_config
+    _pymol._invocation.parse_args = invocation.parse_args
+
     # these locks are to be shared by all PyMOL instances within a
     # single Python interpeter
         
-    _pymol.lock_api = threading.RLock() # mutex for API 
+    _pymol.lock_api = threading.RLock() # mutex for API calls from the outside
     _pymol.lock_api_c = threading.RLock() # mutex for C management of python threads
     _pymol.lock_api_status = threading.RLock() # mutex for PyMOL status info
-    _pymol.lock_api_glut = threading.RLock() # mutex for avoiding GLUT
-
+    _pymol.lock_api_glut = threading.RLock() # mutex for GLUT avoidance
+    _pymol.lock_api_data = threading.RLock() # mutex for internal data structures
+    
 if hasattr(__main__,'pymol_launch'):
     pymol_launch = __main__.pymol_launch
 else:
@@ -248,7 +264,7 @@ if pymol_launch != 3: # if this isn't a dry run
                     _stdin_reader_thread.setDaemon(1)
                     _stdin_reader_thread.start()
                 except:
-                    trackback.print_exc()
+                    traceback.print_exc()
             try:
                 if cmd.ready():
                     cmd.config_mouse(quiet=1)
@@ -273,6 +289,14 @@ if pymol_launch != 3: # if this isn't a dry run
 
         def adapt_to_hardware(self):
             cmd=self.cmd
+
+            # optimize for VISTA
+            if sys.platform[0:3]=='win':
+                if sys.getwindowsversion()[0]>5:
+                    # improves performance 
+                    cmd.set('texture_fonts') 
+                    
+            # optimize for (or workaround) specific hardware
             (vendor,renderer,version) = cmd.get_renderer()
             if vendor[0:6]=='NVIDIA':
                 cmd.set('ribbon_smooth',0,quiet=1)
@@ -301,12 +325,22 @@ if pymol_launch != 3: # if this isn't a dry run
                 if renderer[0:18]=='Mesa GLX Indirect':
                     cmd.set('ribbon_smooth',0,quiet=1)
 
+            elif vendor[0:9]=='Parallels':
+                if renderer[0:8]=='Parallel':
+                    # this was critical for older Parallels
+                    # but actually slows down current versions
+                    cmd.set('texture_fonts',1) 
+
             elif vendor[0:3]=='ATI':
                 cmd.set('ribbon_smooth',0,quiet=1)
                 if renderer[0:17]=='FireGL2 / FireGL3':
                     if invocation.options.show_splash:
                         print " Adapting to FireGL hardware."
                     cmd.set('line_width','2',quiet=1)            
+                if sys.platform[0:3]=='win':
+                    if sys.getwindowsversion()[0]>5:
+                        cmd.set('ati_bugs',1) # Ugh, VISTA.
+
             elif vendor[0:9]=='Microsoft':
                 if renderer[0:17]=='GDI Generic':
                     cmd.set('light_count',1)
@@ -348,7 +382,7 @@ if pymol_launch != 3: # if this isn't a dry run
                 if ncpu>1:
                      cmd.set("max_threads",ncpu)
                      if invocation.options.show_splash:  
-                          print " Detected %d CPUs."%ncpu,
+                          print " Detected %d CPU cores."%ncpu,
                           print " Enabled multithreaded rendering."
             except:
                 pass
@@ -356,26 +390,29 @@ if pymol_launch != 3: # if this isn't a dry run
         # NEED SOME CONTRIBUTIONS HERE!
 
         def launch_gui(self):
-            if sys.platform=='darwin':
-                poll=1
-       	    else:
-                poll=0
-            if self.invocation.options.external_gui==1:
-                __import__(self.invocation.options.gui)
-                sys.modules[self.invocation.options.gui].__init__(self,poll)
-            elif self.invocation.options.external_gui==3:
-                os.environ['DISPLAY']=':0.0'
-                os.environ['TCL_LIBRARY']=os.environ['PYMOL_PATH']+"/ext/lib/tcl8.4"
-                os.environ['TK_LIBRARY']=os.environ['PYMOL_PATH']+"/ext/lib/tk8.4"
-                __import__(self.invocation.options.gui)
-                sys.modules[self.invocation.options.gui].__init__(self,poll)
-
-        # -- Greg Landrum's RPC stuff
-            if self.invocation.options.rpcServer:
-                import rpc
-                rpc.launch_XMLRPC()
-        # --
+            try:
+                if sys.platform=='darwin':
+                    poll=1
+                else:
+                    poll=0
+                skin = self.invocation.options.skin
+                if self.invocation.options.external_gui==1:
+                    __import__(self.invocation.options.gui)
+                    sys.modules[self.invocation.options.gui].__init__(self,poll,skin)
+                elif self.invocation.options.external_gui==3:
+                    os.environ['DISPLAY']=':0.0'
+                    os.environ['TCL_LIBRARY']=os.environ['PYMOL_PATH']+"/ext/lib/tcl8.4"
+                    os.environ['TK_LIBRARY']=os.environ['PYMOL_PATH']+"/ext/lib/tk8.4"
+                    __import__(self.invocation.options.gui)
+                    sys.modules[self.invocation.options.gui].__init__(self,poll,skin)
 
+            # -- Greg Landrum's RPC stuff
+                if self.invocation.options.rpcServer:
+                    import rpc
+                    rpc.launch_XMLRPC()
+            # --
+            except:
+                traceback.print_exc()
     def prime_pymol():
         global glutThread
         try:
@@ -385,8 +422,13 @@ if pymol_launch != 3: # if this isn't a dry run
         pymol_launch = 0 # never do this again : )
         if (sys.platform=='darwin') and (invocation.options.external_gui==1):
             import os
-            os.system("/usr/bin/open -a X11") # launch X11 if we're going to need it
-
+            xdpyinfo = "/usr/X11R6/bin/xdpyinfo"
+            if os.path.exists(xdpyinfo):
+                if os.system(xdpyinfo+" >/dev/null 2>&1"):
+                    os.system("/usr/bin/open -a X11") # launch X11 (if needed)
+            else:
+                os.system("/usr/bin/open -a X11") # launch X11 (if needed)
+                
     def start_pymol(block_input_hook=0):
         prime_pymol()
         _COb = _cmd._get_global_C_object()        
@@ -410,7 +452,7 @@ if pymol_launch != 3: # if this isn't a dry run
         else:
             pymol._COb = cmd._COb
         from pymol import invocation
-        invocation.parse_args(pymol_argv)
+        invocation.parse_args(pymol_argv)            
         start_pymol(0)
 
     elif pymol_launch==2: # threaded launch (create new thread)
@@ -432,7 +474,8 @@ if pymol_launch != 3: # if this isn't a dry run
             _COb = cmd._COb
         else:
             pymol._COb = cmd._COb
-        invocation.parse_args(pymol_argv)
+        from pymol import invocation
+        invocation.parse_args(pymol_argv)            
         prime_pymol()
         # count on host process to actually start PyMOL
 
@@ -443,7 +486,7 @@ if pymol_launch != 3: # if this isn't a dry run
         _COb = _cmd._get_global_C_object()
         e=threading.Event()
         import pymol # wait for import to complete
-        while not _cmd.ready(_CObj): # wait for the C library to initialize
+        while not _cmd.ready(_COb): # wait for the C library to initialize
             e.wait(0.01)
         while not hasattr(pymol,'xray'): # make sure symmetry module has time to start...
             e.wait(0.01)
