@@ -22,12 +22,12 @@ if __name__=='pymol.commanding':
     import threading
     import traceback
     import parsing
-    
     import cmd
     import pymol
+    
     from cmd import _cmd, Shortcut, QuietException, \
           fb_module, fb_mask, is_list, \
-          DEFAULT_ERROR, DEFAULT_SUCCESS, is_ok, is_error
+          DEFAULT_ERROR, DEFAULT_SUCCESS, is_ok, is_error, is_string
 
     def resume(filename, _self=cmd):
         '''
@@ -58,6 +58,21 @@ SEE ALSO
         if _self._raising(r,_self): raise pymol.CmdException
         return r
 
+
+    class QueueFile:
+
+        def __init__(self,queue):
+            self.queue = queue
+
+        def write(self,command):
+            self.queue.put(command)
+
+        def flush(self):
+            pass
+
+        def close(self):
+            del self.queue
+ 
     def log_open(filename='log.pml', mode='w', _self=cmd):
         '''
 DESCRIPTION
@@ -73,33 +88,37 @@ SEE ALSO
     log, log_close
     
         '''
-        pymol=_self._pymol        
-        try:
+        pymol=_self._pymol
+        if not is_string(filename): # we're logging to Queue, not a file.
+            pymol._log_file = QueueFile(filename)
+            _self.set("logging",1,quiet=1)
+        else:
             try:
-                if hasattr(pymol,"_log_file"):
-                    if pymol._log_file!=None:
-                        pymol._log_file.close()
-                        del pymol._log_file
-            except:
-                pass
-            pymol._log_file = open(filename,mode)
-            if _self._feedback(fb_module.cmd,fb_mask.details): # redundant
-                if mode!='a':
-                    print " Cmd: logging to '%s'."%filename
+                try:
+                    if hasattr(pymol,"_log_file"):
+                        if pymol._log_file!=None:
+                            pymol._log_file.close()
+                            del pymol._log_file
+                except:
+                    pass
+                pymol._log_file = open(filename,mode)
+                if _self._feedback(fb_module.cmd,fb_mask.details): # redundant
+                    if mode!='a':
+                        print " Cmd: logging to '%s'."%filename
+                    else:
+                        print " Cmd: appending to '%s'."%filename            
+                if mode=='a':
+                    pymol._log_file.write("\n") # always start on a new line
+                if(re.search(r"\.py$|\.PY$|\.pym$|\.PYM$",filename)):
+                    _self.set("logging",2,quiet=1)
                 else:
-                    print " Cmd: appending to '%s'."%filename            
-            if mode=='a':
-                pymol._log_file.write("\n") # always start on a new line
-            if(re.search(r"\.py$|\.PY$|\.pym$|\.PYM$",filename)):
-                _self.set("logging",2,quiet=1)
-            else:
-                _self.set("logging",1,quiet=1)
-        except:
-            print"Error: unable to open log file '%s'"%filename
-            pymol._log_file = None
-            _self.set("logging",0,quiet=1)
-            traceback.print_exc()
-            raise QuietException
+                    _self.set("logging",1,quiet=1)
+            except:
+                print"Error: unable to open log file '%s'"%filename
+                pymol._log_file = None
+                _self.set("logging",0,quiet=1)
+                traceback.print_exc()
+                raise QuietException
 
     def log(text, alt_text=None, _self=cmd):
         '''
@@ -114,17 +133,18 @@ SEE ALSO
         '''
         pymol=_self._pymol        
         cmd=_self
-        if pymol._log_file!=None:
-            mode = _self.get_setting_legacy("logging")
-            if mode:
-                if mode==1:
-                    pymol._log_file.write(text)
-                elif mode==2:
-                    if alt_text!=None:
-                        pymol._log_file.write(alt_text)
-                    else:
-                        pymol._log_file.write("cmd.do('''%s''')\n"%string.strip(text))
-                pymol._log_file.flush()
+        if hasattr(pymol,"_log_file"):
+            if pymol._log_file!=None:
+                mode = _self.get_setting_legacy("logging")
+                if mode:
+                    if mode==1:
+                        pymol._log_file.write(text)
+                    elif mode==2:
+                        if alt_text!=None:
+                            pymol._log_file.write(alt_text)
+                        else:
+                            pymol._log_file.write("cmd.do('''%s''')\n"%string.strip(text))
+                    pymol._log_file.flush()
 
     def log_close(_self=cmd):
         '''
@@ -143,12 +163,13 @@ SEE ALSO
         '''
         pymol=_self._pymol        
         cmd=_self
-        if pymol._log_file!=None:
-            pymol._log_file.close()
-            del pymol._log_file
-            _self.set("logging",0,quiet=1)
-            if _self._feedback(fb_module.cmd,fb_mask.details): # redundant
-                print " Cmd: log closed."
+        if hasattr(pymol,"_log_file"):
+            if pymol._log_file!=None:
+                pymol._log_file.close()
+                del pymol._log_file
+                _self.set("logging",0,quiet=1)
+                if _self._feedback(fb_module.cmd,fb_mask.details): # redundant
+                    print " Cmd: log closed."
 
     def cls(_self=cmd): 
         '''
@@ -220,7 +241,11 @@ USAGE
     reinit_code = {
         'everything' : 0,
         'settings' : 1,
+        'store_defaults' : 2,
+        'original_settings' : 3,
+        'purge_defaults' : 4,
     }
+    
     reinit_sc = Shortcut(reinit_code.keys())
 
     def reinitialize(what='everything', object='', _self=cmd):
@@ -287,7 +312,7 @@ SEE ALSO
                         break
             
 
-    def do(commands,log=1,echo=1,_self=cmd):
+    def do(commands,log=1,echo=1,flush=1,_self=cmd):
         # WARNING: don't call this routine if you already have the API lock
         # use cmd._do instead
         '''
@@ -311,8 +336,12 @@ USAGE (PYTHON)
             cmmd_list = commands
         else:
             cmmd_list = [ commands ]
+        n_cmmd = len(cmmd_list)
+        if n_cmmd>1: # if processing a list of commands, defer updates
+            defer = _self.get_setting_legacy("defer_updates")
+            _self.set('defer_updates',1)
         for cmmd in cmmd_list:
-            lst = string.split(string.replace(cmmd,chr(13),chr(10)),chr(10))
+            lst = string.split(string.replace(cmmd,chr(13),chr(10)),chr(10)) 
             if len(lst)<2:
                 for a in lst:
                     if(len(a)):
@@ -321,22 +350,27 @@ USAGE (PYTHON)
                             r = _cmd.do(_self._COb,a,log,echo)
                         finally:
                             _self.unlock(r,_self)
+
                     else:
                         r = DEFAULT_SUCCESS
             else:
-                defer = _self.get_setting_legacy("defer_updates")
-                _self.set('defer_updates',1)
-                for a in lst:
-                    if(len(a)):
-                        try:
-                            _self.lock(_self)
+                try:
+                    _self.lock(_self)
+                    do_flush = ((thread.get_ident() == _self._pymol.glutThread)
+                                and _self.lock_api_allow_flush)
+                    for a in lst:
+                        if len(a):
                             r = _cmd.do(_self._COb,a,log,echo)
-                        finally:
-                            _self.unlock(r,_self)
-                    else:
-                        r = DEFAULT_SUCCESS
-                _self.set('defer_updates',defer)
-        if _self._raising(r,_self): raise pymol.CmdException            
+                            if do_flush:
+                                _self.unlock(r,_self) # flushes
+                                _self.lock(_self)
+                        else:
+                            r = DEFAULT_SUCCESS
+                finally:
+                    _self.unlock(r,_self)
+        if n_cmmd>1:
+            _self.set('defer_updates',defer)
+        if _self._raising(r,_self): raise pymol.CmdException
         return r
 
     def quit(_self=cmd):
@@ -354,7 +388,7 @@ PYMOL API
     cmd.quit()
         '''
         if thread.get_ident() == pymol.glutThread:
-            _self._quit()
+            _self._quit(_self)
         else:
             try:
                 _self.lock(_self)
@@ -365,7 +399,7 @@ PYMOL API
                 except SystemExit:
                     pass
             finally:
-                _self.unlock(_self=_self)
+                _self.unlock(-1,_self=_self)
         return None
 
     def delete(name,_self=cmd):
