@@ -21,14 +21,8 @@ if __name__=='pymol.controlling':
     
     from cmd import _cmd, Shortcut, QuietException, is_string, \
           boolean_dict, boolean_sc, \
-          DEFAULT_ERROR, DEFAULT_SUCCESS, is_ok, is_error
-
-    location_code = {
-        'top' : -1,
-        'current' : 0,
-        'bottom' : 1
-    }
-    location_sc = Shortcut(location_code.keys())
+          DEFAULT_ERROR, DEFAULT_SUCCESS, is_ok, is_error, \
+          location_code, location_sc 
 
     button_code = {
         'left' : 0,
@@ -111,6 +105,9 @@ if __name__=='pymol.controlling':
         'movv' : 46 ,
         'mvvz' : 47 ,
 
+        # 48 for internal use only
+        
+        'drgo' : 49 ,
         }
     
     but_act_sc = Shortcut(but_act_code.keys())
@@ -394,28 +391,34 @@ DESCRIPTION
 
 USAGE
 
-    order names-list, sort, location
+    order names, sort, location
+
+ARGUMENTS
+
+    names = string: a space-separated list of names
+
+    sort = yes or no {default: no}
+
+    location = top, current, or bottom {default: current}
 
 EXAMPLES
 
-    order 1dn2 1fgh 1rnd  # sets the order of these three objects
-    order *,yes           # sorts all names
-    order 1dn2_*, yes     # sorts all names beginning with 1dn2_
+    order 1dn2 1fgh 1rnd       # sets the order of these three objects
+    order *,yes                # sorts all names
+    order 1dn2_*, yes          # sorts all names beginning with 1dn2_
     order 1frg, location=top   # puts 1frg at the top of the list
 
 PYMOL API
 
-    cmd.order(string names-list, string sort, string location)
+    cmd.order(string names, string sort, string location)
 
 NOTES
 
-    names-list: a space separated list of names
-    sort: yes or no
-    location: top, current, or bottom
-
+    "order" can also be used to reorder objects within a group.
+    
 SEE ALSO
 
-    set_name
+    set_name, group
         '''
 
         r = DEFAULT_ERROR
@@ -444,6 +447,7 @@ USAGE
 
 '''
         # NOTE: PyMOL automatically runs this routine upon start-up
+        r = DEFAULT_ERROR
         try:
             _self.lock(_self)
 
@@ -483,15 +487,18 @@ USAGE
                     _self.set("button_mode",bm)
                 mode_list = mode_dict[mode]
             if mode_list!=None:
+                kw_dict = {'_self':_self}
                 for a in mode_list:
-                    apply(button,a)
+                    apply(button,a,kw_dict)
                 if not quiet:
                     print " mouse: %s"%mode
                 if mode[-7:]!='editing': _self.unpick()
                 if mode[-7:]=='editing': _self.deselect()
+            r = DEFAULT_SUCCESS
         finally:
-            _self.unlock(_self=_self)
-        return DEFAULT_SUCCESS
+            _self.unlock(r,_self)
+        if _self._raising(r,_self): raise pymol.CmdException                     
+        return r
             
 
     def edit_mode(active=1,quiet=1,_self=cmd):
@@ -512,17 +519,17 @@ DESCRIPTION
             if active:
                 if mouse_mode[0:10]=='two_button':
                     if mouse_mode!='two_button_editing':
-                        mouse(action='two_button_editing',quiet=quiet)
+                        mouse(action='two_button_editing',quiet=quiet,_self=_self)
                 elif mouse_mode[0:12] == 'three_button':
                     if mouse_mode!='three_button_editing':
-                        mouse(action='three_button_editing',quiet=quiet)
+                        mouse(action='three_button_editing',quiet=quiet,_self=_self)
             else:
                 if mouse_mode[0:10]=='two_button':
                     if mouse_mode!='two_button_viewing':               
-                        mouse(action='two_button_viewing',quiet=quiet)
+                        mouse(action='two_button_viewing',quiet=quiet,_self=_self)
                 elif mouse_mode[0:12] == 'three_button':
                     if mouse_mode!='three_button_viewing':
-                        mouse(action='three_button_viewing',quiet=quiet)
+                        mouse(action='three_button_viewing',quiet=quiet,_self=_self)
         return DEFAULT_SUCCESS
     
     def set_key(key,fn,arg=(),kw={},_self=cmd):  
@@ -698,7 +705,7 @@ SEE ALSO
         return r
 
 
-    def mask(selection="(all)",_self=cmd):
+    def mask(selection="(all)",quiet=1,_self=cmd):
         '''
 DESCRIPTION
 
@@ -725,13 +732,13 @@ SEE ALSO
         #
         try:
             _self.lock(_self)   
-            r = _cmd.mask(_self._COb,"("+str(selection)+")",1)
+            r = _cmd.mask(_self._COb,"("+str(selection)+")",1,int(quiet))
         finally:
             _self.unlock(r,_self)
         if _self._raising(r,_self): raise pymol.CmdException         
         return r
 
-    def unmask(selection="(all)",_self=cmd):
+    def unmask(selection="(all)",quiet=1,_self=cmd):
         '''
 DESCRIPTION
 
@@ -755,7 +762,7 @@ SEE ALSO
         #   
         try:
             _self.lock(_self)   
-            r = _cmd.mask(_self._COb,"("+str(selection)+")",0)
+            r = _cmd.mask(_self._COb,"("+str(selection)+")",0,int(quiet))
         finally:
             _self.unlock(r,_self)
         if _self._raising(r,_self): raise pymol.CmdException         
