@@ -23,7 +23,8 @@ if __name__=='pymol.creating':
     import re
     from cmd import _cmd, Shortcut, is_list, is_string, \
           file_ext_re, safe_list_eval, safe_alpha_list_eval, \
-          DEFAULT_ERROR, DEFAULT_SUCCESS, is_ok, is_error
+          DEFAULT_ERROR, DEFAULT_SUCCESS, is_ok, is_error, \
+          is_tuple
 
     from chempy import fragments
 
@@ -330,6 +331,9 @@ SEE ALSO
         # preprocess selection
         if selection!='':
             selection = selector.process(selection)
+        # coerce range
+        range = list(safe_list_eval(str(range)))
+        range = map(lambda x:float(x),range)
         if is_list(color):
             for a in color:
                 if not is_list(a):
@@ -342,7 +346,7 @@ SEE ALSO
             new_color=int(color)
         try:
             _self.lock(_self)
-            r = _cmd.ramp_new(_self._COb,str(name),str(map_name),list(safe_list_eval(str(range))),new_color,
+            r = _cmd.ramp_new(_self._COb,str(name),str(map_name),range,new_color,
                                     int(state)-1,str(selection),float(beyond),float(within),
                                     float(sigma),int(zero),int(quiet))
         finally:
@@ -350,8 +354,8 @@ SEE ALSO
         if _self._raising(r,_self): raise pymol.CmdException         
         return r
 
-    def isomesh(name,map,level=1.0,selection='',buffer=0.0,
-                state=1,carve=None,source_state=0,quiet=1,_self=cmd):
+    def isomesh(name, map, level=1.0, selection='', buffer=0.0,
+                state=1, carve=None, source_state=0, quiet=1, _self=cmd):
         '''
 DESCRIPTION
 
@@ -399,9 +403,9 @@ SEE ALSO
 '''
         r = DEFAULT_ERROR
         if selection!='':
-            mopt = 1 # about a selection
+            region = 1 # about a selection
         else:
-            mopt = 0 # render the whole map
+            region = 0 # render the whole map
         # preprocess selection
         selection = selector.process(selection)
         if selection not in [ 'center', 'origin' ]:
@@ -411,7 +415,7 @@ SEE ALSO
             carve=0.0
         try:
             _self.lock(_self)
-            r = _cmd.isomesh(_self._COb,str(name),0,str(map),int(mopt),
+            r = _cmd.isomesh(_self._COb,str(name),str(map),int(region),
                              selection,float(buffer),
                              float(level),0,int(state)-1,float(carve),
                              int(source_state)-1,int(quiet),
@@ -460,8 +464,9 @@ SEE ALSO
         return r
 
 
-    def isosurface(name,map,level=1.0,selection='',buffer=0.0,state=1,carve=None,
-                        source_state=0,side=1,mode=3,quiet=1,_self=cmd):
+    def isosurface(name, map, level=1.0, selection='', buffer=0.0, state=1,
+                   carve=None, source_state=0, side=1, mode=3, quiet=1,
+                   _self=cmd):
         '''
 DESCRIPTION
 
@@ -500,9 +505,9 @@ SEE ALSO
         '''
         r = DEFAULT_ERROR
         if selection!='':
-            mopt = 1 # about a selection
+            region = 1 # about a selection
         else:
-            mopt = 0 # render the whole map
+            region = 0 # render the whole map
         # preprocess selection
         selection = selector.process(selection)
         if selection not in [ 'center', 'origin' ]:
@@ -512,10 +517,11 @@ SEE ALSO
             carve=0.0
         try:
             _self.lock(_self)
-            r = _cmd.isosurface(_self._COb,str(name),0,str(map),int(mopt),
+            r = _cmd.isosurface(_self._COb,str(name),str(map),int(region),
                                       selection,float(buffer),
                                       float(level),int(mode),int(state)-1,float(carve),
                                       int(source_state)-1,int(side),int(quiet))
+
         finally:
             _self.unlock(r,_self)
         if _self._raising(r,_self): raise pymol.CmdException         
@@ -552,9 +558,9 @@ SEE ALSO
         '''
         r = DEFAULT_ERROR
         if selection!='':
-            mopt = 1 # about a selection
+            region = 1 # about a selection
         else:
-            mopt = 0 # render the whole map
+            region = 0 # render the whole map
         # preprocess selections
         selection = selector.process(selection)
         if selection not in [ 'center', 'origin' ]:
@@ -564,7 +570,7 @@ SEE ALSO
             carve=0.0
         try:
             _self.lock(_self)
-            r = _cmd.isomesh(_self._COb,str(name),0,str(map),int(mopt),
+            r = _cmd.isomesh(_self._COb,str(name),str(map),int(region),
                              selection,float(buffer),
                              float(level),1,int(state)-1,
                              float(carve),int(source_state)-1,int(quiet),
@@ -576,7 +582,7 @@ SEE ALSO
 
 
 
-    def isolevel(name,level=1.0,state=0,query=0,_self=cmd):
+    def isolevel(name,level=1.0,state=0,query=0,quiet=1,_self=cmd):
         '''
 DESCRIPTION
 
@@ -590,16 +596,16 @@ USAGE
         r = DEFAULT_ERROR
         try:
             _self.lock(_self)
-            r = _cmd.isolevel(_self._COb,str(name),float(level),int(state)-1,int(query))
+            r = _cmd.isolevel(_self._COb,str(name),float(level),int(state)-1,int(query),int(quiet))
         finally:
             _self.unlock(r,_self)
         if not int(query):
             if _self._raising(r,_self): raise pymol.CmdException                  
         return r
 
-    def gradient(name,map,minimum=1.0,maximum=-1.0,
-                 selection='',buffer=0.0,state=0,
-                 carve=None,source_state=0,quiet=1,_self=cmd):
+    def gradient(name, map, minimum=1.0, maximum=-1.0,
+                 selection='', buffer=0.0, state=0,
+                 carve=None, source_state=0, quiet=1, _self=cmd):
         '''
 DESCRIPTION
 
@@ -624,9 +630,9 @@ SEE ALSO
         '''
         r = DEFAULT_ERROR
         if selection!='':
-            mopt = 1 # about a selection
+            region = 1 # about a selection
         else:
-            mopt = 0 # render the whole map
+            region = 0 # render the whole map
         # preprocess selections
         selection = selector.process(selection)
         if selection not in [ 'center', 'origin' ]:
@@ -636,7 +642,7 @@ SEE ALSO
             carve=0.0
         try:
             _self.lock(_self)
-            r = _cmd.isomesh(_self._COb,str(name),0,str(map),int(mopt),
+            r = _cmd.isomesh(_self._COb,str(name),str(map),int(region),
                              selection,float(buffer),
                              float(minimum),3,int(state)-1,
                              float(carve),int(source_state)-1,int(quiet),
@@ -779,7 +785,8 @@ ARGUMENTS
 
 PYMOL API
 
-    cmd.create(string name, string selection, int state, int target_state,int discrete)
+    cmd.create(string name, string selection, int state,
+               int target_state, int discrete)
 
 NOTES
 
@@ -891,7 +898,7 @@ NOTES
         try:
             _self.lock(_self)
             if pos!=None:
-                if not is_list(pos):
+                if not (is_list(pos) or is_tuple(pos)):
                     pos = safe_list_eval(pos)
                 pos = (float(pos[0]), # tuple-ize
                        float(pos[1]),
