@@ -354,7 +354,74 @@ SEE ALSO
         if _self._raising(r,_self): raise pymol.CmdException                     
         return r
 
-    def bond(atom1="(pk1)", atom2="(pk2)", order=1, edit=1, _self=cmd):
+    order_dict = {
+    # simulation 
+        '1'         : 1,
+        '2'         : 2,
+        '3'         : 3,
+        '4'         : 4,
+        'aromatic'  : 4,
+        'guess'     : -1,
+        'copy'      : -2
+    }
+
+    order_sc = Shortcut(order_dict.keys())
+
+    def valence(order, selection1=None, selection2=None, source='',
+                target_state=0, source_state=0, reset=1,
+                quiet=1, _self=cmd):
+        '''
+DESCRIPTION
+
+    "valence" modifies the valences of all existing bonds formed
+    between two atom selections.
+    
+USAGE
+
+    valence 2, (name c), (name o)
+
+PYMOL API
+
+    cmd.valence(string selection1, selection2)
+
+SEE ALSO
+
+    unbond, fuse, attach, replace, remove_picked
+    '''
+        if is_string(order):
+            order = order_sc.auto_err(order,"order")
+            order = order_dict[order]
+        else:
+            order = int(order)
+        r = DEFAULT_ERROR
+        # preprocess selections
+        if selection1 == None:
+            selection1="(pk1)"
+            if selection2 == None:
+                selection2="(pk2)"
+        if selection2 == None:
+            selection2 = selection1
+        selection1 = selector.process(selection1)
+        selection2 = selector.process(selection2)
+        if source!='':
+            source = selector.process(source)
+        try:
+            _self.lock(_self)
+            if order>=0:
+                r = _cmd.bond(_self._COb, "("+selection1+")", "("+selection2+")", int(order), 2, int(quiet))
+            else:
+                r = _cmd.revalence(_self._COb,
+                                   "("+selection1+")",
+                                   "("+selection2+")",
+                                   str(source), 
+                                   int(target_state)-1, int(source_state)-1,
+                                   int(reset), int(quiet))
+        finally:
+            _self.unlock(r,_self)
+        if _self._raising(r,_self): raise pymol.CmdException            
+        return r
+
+    def bond(atom1="(pk1)", atom2="(pk2)", order=1, edit=1, quiet=1, _self=cmd):
         '''
 DESCRIPTION
 
@@ -386,7 +453,10 @@ SEE ALSO
         atom2 = selector.process(atom2)
         try:
             _self.lock(_self)
-            r = _cmd.bond(_self._COb,atom1,atom2,int(order),1)
+            r = _cmd.bond(_self._COb,
+                          "("+atom1+")",
+                          "("+atom2+")",
+                          int(order),1,int(quiet))
         finally:
             _self.unlock(r,_self)
         if _self._raising(r,_self): raise pymol.CmdException            
@@ -423,7 +493,7 @@ PYMOL API
         if _self._raising(r,_self): raise pymol.CmdException            
         return r
 
-    def unbond(atom1="(pk1)", atom2="(pk2)", _self=cmd):
+    def unbond(atom1="(pk1)", atom2="(pk2)", quiet=1, _self=cmd):
         '''
 DESCRIPTION
 
@@ -454,7 +524,10 @@ SEE ALSO
         atom2 = selector.process(atom2)   
         try:
             _self.lock(_self)
-            r = _cmd.bond(_self._COb,str(atom1),str(atom2),0,0)
+            r = _cmd.bond(_self._COb,
+                          "("+atom1+")",
+                          "("+atom2+")",
+                          0,0,int(quiet))
         finally:
             _self.unlock(r,_self)
         if _self._raising(r,_self): raise pymol.CmdException            
@@ -1123,7 +1196,7 @@ SEE ALSO
     alter_state, iterate, iterate_state, sort
         '''
         if space == None:
-            space = _self.pymol.__dict__
+            space = _self._pymol.__dict__
         r = DEFAULT_ERROR
         # preprocess selections
         selection = selector.process(selection)
@@ -1145,7 +1218,7 @@ DESCRIPTION
         '''
         #
         if space == None:
-            space = _self.pymol.__dict__
+            space = _self._pymol.__dict__
         try:
             _self.lock(_self)
             r = _cmd.alter_list(_self._COb,str(object),list(expr_list),int(quiet),dict(space))
@@ -1189,7 +1262,7 @@ SEE ALSO
         '''
 
         if space == None:
-            space = _self.pymol.__dict__
+            space = _self._pymol.__dict__
         r = DEFAULT_ERROR
         # preprocess selection
         selection = selector.process(selection)
@@ -1234,7 +1307,7 @@ SEE ALSO
     iterate_state, alter, iterate
         '''
         if space == None:
-            space = _self.pymol.__dict__
+            space = _self._pymol.__dict__
         r = DEFAULT_ERROR
         # preprocess selection
         selection = selector.process(selection)
@@ -1242,8 +1315,10 @@ SEE ALSO
         state = int(state)
         try:
             _self.lock(_self)
-            r = _cmd.alter_state(_self._COb,int(state)-1,"("+str(selection)+")",str(expression),
-                                        0,int(atomic),int(quiet),dict(space))
+            r = _cmd.alter_state(_self._COb,
+                                 int(state)-1,"("+str(selection)+")",
+                                 str(expression),
+                                 0,int(atomic),int(quiet),dict(space))
         finally:
             _self.unlock(r,_self)   
         if _self._raising(r,_self): raise pymol.CmdException            
@@ -1271,8 +1346,9 @@ SEE ALSO
 
     iterate, alter, alter_state
         '''
+        r = DEFAULT_ERROR
         if space == None:
-            space = _self.pymol.__dict__
+            space = _self._pymol.__dict__
         # preprocess selection
         selection = selector.process(selection)
         state = int(state)
@@ -1610,13 +1686,14 @@ DESCRIPTION
 
 PYMOL API
    
-    cmd.transform_selection(string selection, list-of-16-floats matrix, int state-number):
+    cmd.transform_selection(string selection, list matrix, int state,
+                            int log, int homogenous, int transpose):
 
 NOTES
 
-    Note that matrix is NOT a standard homogenous 4x4 transformation
-    matrix.  Instead it is something PyMOL-specific which consists of the
-    following:
+    Note that when homogenous is zero, the input matrix is NOT a
+    standard homogenous 4x4 transformation matrix.  Instead it is
+    something PyMOL-specific which consists of the following:
 
     1) a 3x3 matrix containing the rotation in the upper-left quadrant
 
@@ -1637,8 +1714,8 @@ NOTES
 
     Y = M X
 
-    y0 = m0*(x0+m12) + m1*(x1+m13) +  m8*(x2+m14) + m3 \\
-    y1 = m4*(x0+m12) + m5*(x1+m13) +  m9*(x2+m14) + m7 \\
+    y0 = m0*(x0+m12) + m1*(x1+m13) +  m2*(x2+m14) + m3 \\
+    y1 = m4*(x0+m12) + m5*(x1+m13) +  m6*(x2+m14) + m7 \\
     y2 = m8*(x0+m12) + m9*(x1+m13) + m10*(x2+m14) + m11 
 
         '''
@@ -1846,7 +1923,7 @@ PYMOL API
         r = DEFAULT_ERROR
         try:
             _self.lock(_self)
-            r = _cmd.set_dihe(_self._COb,str(atom1),str(atom2),str(atom3),str(atom4),
+            r = _cmd.set_dihe(_self._COb,atom1,atom2,atom3,atom4,
                                     float(angle),int(state)-1,int(quiet))
         finally:
             _self.unlock(r,_self)
@@ -2083,6 +2160,8 @@ SEE ALSO
         'restrain'      : 2,
         'fix'           : 3,
         'exclude'       : 4,
+        'study'         : 5,
+        
     # rendering
         'exfoliate'     : 24,
         'ignore'        : 25,
@@ -2100,7 +2179,7 @@ SEE ALSO
     flag_action_sc = Shortcut(flag_action_dict.keys())
 
     def fix_chemistry(selection1="all", selection2="all",
-		      invalidate=0, quiet=1, _self=cmd):
+		      invalidate=1, quiet=1, _self=cmd):
         '''
 DESCRIPTION
    
@@ -2119,6 +2198,16 @@ DESCRIPTION
             _self.unlock(r,_self)
         if _self._raising(r,_self): raise pymol.CmdException            
         return r
+
+    def set_object_color(name, color, quiet=1, _self=cmd):
+        r = DEFAULT_ERROR
+        try:
+            _self.lock(_self)
+            r = _cmd.set_object_color(_self._COb,str(name),str(color),int(quiet))
+        finally:
+            _self.unlock(r,_self)      
+        if _raising(r,_self): raise pymol.CmdException
+        return r
     
     def flag(flag, selection, action="reset", quiet=1, _self=cmd):
         '''
