@@ -24,8 +24,10 @@ if __name__=='pymol.exporting':
     import cmd
     from cmd import _cmd,lock,unlock,Shortcut,QuietException
     from chempy import io
+    from chempy.sdf import SDF,SDFRec
     from cmd import _feedback,fb_module,fb_mask, \
-                     DEFAULT_ERROR, DEFAULT_SUCCESS, _raising, is_ok, is_error
+                     DEFAULT_ERROR, DEFAULT_SUCCESS, _raising, is_ok, is_error, \
+                     is_list, is_dict, is_tuple
     import traceback
 
     def copy_image(quiet=1,_self=cmd): # incentive feature / proprietary
@@ -37,6 +39,111 @@ if __name__=='pymol.exporting':
         if _self._raising(r,_self): raise QuietException         
         return r
 
+    cache_action_dict = {
+        'enable'      : 0,
+        'disable'     : 1,
+        'read_only'   : 2,
+        'clear'       : 3,
+        'optimize'    : 4,
+    }
+
+    cache_action_sc = Shortcut(cache_action_dict.keys())
+
+    def cache(action='optimize', scenes='',state=-1, quiet=1, _self=cmd):
+        '''
+DESCRIPTION
+
+    "cache" manages storage of precomputed results, such as
+    molecular surfaces.
+
+USAGE
+
+    cache action [, scenes [, state ]]
+
+ARGUMENTS
+
+    action = string: enable, disable, read_only, clear, or optimize
+
+    scenes = string: a space-separated list of scene names (default: '')
+
+    state = integer: state index (default: -1)
+
+EXAMPLES
+
+    cache enable
+    cache optimize
+    cache optimize, F1 F2 F5
+
+NOTES
+
+    "cache optimize" will iterate through the list of scenes provided
+    (or all defined scenes), compute any missing surfaces, and store
+    them in the cache for later reuse.
+    
+PYMOL API
+
+    cmd.cache(string action, string scenes, int state, int quiet)
+
+    '''
+        
+        r = DEFAULT_ERROR
+        action = cache_action_dict[cache_action_sc.auto_err(str(action),'action')]
+        quiet = int(quiet)
+        if action == 0: # enable
+            r = _self.set('cache_mode',2,quiet=quiet)
+        elif action == 1: # disable
+            r =_self.set('cache_mode',0,quiet=quiet)
+        elif action == 2: # read_only
+            r =_self.set('cache_mode',1,quiet=quiet)
+        elif action == 3: # clear
+            r =_self._cache_clear(_self=_self)
+        elif action == 4: # optimize
+            r = DEFAULT_SUCCESS
+            _self._cache_mark(_self=_self)
+            cur_scene = _self.get('scene_current_name')
+            cache_max = int(_self.get('cache_max'))
+            if cache_max>0:
+                # allow double memory for an optimized cache
+                _self.set('cache_max',cache_max*2) 
+            scenes = str(scenes)
+            scene_list = string.split(scenes)
+            cache_mode = int(_self.get('cache_mode'))
+            _self.set('cache_mode',2)
+            if not len(scene_list):
+                scene_list = _self.get_scene_list()
+            for scene in scene_list:
+                scene = string.strip(scene)
+                if not quiet:
+                    print " cache: optimizing scene '%s'."%scene
+                cmd.scene(scene,animate=0)
+                cmd.rebuild()                
+                cmd.refresh()
+            if len(cur_scene):
+                cmd.scene(cur_scene,animate=0)
+            else:
+                scene_list = _self.get_scene_list()
+                if len(scene_list):
+                    cmd.scene(scene_list[0],animate=0)
+                else:
+                    if not quiet:
+                        print " cache: no scenes defined -- optimizing current display."
+                    cmd.rebuild() 
+                    cmd.refresh()
+            usage = _self._cache_purge(-1,_self=_self)
+            if cache_mode:
+                _self.set('cache_mode',cache_mode)
+            else:
+                _self.set('cache_mode',2) # hmm... could use 1 here instead.
+            _self.set('cache_max',cache_max) # restore previous limits
+            if not quiet:            
+                print " cache: optimization complete (~%0.1f MB)."%(usage*4/1000000.0)
+        try:
+            _self.lock(_self)
+        finally:
+            _self.unlock(r,_self)
+        if _self._raising(r,_self): raise QuietException         
+        return r
+
     def get_pdbstr(selection="all", state=-1, ref='', ref_state=-1, quiet=1,_self=cmd):
         '''
 DESCRIPTION
@@ -66,10 +173,34 @@ NOTES
             _self.unlock(r,_self)
         if _self._raising(r,_self): raise QuietException         
         return r
+
+    def _get_dump_str(obj):
+        if is_list(obj):
+            list = map(_get_dump_str,obj)
+            result = "[ "+string.join(list,",\n")+" ] "
+        elif is_dict(obj):
+            list = []
+            for key in obj.keys():
+                list.append( _get_dump_str(key)+" : "+_get_dump_str(obj[key]) )
+            result = "{ "+string.join(list,",\n")+" } "
+        elif is_tuple(obj):
+            list = map(_get_dump_str,obj)
+            result = "( "+string.join(list,",\n")+" ) "
+        else:
+            result = str(obj)
+        return result
     
-    def get_session(names='', partial=0, quiet=1, compress=-1,_self=cmd):
+    def get_session(names='', partial=0, quiet=1, compress=-1, cache=-1, _self=cmd):
         session = {}
         r = DEFAULT_SUCCESS
+        cache = int(cache)
+        compress = int(compress)
+        if cache:
+            cache_opt = int(_self.get('session_cache_optimize'))
+            if cache != 0:
+                cache_mode = int(_self.get('cache_mode'))
+                if ((cache_mode > 0) and (cache_opt != 0)) or (cache_opt==1):
+                    _self.cache('optimize')
         for a in _self._pymol._session_save_tasks:
             if a==None:
                 try:
@@ -79,7 +210,9 @@ NOTES
                 finally:
                     _self.unlock(r,_self)
                 try:
-                    session['session'] = copy.deepcopy(pymol.session)
+                    session['session'] = copy.deepcopy(_self._pymol.session)
+                    if cache and hasattr(_self._pymol,'_cache'):
+                        session['cache'] = _self._pymol._cache
                 except:
                     traceback.print_exc()
             else:
@@ -235,6 +368,8 @@ SEE ALSO
                 format = 'pqr'
             elif re.search("\.mol$",lc_filename):
                 format = 'mol'
+            elif re.search("\.sdf$",lc_filename):
+                format = 'sdf'
             elif re.search("\.pkl$",lc_filename):
                 format = 'pkl'
             elif re.search("\.pkl$",lc_filename):
@@ -274,11 +409,12 @@ SEE ALSO
                     _self.lock(_self)
                     st = _cmd.get_pdb(_self._COb,"("+str(selection)+")",int(state)-1,0,
                                       str(ref),int(ref_state)-1,int(quiet))
+                    if st != None:
+                        r = DEFAULT_SUCCESS                    
                 finally:
-                    _self.unlock(_self=_self)
+                    _self.unlock(r,_self=_self)
                 f.write(st)
                 f.close()
-                r = DEFAULT_SUCCESS
                 if not quiet:
                     print " Save: wrote \""+filename+"\"."
         elif format=='aln':
@@ -286,13 +422,14 @@ SEE ALSO
             try:
                 _self.lock(_self)
                 st = _cmd.get_seq_align_str(_self._COb,str(selection),int(state)-1,0,int(quiet))
+                if st != None:
+                    r = DEFAULT_SUCCESS
             finally:
-                _self.unlock(_self=_self)
+                _self.unlock(r,_self)
             if st!=None:
                 f=open(filename,"w")
                 f.write(st)
                 f.close()
-                r = DEFAULT_SUCCESS
                 if not quiet:
                     print " Save: wrote \""+filename+"\"."
             else:
@@ -305,11 +442,12 @@ SEE ALSO
                     _self.lock(_self)
                     st = _cmd.get_pdb(_self._COb,"("+str(selection)+")",int(state)-1,1,
                                       str(ref),int(ref_state)-1,int(quiet))
+                    if st != None:
+                        r = DEFAULT_SUCCESS
                 finally:
-                    _self.unlock(_self=_self)
+                    _self.unlock(r,_self)
                 f.write(st)
                 f.close()
-                r = DEFAULT_SUCCESS
                 if not quiet:
                     print " Save: wrote \""+filename+"\"."
         elif format=='pkl': # python binary
@@ -335,6 +473,22 @@ SEE ALSO
             r = DEFAULT_SUCCESS
             if not quiet:
                 print " Save: wrote \""+filename+"\"."
+        elif format=='sdf':
+            state = int(state)
+            if state==0:
+                first_state = 1
+                last_state = cmd.count_states(selection)
+            else:
+                first_state = state
+                last_state = state
+            sdf = SDF(filename,'w')
+            for state in range(first_state, last_state+1):
+                rec = SDFRec(io.mol.toList(_self.get_model(selection,state,ref,ref_state))
+                             + ["$$$$\n"])
+                sdf.write(rec)
+            r = DEFAULT_SUCCESS
+            if not quiet:
+                print " Save: wrote %d states to \"%s\"."%(1+last_state-first_state,filename)
         elif format=='mol': 
             io.mol.toFile(_self.get_model(selection,state,ref,ref_state),filename)
             r = DEFAULT_SUCCESS
