@@ -33,6 +33,7 @@ if __name__=='pymol.importing':
 
     from pymol import parser
     from chempy.sdf import SDF,SDFRec
+    from chempy.cif import CIF,CIFRec
     from chempy import io,PseudoFile
     import pymol
     import copy
@@ -40,12 +41,18 @@ if __name__=='pymol.importing':
     
     loadable_sc = Shortcut(loadable.__dict__.keys()) 
 
-    def set_session(session,partial=0,quiet=1,_self=cmd):
+    def set_session(session,partial=0,quiet=1,cache=1,steal=-1,_self=cmd):
         r = DEFAULT_SUCCESS
         if is_string(session): # string implies compressed session data 
             import zlib
             session = io.pkl.fromString(zlib.decompress(session))
-        for a in pymol._session_restore_tasks:
+            if steal<0:
+                steal = 1
+        elif steal<0:
+            steal = 0
+        # use the pymol instance to store state, not the code module
+        _pymol = _self._pymol
+        for a in _pymol._session_restore_tasks:
             if a==None:
                 try:
                     _self.lock(_self)
@@ -54,9 +61,22 @@ if __name__=='pymol.importing':
                     _self.unlock(r,_self)
                 try:
                     if session.has_key('session'):
-                        pymol.session = copy.deepcopy(session['session'])
+                        if steal:
+                            _pymol.session = session['session']
+                            del session['session']
+                        else:
+                            _pymol.session = copy.deepcopy(session['session'])
                     else:
-                        pymol.session = pymol.Session_Storage()
+                        _pymol.session = pymol.Session_Storage()
+                    if cache:
+                        if session.has_key('cache'):
+                            cache = session['cache']
+                            if len(cache):
+                                if steal:
+                                    _pymol._cache = session['cache']
+                                    del session['cache']
+                                else:
+                                    _pymol._cache = copy.deepcopy(session['cache'])
                 except:
                     traceback.print_exc()
             else:
@@ -372,9 +392,20 @@ SEE ALSO
             _self.unlock(r,_self)
         if _self._raising(r,_self): raise pymol.CmdException
         return r
+    
+    def _processCIF(cif,oname,state,quiet,discrete,_self=cmd):
+        while 1:
+            rec = cif.read()
+            if not rec: break
+            if len(rec.model.atom):
+                r = cmd.load_model(rec.model,oname,state,quiet=quiet,
+                                   _self=_self,discrete=discrete)
+        del cif
+#        _cmd.finish_object(_self._COb,str(oname))
+#        if _cmd.get_setting(_self._COb,"auto_zoom")==1.0:
+#            _self._do("zoom (%s)"%oname)
 
     def _processSDF(sdf,oname,state,quiet,_self=cmd):
-        ftype = loadable.molstr
         while 1:
             rec = sdf.read()
 
@@ -459,9 +490,9 @@ SEE ALSO
             state = int(state)
             finish = int(finish)
             zoom = int(zoom)
-            if discrete==-1:
+            if discrete == -1:
                 discrete_default = 1
-                discrete=0
+                discrete = 0
             else:
                 discrete_default = 0
                 discrete = int(discrete)
@@ -544,6 +575,8 @@ SEE ALSO
                     ftype = loadable.mae
                 elif re.search("\.cube$",filename,re.I):
                     ftype = loadable.cube
+                elif re.search("\.cif$",filename,re.I):
+                    ftype = loadable.cif1
                 elif re.search("\.map$",filename,re.I):
                     r = DEFAULT_ERROR
                     print 'Error: .map is ambiguous.  Please add format or use another extension:'
@@ -575,7 +608,10 @@ SEE ALSO
             if ftype == loadable.psw:
                 go_to_first_scene = 1                
                 ftype = loadable.pse
-                
+            elif ftype == loadable.pse:
+                if int(_self.get_setting_legacy("presentation"))!=0:
+                    go_to_first_scene = 1
+                    
     # get object name
             if len(str(object))==0:
                 oname = re.sub(r".*\/|.*\\","",filename) # strip path
@@ -590,8 +626,19 @@ SEE ALSO
             if ftype == loadable.sdf1:
                 sdf = SDF(fname)
                 _processSDF(sdf,oname,state,quiet,_self)
+                r = DEFAULT_SUCCESS
                 ftype = -1
- 
+
+     # loadable.sdf1 is the Python-based CIF file reader
+            if ftype == loadable.cif1:
+                try:
+                    cif = CIF(fname)
+                    _processCIF(cif,oname,state,quiet,discrete,_self)
+                except:
+                    traceback.print_exc()
+                r = DEFAULT_SUCCESS
+                ftype = -1
+
     # png images 
             if ftype == loadable.png:
                 r = _self.load_png(str(fname),quiet=quiet)
@@ -626,14 +673,15 @@ SEE ALSO
 
             if ftype == loadable.pse:
                 ftype = -1
-                r = _self.set_session(io.pkl.fromFile(fname),quiet=quiet,partial=partial)
+                r = _self.set_session(io.pkl.fromFile(fname),quiet=quiet,
+                                      partial=partial,steal=1)
                 if not partial:
                     _self.set("session_file",fname,quiet=1)
                 
-    # special handling for multi-model files (mol2, sdf)
+    # special handling for multi-model files 
 
-            if ftype in ( loadable.mol2, loadable.sdf1, loadable.sdf2 ):
-                if discrete_default==1: # make such files discrete by default
+            if ftype in ( loadable.mol2, loadable.sdf1, loadable.sdf2, loadable.mae ):
+                if discrete_default: # make such files discrete by default
                     discrete = -1
 
     # standard file handling
@@ -648,7 +696,8 @@ SEE ALSO
         if _self._raising(r,_self): raise pymol.CmdException
         return r
 
-    def load_embedded(key=None, name=None, state=0, finish=1, discrete=1, quiet=1, _self=cmd):
+    def load_embedded(key=None, name=None, state=0, finish=1, discrete=1,
+                      quiet=1, zoom=-1, multiplex=-2, _self=cmd):
         '''
 DESCRIPTION
 
@@ -699,20 +748,25 @@ NOTES
                     print "Error: unknown type '%s'",type
                     raise pymol.CmdException
             if ftype==loadable.pdb:
-                r = read_pdbstr(string.join(data,''),name,state,finish,discrete,quiet)
+                r = read_pdbstr(string.join(data,''),name,state,finish,
+                                discrete,quiet,zoom,multiplex)
             elif ftype==loadable.mol:
-                r = read_molstr(string.join(data,''),name,state,finish,discrete,quiet)
+                r = read_molstr(string.join(data,''),name,state,finish,
+                                discrete,quiet,zoom)
             elif ftype==loadable.mol2:
-                r = read_mol2str(string.join(data,''),name,state,finish,discrete,quiet)
+                r = read_mol2str(string.join(data,''),name,state,finish,
+                                 discrete,quiet,zoom,multiplex)
             elif ftype==loadable.xplor:
                 r = read_xplorstr(string.join(data,''),name,state,finish,discrete,quiet)
             elif ftype==loadable.mae:
                 try:
                     # BEGIN PROPRIETARY CODE SEGMENT
-                    from epymol import schrodinger
-                    r = schrodinger.read_maestr(string.join(data,''),
-                                                name,state,
-                                                finish,discrete,quiet)
+                    from epymol import mae
+                    if discrete_default:
+                        discrete = -1
+                    r = mae.read_maestr(string.join(data,''),
+                                        name,state,finish,discrete,
+                                        quiet,zoom,multiplex)
                     # END PROPRIETARY CODE SEGMENT
                 except ImportError:
                     print "Error: .MAE format not supported by this PyMOL build."
@@ -721,7 +775,8 @@ NOTES
                 sdf = SDF(PseudoFile(data),'pf')
                 r = _processSDF(sdf,name,state,quiet,_self)
             elif ftype==loadable.sdf2: # C-based SDF reader (much faster)
-                r = read_sdfstr(string.join(data,''),name,state,finish,discrete,quiet)
+                r = read_sdfstr(string.join(data,''),name,state,finish,
+                                discrete,quiet,zoom,multiplex)
         if _self._raising(r,_self): raise pymol.CmdException
         return r
 
@@ -762,7 +817,7 @@ NOTES
         return r
         
     def read_sdfstr(sdfstr,name,state=0,finish=1,discrete=1,quiet=1,
-                         zoom=-1,_self=cmd):
+                         zoom=-1,multiplex=-2,_self=cmd):
         '''
 DESCRIPTION
 
@@ -790,7 +845,7 @@ NOTES
             _self.lock(_self)
             r = _cmd.load(_self._COb,str(name),str(sdfstr),int(state)-1,
                               loadable.sdf2str,int(finish),int(discrete),
-                              int(quiet),0,int(zoom))
+                              int(quiet),int(multiplex),int(zoom))
         finally:
             _self.unlock(r,_self)
         if _self._raising(r,_self): raise pymol.CmdException
@@ -866,7 +921,7 @@ DESCRIPTION
         return r
 
     def read_pdbstr(pdb,name,state=0,finish=1,discrete=0,quiet=1,
-                         multiplex=-2,zoom=-1,_self=cmd):
+                         zoom=-1,multiplex=-2,_self=cmd):
         '''
 DESCRIPTION
 
@@ -898,14 +953,14 @@ NOTES
             oname = string.strip(str(name))
             r = _cmd.load(_self._COb,str(oname),pdb,int(state)-1,int(ftype),
                               int(finish),int(discrete),int(quiet),
-                              0,int(zoom))
+                              int(multiplex),int(zoom))
         finally:
             _self.unlock(r,_self)
         if _self._raising(r,_self): raise pymol.CmdException
         return r
 
     def read_mol2str(mol2,name,state=0,finish=1,discrete=0,
-                          quiet=1,zoom=-1,_self=cmd):
+                          quiet=1,zoom=-1,multiplex=-2,_self=cmd):
         '''
 DESCRIPTION
 
@@ -937,7 +992,7 @@ NOTES
             oname = string.strip(str(name))
             r = _cmd.load(_self._COb,str(oname),mol2,int(state)-1,int(ftype),
                               int(finish),int(discrete),int(quiet),
-                              0,int(zoom))
+                              int(multiplex),int(zoom))
         finally:
             _self.unlock(r,_self)
         if _self._raising(r,_self): raise pymol.CmdException
@@ -1066,7 +1121,7 @@ PYMOL API
                                     if auto_close_file:
                                         fobj.close()
                                 r = _self.read_pdbstr(pdb_str,name,state,finish,discrete,quiet,
-                                                    multiplex,zoom)
+                                                      zoom,multiplex)
                                 done = 1
                             except IOError:
 #                                print traceback.print_exc()
@@ -1074,12 +1129,15 @@ PYMOL API
                         else:
 #                            print traceback.print_exc()
                             pass
-                        os.remove(filename)
+                        try:
+                            os.remove(filename)
+                        except:
+                            pass
             if done == 0:
                 time.sleep(0.1)
         if done == 0:
             r = DEFAULT_ERROR
-            print "Error-fetch: unable to load '%s'"%code
+            print "Error-fetch: unable to load '%s'."%code
         return r
     
     def _multifetch(code,name,state,finish,discrete,multiplex,zoom,type,path,file,quiet,_self):
@@ -1144,12 +1202,16 @@ NOTES
         import threading
         r = DEFAULT_SUCCESS
         if path==None:
-            path = setting.get('fetch_path')
+            path = setting.get('fetch_path',_self=_self)
         if async<0: # by default, run asynch when interactive, sync when not
             async = not quiet
         if not int(async):
-            r = _multifetch(code,name,state,finish,
-                            discrete,multiplex,zoom,type,path,file,quiet,_self)
+            try:
+                _self.block_flush()
+                r = _multifetch(code,name,state,finish,
+                                discrete,multiplex,zoom,type,path,file,quiet,_self)
+            except:
+                _self.unblock_flush()
         else:
             t = threading.Thread(target=_multifetch,
                                  args=(code,name,state,finish,
