@@ -8,12 +8,144 @@ import traceback
 import thread
 import re
 import viewing
+import time
+import pymol
+from operator import add
 
 from chempy import io
 
-from cmd import DEFAULT_ERROR, loadable, _load2str, Shortcut, \
+from cmd import DEFAULT_ERROR, DEFAULT_SUCCESS, loadable, _load2str, Shortcut, \
    is_string, is_ok
 
+# cache management:
+
+def _cache_validate(_self=cmd):
+    r = DEFAULT_SUCCESS
+    try:
+        _self.lock_data(_self)
+        _pymol = _self._pymol
+        if not hasattr(_pymol,"_cache"):
+            _pymol._cache = []
+        if not hasattr(_pymol,"_cache_memory"):
+            _pymol._cache_memory = 0
+    finally:
+        _self.unlock_data(_self)
+        
+def _cache_clear(_self=cmd):
+    r = DEFAULT_SUCCESS
+    try:
+        _self.lock_data(_self)
+        _pymol = _self._pymol
+        _pymol._cache = []
+        _pymol._cache_memory = 0
+    finally:
+        _self.unlock_data(_self)
+    return r
+    
+def _cache_mark(_self=cmd):
+    r = DEFAULT_SUCCESS
+    try:
+        _self.lock_data(_self)
+        _pymol = _self._pymol
+        _cache_validate(_self)
+        for entry in _self._pymol._cache: 
+            entry[5] = 0.0
+    finally:
+        _self.unlock_data(_self)
+    return r
+
+def _cache_purge(max_size, _self=cmd):
+    r = DEFAULT_SUCCESS
+    try:
+        _self.lock_data(_self)
+        _pymol = _self._pymol
+        _cache_validate(_self)
+        if len(_pymol._cache):
+            cur_size = reduce(add,map(lambda x:x[0],_pymol._cache))
+            if max_size>=0: # purge to reduce size
+                now = time.time()
+                # sort by last access time
+                new_cache = map(lambda x:[(now-x[5])/x[4],x], _pymol._cache)
+                new_cache.sort()
+                new_cache = map(lambda x:x[1],new_cache)
+                # remove oldest entries one by one until size requirement is met
+                while (cur_size>max_size) and (len(new_cache)>1):
+                    entry = new_cache.pop() 
+                    cur_size = cur_size - entry[0]
+                _pymol._cache = new_cache
+                _pymol._cache_memory = cur_size
+            else: # purge to eliminate unused entries
+                new_cache = []
+                for entry in _pymol._cache:
+                    if entry[5] == 0.0:
+                        cur_size = cur_size - entry[0]
+                    else:
+                        new_cache.append(entry)
+                _pymol._cache = new_cache
+                _pymol._cache_memory = cur_size
+        result = _pymol._cache_memory
+    finally:
+        _self.unlock_data(_self)
+    return result
+        
+def _cache_get(target, hash_size = None, _self=cmd):
+    result = None
+    try:
+        _self.lock_data(_self)
+        try:
+            if hash_size == None:
+                hash_size = len(target[1])
+            key = target[1][0:hash_size]
+            # should optimize this with a dictionary lookup, key -> index in _cache
+            for entry in _self._pymol._cache:
+                if entry[1][0:hash_size] == key:
+                    if entry[2] == target[2]:
+                        while len(entry)<6:
+                            entry.append(0)
+                        entry[4] = entry[4] + 1 # access count
+                        entry[5] = time.time() # timestamp
+                        result = entry[3]
+                        break
+        except:
+            traceback.print_exc()
+    finally:
+        _self.unlock_data(_self)
+    return result
+
+def _cache_set(new_entry, max_size, _self=cmd):
+    r = DEFAULT_SUCCESS
+    try:
+        _self.lock_data(_self)
+        _pymol = _self._pymol
+        _cache_validate(_self)
+        try:
+            hash_size = len(new_entry[1])
+            key = new_entry[1][0:hash_size]
+            count = 0
+            found = 0
+            new_entry[4] = new_entry[4] + 1 # incr access count
+            new_entry[5] = time.time() # timestamp
+            for entry in _pymol._cache: 
+                if entry[1][0:hash_size] == key:
+                    if entry[2] == new_entry[2]: # dupe (shouldn't happen)
+                        entry[3] = new_entry[3] 
+                        found = 1
+                        break
+                count = count + 1
+            if not found:
+                _pymol._cache.append(new_entry)
+                _pymol._cache_memory = _pymol._cache_memory + new_entry[0]
+                if max_size > 0:
+                    if _pymol._cache_memory > max_size:
+                        _cache_purge(max_size, _self)
+        except:
+            traceback.print_exc()
+    finally:
+        _self.unlock_data(_self)
+    return r
+        
+# ray tracing threads
+
 def _ray_anti_spawn(thread_info,_self=cmd):
     # WARNING: internal routine, subject to change      
     # internal routine to support multithreaded raytracing
@@ -126,16 +258,17 @@ def _do(cmmd,log=0,echo=1,_self=cmd):
 
 # movie rendering
 
-def _mpng(prefix, first=-1, last=-1, preserve=0, _self=cmd): # INTERNAL
+def _mpng(prefix, first=-1, last=-1, preserve=0, modal=0, _self=cmd): # INTERNAL
     import sys
     # WARNING: internal routine, subject to change
     try:
         _self.lock(_self)   
         fname = prefix
-        if re.search("\.png$",fname):
-            fname = re.sub("\.png$","",fname)
+        if re.search("[0-9]*\.png$",fname): # remove numbering, etc.
+            fname = re.sub("[0-9]*\.png$","",fname)
         fname = cmd.exp_path(fname)
-        r = _cmd.mpng_(_self._COb,str(fname),int(first),int(last),int(preserve))
+        r = _cmd.mpng_(_self._COb,str(fname),int(first),
+                       int(last),int(preserve),int(modal))
     finally:
         _self.unlock(-1,_self)
     return r
@@ -181,8 +314,8 @@ def _load(oname,finfo,state,ftype,finish,discrete,
             try:
                 # BEGIN PROPRIETARY CODE SEGMENT
                 from epymol import moe
-
                 if (string.find(finfo,":")>1):
+                    import urllib
                     moe_file = urllib.urlopen(finfo)
                 else:
                     moe_file = open(finfo)
@@ -194,32 +327,33 @@ def _load(oname,finfo,state,ftype,finish,discrete,
                 # END PROPRIETARY CODE SEGMENT
             except ImportError:
                 print "Error: .MOE format not supported by this PyMOL build."
-                if _self._raising(-1): raise _self._pymol.CmdException
+                if _self._raising(-1,_self): raise pymol.CmdException
 
         elif ftype == loadable.mae:
             try:
                 # BEGIN PROPRIETARY CODE SEGMENT
-                from epymol import schrodinger
-
+                from epymol import mae
                 if (string.find(finfo,":")>1):
+                    import urllib 
                     mae_file = urllib.urlopen(finfo)
                 else:
                     mae_file = open(finfo)
                 mae_str = mae_file.read()
                 mae_file.close()
-                r = schrodinger.read_maestr(mae_str,str(oname),
+                r = mae.read_maestr(mae_str,str(oname),
                                             int(state),
                                             int(finish),int(discrete),
-                                            int(quiet),int(zoom))
+                                            int(quiet),int(zoom),int(multiplex),_self=_self)
 
                 # END PROPRIETARY CODE SEGMENT
-            except ImportError:
+            except ValueError:
                 print "Error: .MAE format not supported by this PyMOL build."
-                if _self._raising(-1): raise self._pymol.CmdException
+                if _self._raising(-1,_self): raise pymol.CmdException
 
         else:
             if ftype in _load2str.keys() and (string.find(finfo,":")>1):
                 try:
+                    import urllib
                     tmp_file = urllib.urlopen(finfo)
                 except:
                     print "Error: unable to open URL '%s'"%finfo
@@ -350,13 +484,16 @@ def _refresh(swap_buffers=1,_self=cmd):  # Only call with GLUT thread!
     r = None
     try:
         _self.lock(_self)
-        if thread.get_ident() == _self._pymol.glutThread:
-            if swap_buffers:
-                r = _cmd.refresh_now(_self._COb)
+        if hasattr(_self._pymol,'glutThread'):
+            if thread.get_ident() == _self._pymol.glutThread:
+                if swap_buffers:
+                    r = _cmd.refresh_now(_self._COb)
+                else:
+                    r = _cmd.refresh(_self._COb)
             else:
-                r = _cmd.refresh(_self._COb)
+                r = _cmd.refresh_later(_self._COb)                
         else:
-            print "Error: Ignoring an unsafe call to cmd._refresh"
+            r = _cmd.refresh_later(_self._COb)
     finally:
         _self.unlock(-1,_self)
     return r
@@ -418,7 +555,10 @@ def _get_feedback(_self=cmd): # INTERNAL
                 r = _cmd.get_feedback(_self._COb)
         finally:
             _self.unlock(-1,_self)
+    else:
+        l = None
     return l
+
 get_feedback = _get_feedback # for legacy compatibility
 
 def _fake_drag(_self=cmd): # internal
@@ -429,6 +569,9 @@ def _fake_drag(_self=cmd): # internal
         _self.unlock(-1,_self)
     return 1
 
+def _sdof(tx,ty,tz,rx,ry,rz,_self=cmd):
+    _cmd._sdof(_self._COb,tx,ty,tz,rx,ry,rz)
+    
 # testing tools
 
 # for comparing floating point numbers calculated using
