@@ -15,6 +15,7 @@ def get_command_keywords(self_cmd=cmd):
         'alias'         : [ self_cmd.alias             , 0 , 0 , ''  , parsing.LITERAL1 ], # insecure
         'align'         : [ self_cmd.align             , 0 , 0 , ''  , parsing.STRICT ],
         'alter'         : [ self_cmd.alter             , 0 , 0 , ''  , parsing.LITERAL1 ], # insecure
+        '_alt'          : [ self_cmd._alt             , 0 , 0 , ''  , parsing.STRICT ],                
         'alter_state'   : [ self_cmd.alter_state       , 0 , 0 , ''  , parsing.LITERAL2 ], # insecure
         'angle'         : [ self_cmd.angle             , 0 , 0 , ''  , parsing.STRICT ],          
         'as'            : [ self_cmd.show_as           , 0 , 0 , ''  , parsing.STRICT ],          
@@ -25,13 +26,16 @@ def get_command_keywords(self_cmd=cmd):
         'bond'          : [ self_cmd.bond              , 0 , 0 , ''  , parsing.STRICT ],
         'break'         : [ self_cmd.python_help       , 0 , 0 , ''  , parsing.PYTHON ],   
         'button'        : [ self_cmd.button            , 0 , 0 , ''  , parsing.STRICT ],
+        'cache'         : [ self_cmd.cache             , 0 , 0 , ''  , parsing.STRICT ],
         'cartoon'       : [ self_cmd.cartoon           , 0 , 0 , ''  , parsing.STRICT ],
+        'capture'       : [ self_cmd.capture           , 0 , 0 , ''  , parsing.STRICT ],
         'cd'            : [ self_cmd.cd                , 0 , 0 , ''  , parsing.STRICT ],
         'center'        : [ self_cmd.center            , 0 , 0 , ''  , parsing.STRICT ],     
         'check'         : [ self_cmd.check             , 0 , 0 , ''  , parsing.STRICT ],
         'class'         : [ self_cmd.python_help       , 0 , 0 , ''  , parsing.PYTHON ], 
         'clip'          : [ self_cmd.clip              , 0 , 0 , ''  , parsing.STRICT ],
         'cls'           : [ self_cmd.cls               , 0 , 0 , ''  , parsing.STRICT ],
+        '_ctrl'         : [ self_cmd._ctrl             , 0 , 0 , ''  , parsing.STRICT ],        
         'color'         : [ self_cmd.color             , 0 , 0 , ''  , parsing.STRICT ],
         'commands'      : [ self_cmd.helping.commands  , 0 , 0 , ''  , parsing.STRICT ],
         'config_mouse'  : [ self_cmd.config_mouse      , 0 , 0 , ''  , parsing.STRICT ],
@@ -200,6 +204,7 @@ def get_command_keywords(self_cmd=cmd):
         'rms_cur'       : [ self_cmd.rms_cur           , 0 , 0 , ''  , parsing.STRICT ],
         'save'          : [ self_cmd.save              , 0 , 0 , ''  , parsing.SECURE ],
         'scene'         : [ self_cmd.scene             , 0 , 0 , ''  , parsing.STRICT ],
+        'scene_order'   : [ self_cmd.scene_order       , 0 , 0 , ''  , parsing.STRICT ],
         'sculpt_purge'  : [ self_cmd.sculpt_purge      , 0 , 0 , ''  , parsing.STRICT ],   
         'sculpt_deactivate': [ self_cmd.sculpt_deactivate,0, 0 , ''  , parsing.STRICT ],
         'sculpt_activate': [ self_cmd.sculpt_activate  , 0 , 0 , ''  , parsing.STRICT ],
@@ -248,6 +253,7 @@ def get_command_keywords(self_cmd=cmd):
         'unset'         : [ self_cmd.unset             , 0 , 0 , ''  , parsing.STRICT ],
         'unset_bond'    : [ self_cmd.unset_bond        , 0 , 0 , ''  , parsing.STRICT ],               
         'update'        : [ self_cmd.update            , 0 , 0 , ''  , parsing.STRICT ],
+        'valence'       : [ self_cmd.valence           , 0 , 0 , ''  , parsing.STRICT ],           
         'vdw_fit'       : [ self_cmd.vdw_fit           , 0 , 0 , ''  , parsing.STRICT ],   
         'view'          : [ self_cmd.view              , 0 , 0 , ''  , parsing.STRICT ],   
         'viewport'      : [ self_cmd.viewport          , 0 , 0 , ''  , parsing.STRICT ],
@@ -268,6 +274,7 @@ def get_command_keywords(self_cmd=cmd):
         'util.cbam'     : [ self_cmd.util.cbam         , 0 , 0 , ''  , parsing.STRICT ],
         'util.cbc'      : [ self_cmd.util.cbc          , 0 , 0 , ''  , parsing.STRICT ],
         'util.chainbow' : [ self_cmd.util.chainbow     , 0 , 0 , ''  , parsing.STRICT ],
+        'util.cnc'      : [ self_cmd.util.cnc          , 0 , 0 , ''  , parsing.STRICT ],        
         'util.colors'   : [ self_cmd.util.colors       , 0 , 0 , ''  , parsing.STRICT ],
         'util.mrock'    : [ self_cmd.util.mrock        , 0 , 0 , ''  , parsing.STRICT ], # LEGACY
         'util.mroll'    : [ self_cmd.util.mroll        , 0 , 0 , ''  , parsing.STRICT ], # LEGACY
