@@ -31,18 +31,21 @@ if __name__=='pymol.viewing':
           repres,repres_sc, is_string, is_list, is_ok, is_error, \
           toggle_dict,toggle_sc,stereo_dict,stereo_sc, \
           palette_dict ,palette_sc, window_dict, window_sc, \
-          safe_list_eval,  DEFAULT_ERROR, DEFAULT_SUCCESS
+          safe_list_eval,  safe_alpha_list_eval, \
+          location_code, location_sc, boolean_dict, boolean_sc, \
+          DEFAULT_ERROR, DEFAULT_SUCCESS
         
     import thread
     
-    rep_list = [ "lines","sticks","spheres",
-                     "dots","surface","mesh",
-                     "nonbonded", "nb_spheres",
-                     "cartoon","ribbon","labels","slice"]
+    rep_list = [ "lines", "sticks", "spheres", "dots", "surface",
+                 "mesh", "nonbonded", "nb_spheres", "cartoon",
+                 "ribbon", "labels", "slice", "ellipsoids"]
 
     scene_action_sc = Shortcut(['store','recall','clear','insert_before',
                                 'insert_after','next','previous',
-                                'start', 'update','rename','delete', 'append'])
+                                'start', 'update','rename','delete',
+                                'order', 'sort', 'first',
+                                'append'])
     scene_action_dict = {}
     scene_action_dict_sc = Shortcut([])
 
@@ -612,8 +615,8 @@ ARGUMENTS
     
     representation = lines, spheres, mesh, ribbon, cartoon, sticks,
         dots, surface, labels, extent, nonbonded, nb_spheres, slice,
-	extent, slice, dashes, angles, dihedrals, cgo, cell, callback,
-	or everything
+        extent, slice, dashes, angles, dihedrals, cgo, cell, callback,
+        or everything
 
     selection = string {default: all}
 
@@ -791,7 +794,7 @@ SEE ALSO
             _self.unlock(r,_self)
         if is_ok(r):
             if len(r):
-                if (_self.get_setting_legacy("logging")!=0.0) and (output!=3):
+                if (_self.get_setting_legacy("logging")!=0.0) and (output<3):
                     if not quiet:
                         print " get_view: matrix written to log file."
                     _self.log("_ set_view (\\\n","cmd.set_view((\\\n")
@@ -803,7 +806,7 @@ SEE ALSO
                     _self.log("_  %14.9f, %14.9f, %14.9f )\n"%r[22:25] , "  %14.9f, %14.9f, %14.9f ))\n"%r[22:25])
                     if output<2: # suppress if we have a log file open
                         output=0
-                if output and not quiet and (output!=3):
+                if output and (not quiet) and (output<3):
                     print "### cut below here and paste into script ###"
                     print "set_view (\\"
                     print "  %14.9f, %14.9f, %14.9f,\\"%r[0:3]
@@ -842,11 +845,11 @@ EXAMPLE
 
     set_view (\
         0.999876618,   -0.000452542,   -0.015699286,\
-	0.000446742,    0.999999821,   -0.000372844,\
-	0.015699454,    0.000365782,    0.999876678,\
-	0.000000000,    0.000000000, -150.258514404,\
-	11.842411041,   20.648729324,    8.775371552,\
-	118.464958191,  182.052062988,    0.000000000 )
+        0.000446742,    0.999999821,   -0.000372844,\
+        0.015699454,    0.000365782,    0.999876678,\
+        0.000000000,    0.000000000, -150.258514404,\
+        11.842411041,   20.648729324,    8.775371552,\
+        118.464958191,  182.052062988,    0.000000000 )
 
 PYMOL API
 
@@ -861,6 +864,7 @@ SEE ALSO
             try:
                 view = eval(re.sub(r"[^0-9,\-\)\(\.]","",view))
             except:
+                traceback.print_exc()
                 print "Error: bad view argument; should be a sequence of 18 floats."
                 raise QuietException
         if len(view)!=18:
@@ -877,7 +881,7 @@ SEE ALSO
                     float(view[ 9]),float(view[10]),float(view[11]),
                     float(view[12]),float(view[13]),float(view[14]),
                     float(view[15]),float(view[16]),float(view[17])),
-		    int(quiet),float(animate),int(hand))
+                    int(quiet),float(animate),int(hand))
             finally:
                 _self.unlock(r,_self)
         if _self._raising(r,_self): raise QuietException
@@ -937,19 +941,19 @@ SEE ALSO
             if action=='recall':
                 key = pymol._view_dict_sc.auto_err(key,'view')
                 _self.set_view(pymol._view_dict[key],animate=animate)
-                if _feedback(fb_module.scene,fb_mask.actions): # redundant
+                if _feedback(fb_module.scene,fb_mask.actions,_self): # redundant
                     print " view: \"%s\" recalled."%key
             elif (action=='store') or (action=='update'):
                 pymol._view_dict_sc.append(key)
                 pymol._view_dict[key]=_self.get_view(0)
-                if _feedback(fb_module.scene,fb_mask.actions):
+                if _feedback(fb_module.scene,fb_mask.actions,_self):
                     print " view: view stored as \"%s\"."%key
             elif action=='clear':
                 key = pymol._view_dict_sc.auto_err(key,'view')
                 if pymol._view_dict.has_key(key):
                     del pymol._view_dict[key]
                     pymol._view_dict_sc = Shortcut(pymol._view_dict.keys())            
-                    if _feedback(fb_module.scene,fb_mask.actions): # redundant
+                    if _feedback(fb_module.scene,fb_mask.actions,_self): # redundant
                         print " view: '%s' deleted."%key
 
 
@@ -1020,9 +1024,12 @@ SEE ALSO
             _self.lock(_self)
             cpy = copy.deepcopy(pymol._scene_dict)
         finally:
-            _self.unlock(_self)
+            _self.unlock(r,_self)
         return cpy
 
+    def get_scene_list(_self=cmd):
+        return copy.deepcopy(_scene_validate_list(_self))
+
     scene_sort_dict = {
         'F1' : 'F01',
         'F2' : 'F02',
@@ -1102,10 +1109,105 @@ SEE ALSO
                         if os.path.exists(new_file):
                             _self.do("_ cmd.load(r'''"+new_file+"''',format='psw')")
                             return 1
-
-                
         return 0
-    
+
+    def scene_order(names,sort=0,location='current',quiet=1,_self=cmd):
+        '''
+DESCRIPTION
+
+    "scene_order" changes the ordering of scenes.
+
+USAGE
+
+    scene_order names, sort, location
+
+ARGUMENTS
+
+    names = string: a space-separated list of names
+
+    sort = yes or no {default: no}
+
+    location = top, current, or bottom {default: current}
+
+EXAMPLES
+
+    scene_order *,yes             
+    scene_order F6 F4 F3 
+    scene_order 003 006 004, location=top
+
+PYMOL API
+
+    cmd.scene_order(string names, string sort, string location)
+
+SEE ALSO
+
+    scene
+    '''
+        pymol=_self._pymol
+
+        r = DEFAULT_ERROR
+        location=location_code[location_sc.auto_err(location,'location')]
+        if is_string(sort):
+            sort=boolean_dict[boolean_sc.auto_err(sort,'sort option')]
+        if is_string(names):
+            if names=='*':
+                names = _scene_validate_list(_self)
+            else:
+                names = names.split()
+        r = DEFAULT_SUCCESS
+        if len(names):
+            name_dict = {}
+            for name in names:
+                if not pymol._scene_dict.has_key(name):
+                    print " Error: scene '%s' is not defined."%name
+                    r = DEFAULT_ERROR
+                name_dict[name] = 1
+            if sort: # special F-key-name aware sort
+                sort_list = [] 
+                fkey_re = re.compile("[fF]([1-9][0-9]*).*")
+                for name in names:
+                    mo = fkey_re.match(name)
+                    if mo != None:
+                        sort_list.append( ("F%02d\n"%int(mo.group(1)),name) )
+                    else:
+                        sort_list.append( (name,name) )
+                sort_list.sort()
+                names = []
+                for name in sort_list:
+                    names.append(name[1])
+            if not is_error(r):
+                old_list = _scene_validate_list(_self)
+                if location < 0: # top
+                    new_list = names
+                    for name in old_list:
+                        if not name_dict.has_key(name):
+                            new_list.append(names)
+                    pymol._scene_order = new_list
+                elif location == 0: # current
+                    start = old_list.index(names[0])
+                    if start >= 0: # guaranteed?
+                        new_list = []
+                        for name in old_list[:start]:
+                            if not name_dict.has_key(name):
+                                new_list.append(name)
+                        new_list.extend(names)
+                        for name in old_list[start:]:
+                            if not name_dict.has_key(name):
+                                new_list.append(name)
+                        pymol._scene_order = new_list
+                else: # bottom
+                    new_list = []
+                    for name in old_list:
+                        if not name_dict.has_key(name):
+                            new_list.append(name)
+                    new_list.extend(names)
+                    pymol._scene_order = new_list
+        if _self._raising(r,_self):
+            raise pymol.CmdException
+        if not quiet and not is_error(r):
+            _self.scene('*')
+        return r
+        
     def scene(key='auto', action='recall', message=None, view=1,
               color=1, active=1, rep=1, frame=1, animate=-1,
               new_key=None, hand=1, quiet=1, _self=cmd):
@@ -1167,6 +1269,7 @@ SEE ALSO
         active = int(active)
         frame = int(frame)
         quiet = int(quiet)
+
         if not view:
             animate=0
         elif animate<0:
@@ -1208,8 +1311,10 @@ SEE ALSO
                     pymol._scene_dict_sc = Shortcut(pymol._scene_dict.keys())
                     pymol._scene_order = []
                     _scene_validate_list(_self)
+                elif action in ['sort']:
+                    _self.scene_order(key,1,quiet=quiet)                    
                 else:
-                    print " scene: stored scenes:"
+                    print " scene: current order:"
                     lst = _scene_validate_list(_self)
                     parsing.dump_str_list(lst)
             else:
@@ -1276,8 +1381,8 @@ SEE ALSO
                     if (ll>2) and (frame):
                         if list[2]!=None:
                             if not _self.get_movie_playing(): # don't set frame when movie is already playing
-				if _self.get_frame()!=list[2]: # only set the frame when it isn't already correct
-				    _self.frame(list[2])
+                                if _self.get_frame()!=list[2]: # only set the frame when it isn't already correct
+                                    _self.frame(list[2])
                     if (ll>3) and (color):
                         if list[3]!=None:
                             _self.set_colorection(list[3],key)
@@ -1323,7 +1428,7 @@ SEE ALSO
                     if (ll>0) and (view):
                         if list[0]!=None:
                             _self.set_view(list[0],animate,quiet,hand)
-                    if not quiet and _feedback(fb_module.scene,fb_mask.actions): # redundant
+                    if not quiet and _feedback(fb_module.scene,fb_mask.actions,_self): # redundant
                         print " scene: \"%s\" recalled."%key
                 elif (action=='store') or (action=='update'):
                     if key =='new':
@@ -1379,7 +1484,7 @@ SEE ALSO
                                 message = string.split(message,"\n")
                     entry.append(message)
                     pymol._scene_dict[key]=entry
-                    if _feedback(fb_module.scene,fb_mask.actions):
+                    if _feedback(fb_module.scene,fb_mask.actions,_self):
                         print " scene: scene stored as \"%s\"."%key
                     _scene_validate_list(_self)                        
                     _self.set("scenes_changed",1,quiet=1);
@@ -1400,13 +1505,15 @@ SEE ALSO
                             ix = lst.index(key) - 1
                             if ix>=0:
                                 setting.set("scene_current_name",lst[ix],quiet=1,_self=_self)
+                            else:
+                                setting.set("scene_current_name","",quiet=1,_self=_self)                                
                         _self.set("scenes_changed",1,quiet=1);               
                         del pymol._scene_dict[key]
                         name = "_scene_"+key+"_*"
                         _self.delete(name)
                         pymol._scene_dict_sc = Shortcut(pymol._scene_dict.keys())
                         _scene_validate_list(_self)
-                        if _feedback(fb_module.scene,fb_mask.actions):
+                        if _feedback(fb_module.scene,fb_mask.actions,_self):
                             print " scene: '%s' deleted."%key
                     _self.set("session_changed",1,quiet=1)                                                                    
                 elif action=='next':
@@ -1424,12 +1531,12 @@ SEE ALSO
                     if ix<len(lst):
                         scene_name = lst[ix]
                         _self.set('scene_current_name', scene_name, quiet=1)
-                        scene(scene_name,'recall',animate=animate)
+                        scene(scene_name,'recall',animate=animate,_self=_self)
                     elif setting.get("scene_loop",_self=_self)=="on": # loop back to the beginning
                         if len(lst):
                             scene_name = lst[0]
                             _self.set('scene_current_name', scene_name, quiet=1)
-                            scene(scene_name,'recall',animate=animate)
+                            scene(scene_name,'recall',animate=animate,_self=_self)
                     else: # otherwise put up blank screen
                         _self.set('scene_current_name','',quiet=1)
                         chained = 0
@@ -1455,13 +1562,13 @@ SEE ALSO
                             _self.quit()
                     if ix>=0:
                         scene_name = lst[ix]
-                        scene(scene_name,'recall',animate=animate,hand=-1)
+                        scene(scene_name,'recall',animate=animate,hand=-1,_self=_self)
                     elif setting.get("scene_loop",_self=_self)=="on": # loop back to the end
                         print setting.get("scene_loop",_self=_self)
                         if len(lst):
                             scene_name = lst[-1]
                             _self.set('scene_current_name', scene_name, quiet=1)
-                            scene(scene_name,'recall',animate=animate,hand=-1)
+                            scene(scene_name,'recall',animate=animate,hand=-1,_self=_self)
                     else: # otherwise put up blank screen
                         _self.set('scene_current_name','',quiet=1)
                         if ((setting.get("presentation",_self=_self)=="on") and 
@@ -1470,6 +1577,13 @@ SEE ALSO
                         if len(lst):
                             _self.disable() # just hide everything
                             _self.wizard()
+                elif action=='order':
+                    _self.scene_order(key,quiet=quiet)
+                elif action=='sort':
+                    _self.scene_order(key,1,quiet=quiet)
+                elif action=='first':
+                    _self.scene_order(key,location='top',quiet=quiet)
+                
         finally:
             _self.unlock(r,_self)
         return r
@@ -1890,8 +2004,11 @@ NOTES
         if _self._raising(r,_self): raise QuietException
         return r
 
+    def capture(quiet=1, _self=cmd):
+        _self.draw(antialias=-2,quiet=quiet)
+        
     def draw(width=0, height=0, antialias=-1, quiet=1, _self=cmd):
-    	'''
+        '''
 DESCRIPTION
 
     "draw" creates an OpenGL-based image of the current frame.  
@@ -2059,15 +2176,15 @@ SEE ALSO
         '''
         r = None
         if thread.get_ident() == pymol.glutThread:
-	    try:
-		_self.lock(_self)
-		r = _cmd.refresh_now(_self._COb)
-	    finally:
-		_self.unlock(r,_self)
+            try:
+                _self.lock(_self)
+                r = _cmd.refresh_now(_self._COb)
+            finally:
+                _self.unlock(r,_self)
         else:
             try:
                 _self.lock(_self)
-                r = _self._do("_ cmd._refresh()")
+                r = _self._do("_ cmd._refresh(_self=cmd)",_self=_self)
             finally:
                 _self.unlock(r,_self)
         if _self._raising(r,_self): raise QuietException
@@ -2235,6 +2352,7 @@ SEE ALSO
         if _self._raising(r,_self): raise QuietException
         return r
 
+
     def color(color, selection="(all)", quiet=1, flags=0, _self=cmd):
         '''
 DESCRIPTION
