@@ -1,5 +1,7 @@
-
+7
 from pymol import cmd as global_cmd
+import pymol
+
 
 class Cmd:
 
@@ -16,7 +18,8 @@ class Cmd:
         # private data
     
         self.color_sc = None
-
+        self.reaper = None
+        
         # CONSTANTS (pymol/constants.py)
 
         self.DEFAULT_ERROR = global_cmd.DEFAULT_ERROR
@@ -72,15 +75,21 @@ class Cmd:
             self.lock_api_c = _pymol.lock_api_c
             self.lock_api_status = _pymol.lock_api_status
             self.lock_api_glut = _pymol.lock_api_glut
+            self.lock_api_data = _pymol.lock_api_data            
         else:
             # use global locks (for debugging)
             self.lock_api = global_cmd._pymol.lock_api
             self.lock_api_c = global_cmd._pymol.lock_api_c
             self.lock_api_status = global_cmd._pymol.lock_api_status
             self.lock_api_glut = global_cmd._pymol.lock_api_glut
+            self.lock_api_data = global_cmd._pymol.lock_api_data            
+
+        self.lock_api_allow_flush = 1
 
         self.lock_c = global_cmd.lock_c
         self.unlock_c = global_cmd.unlock_c
+        self.lock_data = global_cmd.lock_data
+        self.unlock_data = global_cmd.unlock_data
         self.lock_status_attempt = global_cmd.lock_status_attempt
         self.lock_status = global_cmd.lock_status
         self.unlock_status = global_cmd.unlock_status
@@ -104,14 +113,16 @@ class Cmd:
         self.is_error = global_cmd.is_error
         self.is_ok = global_cmd.is_ok
 
+        # from pymol/feedingback.py
+
+        self._feedback = global_cmd._feedback
+        
         # from pymol/internal.py
         
         self._adjust_coord = global_cmd._adjust_coord
-        self._alt = global_cmd._alt
         self._coordset_update_spawn = global_cmd._coordset_update_spawn
         self._coordset_update_thread = global_cmd._coordset_update_thread
         self._copy_image = global_cmd._copy_image
-        self._ctrl = global_cmd._ctrl
         self._do = global_cmd._do
         self._dump_floats = global_cmd._dump_floats
         self._dump_ufloats = global_cmd._dump_ufloats
@@ -133,8 +144,12 @@ class Cmd:
         self._ray_spawn = global_cmd._ray_spawn
         self._refresh = global_cmd._refresh
         self._sgi_stereo = global_cmd._sgi_stereo
-        self._special = global_cmd._special
         self._validate_color_sc = global_cmd._validate_color_sc
+        self._cache_set = global_cmd._cache_set
+        self._cache_get = global_cmd._cache_get
+        self._cache_clear = global_cmd._cache_clear
+        self._cache_mark = global_cmd._cache_mark
+        self._cache_purge = global_cmd._cache_purge
 
         # now we create the command langauge
 
@@ -147,14 +162,69 @@ class Cmd:
         self.kwhash = self.Shortcut(self.kw_list)
         keywords.fix_dict(self.keyword)
 
+        self.controlling = pymol.controlling
+        self.completing = pymol.completing
+        self.controlling = pymol.controlling
+        self.editing = pymol.editing
+        self.exporting = pymol.exporting
+        self.moving = pymol.moving
+        self.creating = pymol.creating
+        self.viewing = pymol.viewing
+        self.setting = pymol.setting
+        self.commanding = pymol.commanding
+
         self.help_only = keywords.get_help_only_keywords()
-        help_sc = self.Shortcut(self.keyword.keys()+self.help_only.keys())
+        self.help_sc = self.Shortcut(self.keyword.keys()+self.help_only.keys())
+
+        
+        self.selection_sc = lambda sc=self.Shortcut,gn=self.get_names:sc(gn('public')+['all'])
+        self.object_sc = lambda sc=self.Shortcut,gn=self.get_names:sc(gn('objects'))
+        self.map_sc = lambda sc=self.Shortcut,gnot=self.get_names_of_type:sc(gnot('object:map'))
+        self.contour_sc =  lambda sc=self.Shortcut,gnot=self.get_names_of_type:sc(
+            gnot('object:mesh')+gnot('object:surface'))
+        
+        self.fb_action_sc = pymol.feedingback.fb_action_sc
+        self.fb_module_sc = pymol.feedingback.fb_module_sc
+        self.fb_mask_sc = pymol.feedingback.fb_mask_sc
+        
+        self.auto_arg = pymol.completing.get_auto_arg_list(self)
+        self.color_sc = None
+
+        # keyboard configuration
+                
+        from pymol import keyboard
+        
+        self.special = keyboard.get_special(self)
+
+        self.shft_special = keyboard.get_shft_special(self)        
+        self.alt_special = keyboard.get_alt_special(self)        
+        self.ctrl_special = keyboard.get_ctrl_special(self)
+        self.ctsh_special = keyboard.get_ctsh_special(self)
+
+        self.ctrl = keyboard.get_ctrl(self)        
+        self.alt = keyboard.get_alt(self)
         
 # PUBLIC API METHODS which expect "self" as the first argument
 
 # ========= WARNING WARNING WARNING WARNING ===========
 # ========= AUTOGENERATED BEYOND THIS POINT ===========
 
+    def _feedback(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd._feedback, a, k)
+    
+    def _special(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd._special, a, k)
+    
+    def _ctrl(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd._ctrl, a, k)
+    
+    def _alt(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd._alt, a, k)
+    
     def accept(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.accept, a, k)
@@ -211,10 +281,18 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.button, a, k)
     
+    def cache(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.cache, a, k)
+    
     def cartoon(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.cartoon, a, k)
     
+    def capture(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.capture, a, k)
+    
     def cd(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.cd, a, k)
@@ -283,6 +361,10 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.delete, a, k)
     
+    def del_colorection(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.del_colorection, a, k)
+    
     def deprotect(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.deprotect, a, k)
@@ -311,6 +393,10 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.distance, a, k)
     
+    def dist(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.dist, a, k)
+    
     def do(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.do, a, k)
@@ -435,6 +521,10 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.get_chains, a, k)
     
+    def get_color_index(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.get_color_index, a, k)
+    
     def get_color_indices(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.get_color_indices, a, k)
@@ -443,6 +533,10 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.get_colorection, a, k)
     
+    def get_color_tuple(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.get_color_tuple, a, k)
+    
     def get_dihedral(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.get_dihedral, a, k)
@@ -463,10 +557,6 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.get_frame, a, k)
     
-    def get_state(self, *a, **k):
-        k['_self']=self
-        return apply(global_cmd.get_state, a, k)
-    
     def get_model(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.get_model, a, k)
@@ -479,6 +569,10 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.get_movie_locked, a, k)
     
+    def get_movie_length(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.get_movie_length, a, k)
+    
     def get_mtl_obj(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.get_mtl_obj, a, k)
@@ -487,6 +581,10 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.get_names, a, k)
     
+    def get_names_of_type(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.get_names_of_type, a, k)
+    
     def get_object_list(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.get_object_list, a, k)
@@ -507,6 +605,18 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.get_povray, a, k)
     
+    def get_progress(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.get_progress, a, k)
+    
+    def get_renderer(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.get_renderer, a, k)
+    
+    def get_scene_dict(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.get_scene_dict, a, k)
+    
     def get_session(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.get_session, a, k)
@@ -539,6 +649,10 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.get_setting_text, a, k)
     
+    def get_state(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.get_state, a, k)
+    
     def get_symmetry(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.get_symmetry, a, k)
@@ -663,6 +777,10 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.load, a, k)
     
+    def load_cgo(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.load_cgo, a, k)
+    
     def load_embedded(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.load_embedded, a, k)
@@ -671,6 +789,10 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.load_model, a, k)
     
+    def load_object(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.load_object, a, k)
+    
     def load_png(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.load_png, a, k)
@@ -879,6 +1001,10 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.read_pdbstr, a, k)
     
+    def ready(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.ready, a, k)
+    
     def rebuild(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.rebuild, a, k)
@@ -979,6 +1105,10 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.select, a, k)
     
+    def select_list(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.select_list, a, k)
+    
     def set(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.set, a, k)
@@ -1023,6 +1153,14 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.set_title, a, k)
     
+    def set_wizard(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.set_wizard, a, k)
+    
+    def set_wizard_stack(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.set_wizard_stack, a, k)
+    
     def set_view(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.set_view, a, k)
@@ -1143,6 +1281,10 @@ class Cmd:
         k['_self']=self
         return apply(global_cmd.update, a, k)
     
+    def valence(self, *a, **k):
+        k['_self']=self
+        return apply(global_cmd.valence, a, k)
+    
     def vdw_fit(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.vdw_fit, a, k)
@@ -1166,4 +1308,4 @@ class Cmd:
     def zoom(self, *a, **k):
         k['_self']=self
         return apply(global_cmd.zoom, a, k)
-    
+    
\ No newline at end of file
